! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! Linear Algebra Data and Routines File
! 
! Generated by KPP-2.2.4_gc symbolic chemistry Kinetics PreProcessor
!       (http://www.cs.vt.edu/~asandu/Software/KPP)
! KPP is distributed under GPL, the general public licence
!       (http://www.gnu.org/copyleft/gpl.html)
! (C) 1995-1997, V. Damian & A. Sandu, CGRER, Univ. Iowa
! (C) 1997-2005, A. Sandu, Michigan Tech, Virginia Tech
!     With important contributions from:
!        M. Damian, Villanova University, USA
!        R. Sander, Max-Planck Institute for Chemistry, Mainz, Germany
! 
! File                 : gckpp_LinearAlgebra.f90
! Time                 : Thu Mar 23 12:42:21 2017
! Working directory    : /n/home05/msulprizio/GC/FlexChem/Mechanisms/UCX
! Equation file        : gckpp.kpp
! Output root filename : gckpp
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



MODULE gckpp_LinearAlgebra

  USE gckpp_Parameters
  USE gckpp_JacobianSP

  IMPLICIT NONE

CONTAINS


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! SPARSE_UTIL - SPARSE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecomp( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: IER
      REAL(kind=dp) :: JVS(LU_NONZERO), W(NVAR), a
      INTEGER  :: k, kk, j, jj

      a = 0. ! mz_rs_20050606
      IER = 0
      DO k=1,NVAR
        ! mz_rs_20050606: don't check if real value == 0
        ! IF ( JVS( LU_DIAG(k) ) .EQ. 0. ) THEN
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(a) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecomp


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplx( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization, complex
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: IER
      DOUBLE COMPLEX :: JVS(LU_NONZERO), W(NVAR), a
      REAL(kind=dp)  :: b = 0.0
      INTEGER        :: k, kk, j, jj

      IER = 0
      DO k=1,NVAR
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(b) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecompCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplxR( JVSR, JVSI, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!    Sparse LU factorization, complex
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: IER
      REAL(kind=dp) :: JVSR(LU_NONZERO), JVSI(LU_NONZERO) 
      REAL(kind=dp) :: WR(NVAR), WI(NVAR), ar, ai, den
      INTEGER       :: k, kk, j, jj

      IER = 0
      ar  = 0.0
      DO k=1,NVAR
        IF (  ( ABS(JVSR(LU_DIAG(k))) < TINY(ar) ) .AND. &
              ( ABS(JVSI(LU_DIAG(k))) < TINY(ar) ) )  THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              WR( LU_ICOL(kk) ) = JVSR(kk)
              WI( LU_ICOL(kk) ) = JVSI(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            den = JVSR(LU_DIAG(j))**2 + JVSI(LU_DIAG(j))**2
            ar = -(WR(j)*JVSR(LU_DIAG(j)) + WI(j)*JVSI(LU_DIAG(j)))/den
            ai = -(WI(j)*JVSR(LU_DIAG(j)) - WR(j)*JVSI(LU_DIAG(j)))/den
            WR(j) = -ar
            WI(j) = -ai
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               WR( LU_ICOL(jj) ) = WR( LU_ICOL(jj) ) + ar*JVSR(jj) - ai*JVSI(jj)
               WI( LU_ICOL(jj) ) = WI( LU_ICOL(jj) ) + ar*JVSI(jj) + ai*JVSR(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVSR(kk) = WR( LU_ICOL(kk) )
            JVSI(kk) = WI( LU_ICOL(kk) )
         END DO
      END DO

END SUBROUTINE KppDecompCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveCmplx

! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), sumr, sumi, den

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             XR(i) = XR(i) - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
             XI(i) = XI(i) - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
         END DO  
      END DO

      DO i=NVAR,1,-1
        sumr = XR(i); sumi = XI(i)
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
            sumr = sumr - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
            sumi = sumi - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
        END DO
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (sumr*JVSR(LU_DIAG(i)) + sumi*JVSI(LU_DIAG(i)))/den
        XI(i) = (sumi*JVSR(LU_DIAG(i)) - sumr*JVSI(LU_DIAG(i)))/den
      END DO
      
END SUBROUTINE KppSolveCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve transpose subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), den

      DO i=1,NVAR
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (XR(i)*JVSR(LU_DIAG(i)) + XI(i)*JVSI(LU_DIAG(i)))/den
        XI(i) = (XI(i)*JVSR(LU_DIAG(i)) - XR(i)*JVSI(LU_DIAG(i)))/den
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplxR


!
! Next few commented subroutines perform sparse big linear algebra
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppDecompBig( JVS, IP, IER )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse LU factorization
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: IP3(3), IER, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), W(3,3,NVAR), a(3,3), E(3,3)
!      INTEGER  :: k, kk, j, jj
!
!      a = 0.0d0
!      IER = 0
!      DO k=1,NVAR
!        DO kk = LU_CROW(k), LU_CROW(k+1)-1
!              W( 1:3,1:3,LU_ICOL(kk) ) = JVS(1:3,1:3,kk)
!        END DO
!        DO kk = LU_CROW(k), LU_DIAG(k)-1
!            j = LU_ICOL(kk)
!            E(1:3,1:3) = JVS( 1:3,1:3,LU_DIAG(j) )
!            ! CALL DGETRF(3,3,E,3,IP3,IER) 
!            CALL FAC3(E,IP3,IER)
!            IF ( IER /= 0 )  RETURN
!            ! a = W(j) / JVS( LU_DIAG(j) )
!            a(1:3,1:3) = W( 1:3,1:3,j )
!            ! CALL DGETRS ('N',3,3,E,3,IP3,a,3,IER) 
!            CALL SOL3('N',E,IP3,a(1,1))
!            CALL SOL3('N',E,IP3,a(1,2))
!            CALL SOL3('N',E,IP3,a(1,3))
!            W(1:3,1:3,j) = a(1:3,1:3)
!            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
!               W( 1:3,1:3,LU_ICOL(jj) ) = W( 1:3,1:3,LU_ICOL(jj) ) &
!                        - MATMUL( a(1:3,1:3) , JVS(1:3,1:3,jj) )
!            END DO
!         END DO
!         DO kk = LU_CROW(k), LU_CROW(k+1)-1
!            JVS(1:3,1:3,kk) = W( 1:3,1:3,LU_ICOL(kk) )
!         END DO
!      END DO
!
!      DO k=1,NVAR
!         ! CALL WGEFA(JVS(1,1,LU_DIAG(k)),3,3,IP(1,k),IER)
!         ! CALL DGETRF(3,3,JVS(1,1,LU_DIAG(k)),3,IP(1,k),IER)
!         CALL FAC3(JVS(1,1,LU_DIAG(k)),IP(1,k),IER)
!         IF ( IER /= 0 )  RETURN
!      END DO 
!      
!END SUBROUTINE KppDecompBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBig( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse solve subroutine using indirect addressing
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: i, j, k, m, IP3(3), IP(3,NVAR), IER
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR), sum(3)
!
!      DO i=1,NVAR
!        DO j = LU_CROW(i), LU_DIAG(i)-1 
!          !X(1:3,i) = X(1:3,i) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       X(k,i) = X(k,i) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO  
!      END DO
!
!      DO i=NVAR,1,-1
!        sum(1:3) = X(1:3,i);
!        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
!          !sum(1:3) = sum(1:3) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       sum(k) = sum(k) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO
!        ! X(i) = sum/JVS(LU_DIAG(i));
!        ! CALL DGETRS ('N',3,1,JVS(1:3,1:3,LU_DIAG(i)),3,IP(1,i),sum,3,0) 
!        ! CALL WGESL('N',JVS(1,1,LU_DIAG(i)),3,3,IP(1,i),sum)
!        CALL SOL3('N',JVS(1,1,LU_DIAG(i)),IP(1,i),sum)
!        X(1:3,i) = sum(1:3)
!      END DO
!      
!END SUBROUTINE KppSolveBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBigTR( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Big sparse transpose solve using indirect addressing
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER       :: i, j, k, m, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR)
!
!      DO i=1,NVAR
!        ! X(i) = X(i)/JVS(LU_DIAG(i))
!        CALL SOL3('T',JVS(1,1,LU_DIAG(i)),IP(1,i),X(1,i))
!        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !    - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!
!      DO i=NVAR, 1, -1
!        DO j=LU_CROW(i),LU_DIAG(i)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !   - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!      
!END SUBROUTINE KppSolveBigTR
!
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE FAC3(A,IPVT,INFO)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     FAC3 FACTORS THE MATRIX A (3,3) BY
!!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!!     LINPACK - LIKE 
!!
!!     Remove comments to perform pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!
!      REAL(kind=dp) :: A(3,3)
!      INTEGER       :: IPVT(3),INFO
!!      INTEGER       :: L
!!      REAL(kind=dp) :: t, dmax, da, TMP(3)
!      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0
!
!      info = 0
!!      t = TINY(da)
!!      
!!      da = ABS(A(1,1)); L = 1
!!      IF ( ABS(A(2,1))>da ) THEN
!!        da = ABS(A(2,1)); L = 2
!!        IF ( ABS(A(3,1))>da ) THEN
!!          L = 3
!!        END IF  
!!      END IF  
!!      IPVT(1)  = L
!!      IF (L /=1 ) THEN
!!         TMP(1:3) = A(L,1:3)
!!         A(L,1:3) = A(1,1:3)
!!         A(1,1:3) = TMP(1:3)
!!      END IF
!!      IF (ABS(A(1,1)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!
!      A(2,1) = A(2,1)/A(1,1)
!      A(2,2) = A(2,2) - A(2,1)*A(1,2)
!      A(2,3) = A(2,3) - A(2,1)*A(1,3)
!      A(3,1) = A(3,1)/A(1,1)
!      A(3,2) = A(3,2) - A(3,1)*A(1,2)
!      A(3,3) = A(3,3) - A(3,1)*A(1,3)
!      
!!      IPVT(2)  = 2
!!      IF (ABS(A(3,2))>ABS(A(2,2))) THEN
!!         IPVT(2)  = 3
!!         TMP(2:3) = A(3,2:3)
!!         A(3,2:3) = A(2,2:3)
!!         A(2,2:3) = TMP(2:3)
!!      END IF
!!      IF (ABS(A(2,2)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!      
!      A(3,2)   = A(3,2)/A(2,2)
!      A(3,3)   = A(3,3) - A(3,2)*A(2,3)
!      IPVT(3)  = 3
!      
!END SUBROUTINE FAC3
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE SOL3(Trans,A,IPVT,b)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     SOL3 solves the system 3x3
!!     A * x = b  or  trans(a) * x = b
!!     using the factors computed by WGEFA.
!!
!!     Trans      = 'N'   to solve  A*x = b ,
!!                = 'T'   to solve  transpose(A)*x = b
!!     LINPACK - LIKE 
!!
!!     Remove comments to use pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!      CHARACTER     :: Trans
!      REAL(kind=dp) :: a(3,3),b(3)
!      INTEGER       :: IPVT(3)
!!      INTEGER       :: L
!!      REAL(kind=dp) :: TMP
!      
!      SELECT CASE (Trans)
!
!      CASE ('n','N')  !  Solve  A * x = b
!
!!     Solve  L*y = b
!!         L = IPVT(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!         b(2) = b(2)-A(2,1)*b(1)
!         b(3) = b(3)-A(3,1)*b(1)
!         
!!         L = IPVT(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(3) = b(3)-A(3,2)*b(2)
!
!!     Solve  U*x = y
!         b(3) = b(3)/A(3,3)
!         b(2) = (b(2)-A(2,3)*b(3))/A(2,2)
!         b(1) = (b(1)-A(1,3)*b(3)-A(1,2)*b(2))/A(1,1)
!      
!      
!      CASE ('t','T')  !  Solve transpose(A) * x = b
!
!!      Solve transpose(U)*y = b
!         b(1) = b(1)/A(1,1)
!         b(2) = (b(2)-A(1,2)*b(1))/A(2,2)
!         b(3) = (b(3)-A(1,3)*b(1)-A(2,3)*b(2))/A(3,3)
!
!!      Solve transpose(L)*x = y
!         b(2) = b(2)-A(3,2)*b(3)
!!         L = ipvt(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(1) = b(1)-A(3,1)*b(3)-A(2,1)*b(2)
!!         L = ipvt(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!   
!      END SELECT
!
!END SUBROUTINE SOL3

! End of SPARSE_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolve - sparse back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolve ( JVS, X )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)

  X(35) = X(35)-JVS(279)*X(20)
  X(36) = X(36)-JVS(284)*X(22)
  X(66) = X(66)-JVS(387)*X(48)
  X(82) = X(82)-JVS(475)*X(80)
  X(91) = X(91)-JVS(533)*X(83)
  X(93) = X(93)-JVS(546)*X(24)-JVS(547)*X(77)
  X(97) = X(97)-JVS(582)*X(25)
  X(100) = X(100)-JVS(604)*X(99)
  X(101) = X(101)-JVS(610)*X(66)
  X(105) = X(105)-JVS(640)*X(88)
  X(106) = X(106)-JVS(649)*X(73)-JVS(650)*X(96)
  X(107) = X(107)-JVS(661)*X(71)-JVS(662)*X(103)
  X(108) = X(108)-JVS(675)*X(20)-JVS(676)*X(22)-JVS(677)*X(51)-JVS(678)*X(92)-JVS(679)*X(93)-JVS(680)*X(102)-JVS(681)&
             &*X(104)
  X(110) = X(110)-JVS(702)*X(100)
  X(111) = X(111)-JVS(711)*X(99)
  X(113) = X(113)-JVS(730)*X(64)
  X(114) = X(114)-JVS(738)*X(49)-JVS(739)*X(60)
  X(116) = X(116)-JVS(757)*X(90)
  X(117) = X(117)-JVS(767)*X(90)-JVS(768)*X(116)
  X(118) = X(118)-JVS(777)*X(50)
  X(119) = X(119)-JVS(789)*X(99)-JVS(790)*X(100)
  X(120) = X(120)-JVS(801)*X(97)-JVS(802)*X(113)-JVS(803)*X(114)
  X(122) = X(122)-JVS(839)*X(88)
  X(123) = X(123)-JVS(849)*X(75)-JVS(850)*X(100)
  X(124) = X(124)-JVS(860)*X(100)
  X(126) = X(126)-JVS(878)*X(90)-JVS(879)*X(109)-JVS(880)*X(111)-JVS(881)*X(112)-JVS(882)*X(115)-JVS(883)*X(119)&
             &-JVS(884)*X(124)
  X(127) = X(127)-JVS(901)*X(71)-JVS(902)*X(100)
  X(129) = X(129)-JVS(921)*X(78)-JVS(922)*X(99)
  X(130) = X(130)-JVS(932)*X(50)-JVS(933)*X(60)
  X(131) = X(131)-JVS(943)*X(68)-JVS(944)*X(90)
  X(132) = X(132)-JVS(953)*X(80)
  X(133) = X(133)-JVS(961)*X(61)-JVS(962)*X(81)
  X(134) = X(134)-JVS(976)*X(21)-JVS(977)*X(69)-JVS(978)*X(121)
  X(135) = X(135)-JVS(991)*X(84)
  X(136) = X(136)-JVS(1001)*X(90)
  X(137) = X(137)-JVS(1011)*X(42)-JVS(1012)*X(52)-JVS(1013)*X(81)-JVS(1014)*X(85)-JVS(1015)*X(91)-JVS(1016)*X(92)&
             &-JVS(1017)*X(96)-JVS(1018)*X(108)-JVS(1019)*X(113)-JVS(1020)*X(128)-JVS(1021)*X(132)
  X(138) = X(138)-JVS(1052)*X(48)-JVS(1053)*X(54)-JVS(1054)*X(55)-JVS(1055)*X(85)-JVS(1056)*X(101)-JVS(1057)*X(128)
  X(139) = X(139)-JVS(1072)*X(78)-JVS(1073)*X(80)-JVS(1074)*X(92)-JVS(1075)*X(93)-JVS(1076)*X(103)-JVS(1077)*X(105)&
             &-JVS(1078)*X(109)-JVS(1079)*X(129)-JVS(1080)*X(132)
  X(140) = X(140)-JVS(1099)*X(86)-JVS(1100)*X(125)
  X(142) = X(142)-JVS(1120)*X(79)-JVS(1121)*X(118)-JVS(1122)*X(130)-JVS(1123)*X(131)-JVS(1124)*X(136)
  X(143) = X(143)-JVS(1137)*X(64)-JVS(1138)*X(94)-JVS(1139)*X(121)-JVS(1140)*X(141)
  X(144) = X(144)-JVS(1152)*X(87)-JVS(1153)*X(99)-JVS(1154)*X(102)-JVS(1155)*X(104)-JVS(1156)*X(141)
  X(145) = X(145)-JVS(1165)*X(77)-JVS(1166)*X(99)
  X(146) = X(146)-JVS(1175)*X(77)-JVS(1176)*X(88)-JVS(1177)*X(103)-JVS(1178)*X(144)-JVS(1179)*X(145)
  X(147) = X(147)-JVS(1188)*X(22)-JVS(1189)*X(51)-JVS(1190)*X(78)-JVS(1191)*X(79)-JVS(1192)*X(80)-JVS(1193)*X(92)&
             &-JVS(1194)*X(93)-JVS(1195)*X(97)-JVS(1196)*X(105)-JVS(1197)*X(107)-JVS(1198)*X(112)-JVS(1199)*X(115)-JVS(1200)&
             &*X(122)-JVS(1201)*X(125)-JVS(1202)*X(127)-JVS(1203)*X(129)-JVS(1204)*X(132)-JVS(1205)*X(135)-JVS(1206)*X(136)&
             &-JVS(1207)*X(142)-JVS(1208)*X(144)-JVS(1209)*X(145)-JVS(1210)*X(146)
  X(148) = X(148)-JVS(1233)*X(86)-JVS(1234)*X(88)-JVS(1235)*X(125)-JVS(1236)*X(145)
  X(149) = X(149)-JVS(1247)*X(86)-JVS(1248)*X(103)-JVS(1249)*X(125)-JVS(1250)*X(144)-JVS(1251)*X(145)-JVS(1252)*X(148)
  X(150) = X(150)-JVS(1262)*X(99)
  X(151) = X(151)-JVS(1272)*X(42)-JVS(1273)*X(76)-JVS(1274)*X(91)-JVS(1275)*X(92)-JVS(1276)*X(132)-JVS(1277)*X(140)&
             &-JVS(1278)*X(145)-JVS(1279)*X(146)-JVS(1280)*X(148)-JVS(1281)*X(149)
  X(152) = X(152)-JVS(1292)*X(75)-JVS(1293)*X(80)-JVS(1294)*X(82)-JVS(1295)*X(84)-JVS(1296)*X(92)-JVS(1297)*X(93)&
             &-JVS(1298)*X(94)-JVS(1299)*X(97)-JVS(1300)*X(103)-JVS(1301)*X(109)-JVS(1302)*X(113)-JVS(1303)*X(121)-JVS(1304)&
             &*X(122)-JVS(1305)*X(123)-JVS(1306)*X(132)-JVS(1307)*X(135)-JVS(1308)*X(141)-JVS(1309)*X(142)-JVS(1310)*X(143)&
             &-JVS(1311)*X(144)-JVS(1312)*X(145)-JVS(1313)*X(146)-JVS(1314)*X(148)-JVS(1315)*X(149)-JVS(1316)*X(150)&
             &-JVS(1317)*X(151)
  X(153) = X(153)-JVS(1335)*X(87)-JVS(1336)*X(102)-JVS(1337)*X(104)-JVS(1338)*X(121)-JVS(1339)*X(125)-JVS(1340)*X(136)&
             &-JVS(1341)*X(140)-JVS(1342)*X(141)-JVS(1343)*X(142)-JVS(1344)*X(144)-JVS(1345)*X(148)-JVS(1346)*X(149)&
             &-JVS(1347)*X(151)
  X(154) = X(154)-JVS(1360)*X(32)-JVS(1361)*X(33)-JVS(1362)*X(37)-JVS(1363)*X(45)-JVS(1364)*X(46)-JVS(1365)*X(62)&
             &-JVS(1366)*X(96)-JVS(1367)*X(106)
  X(155) = X(155)-JVS(1382)*X(49)-JVS(1383)*X(68)-JVS(1384)*X(71)-JVS(1385)*X(76)-JVS(1386)*X(86)-JVS(1387)*X(87)&
             &-JVS(1388)*X(90)-JVS(1389)*X(91)-JVS(1390)*X(92)-JVS(1391)*X(95)-JVS(1392)*X(102)-JVS(1393)*X(104)-JVS(1394)&
             &*X(113)-JVS(1395)*X(114)-JVS(1396)*X(116)-JVS(1397)*X(117)-JVS(1398)*X(123)-JVS(1399)*X(125)-JVS(1400)*X(127)&
             &-JVS(1401)*X(129)-JVS(1402)*X(130)-JVS(1403)*X(131)-JVS(1404)*X(132)-JVS(1405)*X(135)-JVS(1406)*X(136)&
             &-JVS(1407)*X(140)-JVS(1408)*X(141)-JVS(1409)*X(143)-JVS(1410)*X(144)-JVS(1411)*X(145)-JVS(1412)*X(146)&
             &-JVS(1413)*X(148)-JVS(1414)*X(149)-JVS(1415)*X(150)-JVS(1416)*X(151)-JVS(1417)*X(153)
  X(156) = X(156)-JVS(1434)*X(68)-JVS(1435)*X(78)-JVS(1436)*X(82)-JVS(1437)*X(83)-JVS(1438)*X(87)-JVS(1439)*X(90)&
             &-JVS(1440)*X(102)-JVS(1441)*X(104)-JVS(1442)*X(113)-JVS(1443)*X(116)-JVS(1444)*X(117)-JVS(1445)*X(129)&
             &-JVS(1446)*X(131)-JVS(1447)*X(132)-JVS(1448)*X(135)-JVS(1449)*X(136)-JVS(1450)*X(141)-JVS(1451)*X(142)&
             &-JVS(1452)*X(143)-JVS(1453)*X(144)-JVS(1454)*X(145)-JVS(1455)*X(146)-JVS(1456)*X(149)-JVS(1457)*X(150)&
             &-JVS(1458)*X(151)-JVS(1459)*X(153)
  X(157) = X(157)-JVS(1475)*X(26)-JVS(1476)*X(27)-JVS(1477)*X(28)-JVS(1478)*X(29)-JVS(1479)*X(30)-JVS(1480)*X(31)&
             &-JVS(1481)*X(37)-JVS(1482)*X(48)-JVS(1483)*X(54)-JVS(1484)*X(56)-JVS(1485)*X(57)-JVS(1486)*X(58)-JVS(1487)&
             &*X(59)-JVS(1488)*X(66)-JVS(1489)*X(101)-JVS(1490)*X(128)-JVS(1491)*X(138)-JVS(1492)*X(154)
  X(158) = X(158)-JVS(1508)*X(77)-JVS(1509)*X(99)-JVS(1510)*X(144)-JVS(1511)*X(145)-JVS(1512)*X(150)
  X(159) = X(159)-JVS(1525)*X(43)-JVS(1526)*X(61)-JVS(1527)*X(69)-JVS(1528)*X(75)-JVS(1529)*X(100)-JVS(1530)*X(121)&
             &-JVS(1531)*X(123)-JVS(1532)*X(124)-JVS(1533)*X(127)-JVS(1534)*X(133)-JVS(1535)*X(134)-JVS(1536)*X(136)&
             &-JVS(1537)*X(140)-JVS(1538)*X(141)-JVS(1539)*X(144)-JVS(1540)*X(148)-JVS(1541)*X(149)-JVS(1542)*X(151)&
             &-JVS(1543)*X(153)-JVS(1544)*X(155)-JVS(1545)*X(156)-JVS(1546)*X(158)
  X(160) = X(160)-JVS(1561)*X(77)-JVS(1562)*X(99)-JVS(1563)*X(111)-JVS(1564)*X(144)-JVS(1565)*X(145)
  X(161) = X(161)-JVS(1578)*X(41)-JVS(1579)*X(52)-JVS(1580)*X(72)-JVS(1581)*X(109)-JVS(1582)*X(111)-JVS(1583)*X(112)&
             &-JVS(1584)*X(115)-JVS(1585)*X(119)-JVS(1586)*X(124)-JVS(1587)*X(146)-JVS(1588)*X(150)-JVS(1589)*X(158)&
             &-JVS(1590)*X(160)
  X(162) = X(162)-JVS(1603)*X(39)-JVS(1604)*X(44)-JVS(1605)*X(64)-JVS(1606)*X(78)-JVS(1607)*X(79)-JVS(1608)*X(94)&
             &-JVS(1609)*X(99)-JVS(1610)*X(105)-JVS(1611)*X(113)-JVS(1612)*X(114)-JVS(1613)*X(115)-JVS(1614)*X(116)&
             &-JVS(1615)*X(117)-JVS(1616)*X(118)-JVS(1617)*X(121)-JVS(1618)*X(123)-JVS(1619)*X(125)-JVS(1620)*X(127)&
             &-JVS(1621)*X(129)-JVS(1622)*X(130)-JVS(1623)*X(131)-JVS(1624)*X(132)-JVS(1625)*X(133)-JVS(1626)*X(134)&
             &-JVS(1627)*X(135)-JVS(1628)*X(136)-JVS(1629)*X(140)-JVS(1630)*X(141)-JVS(1631)*X(142)-JVS(1632)*X(143)&
             &-JVS(1633)*X(144)-JVS(1634)*X(145)-JVS(1635)*X(146)-JVS(1636)*X(147)-JVS(1637)*X(148)-JVS(1638)*X(149)&
             &-JVS(1639)*X(150)-JVS(1640)*X(151)-JVS(1641)*X(152)-JVS(1642)*X(153)-JVS(1643)*X(155)-JVS(1644)*X(156)&
             &-JVS(1645)*X(158)-JVS(1646)*X(159)-JVS(1647)*X(160)-JVS(1648)*X(161)
  X(163) = X(163)-JVS(1661)*X(1)-JVS(1662)*X(20)-JVS(1663)*X(22)-JVS(1664)*X(47)-JVS(1665)*X(51)-JVS(1666)*X(52)&
             &-JVS(1667)*X(64)-JVS(1668)*X(67)-JVS(1669)*X(74)-JVS(1670)*X(75)-JVS(1671)*X(77)-JVS(1672)*X(78)-JVS(1673)&
             &*X(79)-JVS(1674)*X(84)-JVS(1675)*X(88)-JVS(1676)*X(93)-JVS(1677)*X(94)-JVS(1678)*X(97)-JVS(1679)*X(99)&
             &-JVS(1680)*X(100)-JVS(1681)*X(102)-JVS(1682)*X(103)-JVS(1683)*X(104)-JVS(1684)*X(105)-JVS(1685)*X(107)&
             &-JVS(1686)*X(108)-JVS(1687)*X(110)-JVS(1688)*X(113)-JVS(1689)*X(114)-JVS(1690)*X(116)-JVS(1691)*X(117)&
             &-JVS(1692)*X(119)-JVS(1693)*X(121)-JVS(1694)*X(122)-JVS(1695)*X(123)-JVS(1696)*X(125)-JVS(1697)*X(127)&
             &-JVS(1698)*X(129)-JVS(1699)*X(130)-JVS(1700)*X(131)-JVS(1701)*X(132)-JVS(1702)*X(133)-JVS(1703)*X(134)&
             &-JVS(1704)*X(135)-JVS(1705)*X(136)-JVS(1706)*X(139)-JVS(1707)*X(140)-JVS(1708)*X(141)-JVS(1709)*X(142)&
             &-JVS(1710)*X(143)-JVS(1711)*X(144)-JVS(1712)*X(145)-JVS(1713)*X(146)-JVS(1714)*X(148)-JVS(1715)*X(149)&
             &-JVS(1716)*X(150)-JVS(1717)*X(151)-JVS(1718)*X(152)-JVS(1719)*X(153)-JVS(1720)*X(155)-JVS(1721)*X(156)&
             &-JVS(1722)*X(157)-JVS(1723)*X(158)-JVS(1724)*X(159)-JVS(1725)*X(160)-JVS(1726)*X(161)-JVS(1727)*X(162)
  X(164) = X(164)-JVS(1744)*X(39)-JVS(1745)*X(44)-JVS(1746)*X(47)-JVS(1747)*X(52)-JVS(1748)*X(62)-JVS(1749)*X(63)&
             &-JVS(1750)*X(67)-JVS(1751)*X(99)-JVS(1752)*X(100)-JVS(1753)*X(102)-JVS(1754)*X(104)-JVS(1755)*X(107)-JVS(1756)&
             &*X(110)-JVS(1757)*X(113)-JVS(1758)*X(114)-JVS(1759)*X(115)-JVS(1760)*X(116)-JVS(1761)*X(117)-JVS(1762)*X(118)&
             &-JVS(1763)*X(120)-JVS(1764)*X(122)-JVS(1765)*X(123)-JVS(1766)*X(124)-JVS(1767)*X(125)-JVS(1768)*X(127)&
             &-JVS(1769)*X(129)-JVS(1770)*X(130)-JVS(1771)*X(131)-JVS(1772)*X(132)-JVS(1773)*X(133)-JVS(1774)*X(134)&
             &-JVS(1775)*X(135)-JVS(1776)*X(136)-JVS(1777)*X(140)-JVS(1778)*X(141)-JVS(1779)*X(142)-JVS(1780)*X(143)&
             &-JVS(1781)*X(144)-JVS(1782)*X(145)-JVS(1783)*X(146)-JVS(1784)*X(148)-JVS(1785)*X(149)-JVS(1786)*X(150)&
             &-JVS(1787)*X(151)-JVS(1788)*X(152)-JVS(1789)*X(153)-JVS(1790)*X(155)-JVS(1791)*X(156)-JVS(1792)*X(157)&
             &-JVS(1793)*X(158)-JVS(1794)*X(159)-JVS(1795)*X(160)-JVS(1796)*X(161)-JVS(1797)*X(162)
  X(165) = X(165)-JVS(1813)*X(23)-JVS(1814)*X(32)-JVS(1815)*X(33)-JVS(1816)*X(37)-JVS(1817)*X(45)-JVS(1818)*X(46)&
             &-JVS(1819)*X(60)-JVS(1820)*X(62)-JVS(1821)*X(70)-JVS(1822)*X(73)-JVS(1823)*X(81)-JVS(1824)*X(96)-JVS(1825)&
             &*X(106)-JVS(1826)*X(118)-JVS(1827)*X(128)-JVS(1828)*X(130)-JVS(1829)*X(131)-JVS(1830)*X(138)-JVS(1831)*X(151)&
             &-JVS(1832)*X(153)-JVS(1833)*X(154)-JVS(1834)*X(156)-JVS(1835)*X(157)-JVS(1836)*X(158)-JVS(1837)*X(159)&
             &-JVS(1838)*X(160)-JVS(1839)*X(161)-JVS(1840)*X(162)-JVS(1841)*X(163)-JVS(1842)*X(164)
  X(166) = X(166)-JVS(1857)*X(19)-JVS(1858)*X(53)-JVS(1859)*X(56)-JVS(1860)*X(57)-JVS(1861)*X(58)-JVS(1862)*X(59)&
             &-JVS(1863)*X(62)-JVS(1864)*X(63)-JVS(1865)*X(65)-JVS(1866)*X(67)-JVS(1867)*X(79)-JVS(1868)*X(81)-JVS(1869)&
             &*X(85)-JVS(1870)*X(89)-JVS(1871)*X(93)-JVS(1872)*X(96)-JVS(1873)*X(97)-JVS(1874)*X(98)-JVS(1875)*X(105)&
             &-JVS(1876)*X(106)-JVS(1877)*X(109)-JVS(1878)*X(110)-JVS(1879)*X(111)-JVS(1880)*X(112)-JVS(1881)*X(115)&
             &-JVS(1882)*X(118)-JVS(1883)*X(119)-JVS(1884)*X(120)-JVS(1885)*X(122)-JVS(1886)*X(123)-JVS(1887)*X(124)&
             &-JVS(1888)*X(125)-JVS(1889)*X(126)-JVS(1890)*X(127)-JVS(1891)*X(128)-JVS(1892)*X(129)-JVS(1893)*X(130)&
             &-JVS(1894)*X(131)-JVS(1895)*X(132)-JVS(1896)*X(133)-JVS(1897)*X(134)-JVS(1898)*X(135)-JVS(1899)*X(136)&
             &-JVS(1900)*X(137)-JVS(1901)*X(138)-JVS(1902)*X(139)-JVS(1903)*X(140)-JVS(1904)*X(141)-JVS(1905)*X(142)&
             &-JVS(1906)*X(143)-JVS(1907)*X(144)-JVS(1908)*X(145)-JVS(1909)*X(146)-JVS(1910)*X(147)-JVS(1911)*X(148)&
             &-JVS(1912)*X(149)-JVS(1913)*X(150)-JVS(1914)*X(151)-JVS(1915)*X(152)-JVS(1916)*X(153)-JVS(1917)*X(154)&
             &-JVS(1918)*X(155)-JVS(1919)*X(156)-JVS(1920)*X(157)-JVS(1921)*X(158)-JVS(1922)*X(159)-JVS(1923)*X(160)&
             &-JVS(1924)*X(161)-JVS(1925)*X(162)-JVS(1926)*X(163)-JVS(1927)*X(164)-JVS(1928)*X(165)
  X(167) = X(167)-JVS(1942)*X(35)-JVS(1943)*X(36)-JVS(1944)*X(40)-JVS(1945)*X(43)-JVS(1946)*X(47)-JVS(1947)*X(49)&
             &-JVS(1948)*X(50)-JVS(1949)*X(51)-JVS(1950)*X(61)-JVS(1951)*X(62)-JVS(1952)*X(63)-JVS(1953)*X(65)-JVS(1954)&
             &*X(67)-JVS(1955)*X(68)-JVS(1956)*X(69)-JVS(1957)*X(71)-JVS(1958)*X(75)-JVS(1959)*X(76)-JVS(1960)*X(77)&
             &-JVS(1961)*X(78)-JVS(1962)*X(80)-JVS(1963)*X(82)-JVS(1964)*X(83)-JVS(1965)*X(84)-JVS(1966)*X(86)-JVS(1967)&
             &*X(87)-JVS(1968)*X(88)-JVS(1969)*X(89)-JVS(1970)*X(90)-JVS(1971)*X(91)-JVS(1972)*X(92)-JVS(1973)*X(93)&
             &-JVS(1974)*X(95)-JVS(1975)*X(97)-JVS(1976)*X(98)-JVS(1977)*X(99)-JVS(1978)*X(100)-JVS(1979)*X(102)-JVS(1980)&
             &*X(103)-JVS(1981)*X(104)-JVS(1982)*X(105)-JVS(1983)*X(108)-JVS(1984)*X(110)-JVS(1985)*X(113)-JVS(1986)*X(114)&
             &-JVS(1987)*X(116)-JVS(1988)*X(117)-JVS(1989)*X(119)-JVS(1990)*X(121)-JVS(1991)*X(122)-JVS(1992)*X(123)&
             &-JVS(1993)*X(125)-JVS(1994)*X(126)-JVS(1995)*X(127)-JVS(1996)*X(129)-JVS(1997)*X(130)-JVS(1998)*X(131)&
             &-JVS(1999)*X(132)-JVS(2000)*X(133)-JVS(2001)*X(134)-JVS(2002)*X(135)-JVS(2003)*X(136)-JVS(2004)*X(139)&
             &-JVS(2005)*X(140)-JVS(2006)*X(141)-JVS(2007)*X(142)-JVS(2008)*X(143)-JVS(2009)*X(144)-JVS(2010)*X(145)&
             &-JVS(2011)*X(146)-JVS(2012)*X(147)-JVS(2013)*X(148)-JVS(2014)*X(149)-JVS(2015)*X(150)-JVS(2016)*X(151)&
             &-JVS(2017)*X(152)-JVS(2018)*X(153)-JVS(2019)*X(154)-JVS(2020)*X(155)-JVS(2021)*X(156)-JVS(2022)*X(157)&
             &-JVS(2023)*X(158)-JVS(2024)*X(159)-JVS(2025)*X(160)-JVS(2026)*X(161)-JVS(2027)*X(162)-JVS(2028)*X(163)&
             &-JVS(2029)*X(164)-JVS(2030)*X(165)-JVS(2031)*X(166)
  X(168) = X(168)-JVS(2044)*X(21)-JVS(2045)*X(23)-JVS(2046)*X(25)-JVS(2047)*X(38)-JVS(2048)*X(39)-JVS(2049)*X(47)&
             &-JVS(2050)*X(53)-JVS(2051)*X(55)-JVS(2052)*X(65)-JVS(2053)*X(71)-JVS(2054)*X(74)-JVS(2055)*X(85)-JVS(2056)&
             &*X(86)-JVS(2057)*X(87)-JVS(2058)*X(88)-JVS(2059)*X(91)-JVS(2060)*X(92)-JVS(2061)*X(93)-JVS(2062)*X(94)&
             &-JVS(2063)*X(96)-JVS(2064)*X(97)-JVS(2065)*X(102)-JVS(2066)*X(103)-JVS(2067)*X(104)-JVS(2068)*X(105)-JVS(2069)&
             &*X(107)-JVS(2070)*X(109)-JVS(2071)*X(111)-JVS(2072)*X(112)-JVS(2073)*X(113)-JVS(2074)*X(114)-JVS(2075)*X(115)&
             &-JVS(2076)*X(116)-JVS(2077)*X(117)-JVS(2078)*X(119)-JVS(2079)*X(121)-JVS(2080)*X(122)-JVS(2081)*X(123)&
             &-JVS(2082)*X(124)-JVS(2083)*X(125)-JVS(2084)*X(127)-JVS(2085)*X(128)-JVS(2086)*X(129)-JVS(2087)*X(130)&
             &-JVS(2088)*X(131)-JVS(2089)*X(132)-JVS(2090)*X(133)-JVS(2091)*X(134)-JVS(2092)*X(135)-JVS(2093)*X(136)&
             &-JVS(2094)*X(137)-JVS(2095)*X(139)-JVS(2096)*X(140)-JVS(2097)*X(141)-JVS(2098)*X(142)-JVS(2099)*X(143)&
             &-JVS(2100)*X(144)-JVS(2101)*X(145)-JVS(2102)*X(146)-JVS(2103)*X(147)-JVS(2104)*X(148)-JVS(2105)*X(149)&
             &-JVS(2106)*X(150)-JVS(2107)*X(151)-JVS(2108)*X(152)-JVS(2109)*X(153)-JVS(2110)*X(154)-JVS(2111)*X(155)&
             &-JVS(2112)*X(156)-JVS(2113)*X(157)-JVS(2114)*X(158)-JVS(2115)*X(159)-JVS(2116)*X(160)-JVS(2117)*X(161)&
             &-JVS(2118)*X(162)-JVS(2119)*X(163)-JVS(2120)*X(164)-JVS(2121)*X(165)-JVS(2122)*X(166)-JVS(2123)*X(167)
  X(169) = X(169)-JVS(2135)*X(26)-JVS(2136)*X(27)-JVS(2137)*X(28)-JVS(2138)*X(29)-JVS(2139)*X(30)-JVS(2140)*X(31)&
             &-JVS(2141)*X(32)-JVS(2142)*X(33)-JVS(2143)*X(37)-JVS(2144)*X(38)-JVS(2145)*X(41)-JVS(2146)*X(45)-JVS(2147)&
             &*X(46)-JVS(2148)*X(54)-JVS(2149)*X(56)-JVS(2150)*X(57)-JVS(2151)*X(58)-JVS(2152)*X(59)-JVS(2153)*X(98)&
             &-JVS(2154)*X(101)-JVS(2155)*X(106)-JVS(2156)*X(110)-JVS(2157)*X(126)-JVS(2158)*X(128)-JVS(2159)*X(138)&
             &-JVS(2160)*X(146)-JVS(2161)*X(150)-JVS(2162)*X(154)-JVS(2163)*X(157)-JVS(2164)*X(158)-JVS(2165)*X(159)&
             &-JVS(2166)*X(160)-JVS(2167)*X(161)-JVS(2168)*X(162)-JVS(2169)*X(163)-JVS(2170)*X(164)-JVS(2171)*X(165)&
             &-JVS(2172)*X(166)-JVS(2173)*X(167)-JVS(2174)*X(168)
  X(170) = X(170)-JVS(2185)*X(83)-JVS(2186)*X(88)-JVS(2187)*X(90)-JVS(2188)*X(94)-JVS(2189)*X(98)-JVS(2190)*X(99)&
             &-JVS(2191)*X(100)-JVS(2192)*X(103)-JVS(2193)*X(110)-JVS(2194)*X(121)-JVS(2195)*X(132)-JVS(2196)*X(134)&
             &-JVS(2197)*X(141)-JVS(2198)*X(143)-JVS(2199)*X(144)-JVS(2200)*X(145)-JVS(2201)*X(146)-JVS(2202)*X(155)&
             &-JVS(2203)*X(156)-JVS(2204)*X(158)-JVS(2205)*X(159)-JVS(2206)*X(160)-JVS(2207)*X(161)-JVS(2208)*X(162)&
             &-JVS(2209)*X(163)-JVS(2210)*X(164)-JVS(2211)*X(165)-JVS(2212)*X(166)-JVS(2213)*X(167)-JVS(2214)*X(168)&
             &-JVS(2215)*X(169)
  X(171) = X(171)-JVS(2225)*X(19)-JVS(2226)*X(26)-JVS(2227)*X(27)-JVS(2228)*X(28)-JVS(2229)*X(29)-JVS(2230)*X(30)&
             &-JVS(2231)*X(31)-JVS(2232)*X(37)-JVS(2233)*X(48)-JVS(2234)*X(55)-JVS(2235)*X(56)-JVS(2236)*X(57)-JVS(2237)&
             &*X(58)-JVS(2238)*X(59)-JVS(2239)*X(63)-JVS(2240)*X(66)-JVS(2241)*X(70)-JVS(2242)*X(85)-JVS(2243)*X(96)&
             &-JVS(2244)*X(101)-JVS(2245)*X(106)-JVS(2246)*X(110)-JVS(2247)*X(126)-JVS(2248)*X(128)-JVS(2249)*X(138)&
             &-JVS(2250)*X(146)-JVS(2251)*X(150)-JVS(2252)*X(154)-JVS(2253)*X(157)-JVS(2254)*X(158)-JVS(2255)*X(159)&
             &-JVS(2256)*X(160)-JVS(2257)*X(161)-JVS(2258)*X(162)-JVS(2259)*X(163)-JVS(2260)*X(164)-JVS(2261)*X(165)&
             &-JVS(2262)*X(166)-JVS(2263)*X(167)-JVS(2264)*X(168)-JVS(2265)*X(169)-JVS(2266)*X(170)
  X(172) = X(172)-JVS(2275)*X(39)-JVS(2276)*X(42)-JVS(2277)*X(47)-JVS(2278)*X(51)-JVS(2279)*X(52)-JVS(2280)*X(65)&
             &-JVS(2281)*X(81)-JVS(2282)*X(85)-JVS(2283)*X(90)-JVS(2284)*X(94)-JVS(2285)*X(96)-JVS(2286)*X(97)-JVS(2287)&
             &*X(99)-JVS(2288)*X(100)-JVS(2289)*X(104)-JVS(2290)*X(105)-JVS(2291)*X(108)-JVS(2292)*X(109)-JVS(2293)*X(111)&
             &-JVS(2294)*X(112)-JVS(2295)*X(115)-JVS(2296)*X(116)-JVS(2297)*X(117)-JVS(2298)*X(119)-JVS(2299)*X(121)&
             &-JVS(2300)*X(122)-JVS(2301)*X(124)-JVS(2302)*X(128)-JVS(2303)*X(129)-JVS(2304)*X(131)-JVS(2305)*X(132)&
             &-JVS(2306)*X(135)-JVS(2307)*X(137)-JVS(2308)*X(139)-JVS(2309)*X(141)-JVS(2310)*X(143)-JVS(2311)*X(144)&
             &-JVS(2312)*X(145)-JVS(2313)*X(146)-JVS(2314)*X(147)-JVS(2315)*X(148)-JVS(2316)*X(149)-JVS(2317)*X(150)&
             &-JVS(2318)*X(151)-JVS(2319)*X(152)-JVS(2320)*X(153)-JVS(2321)*X(154)-JVS(2322)*X(155)-JVS(2323)*X(156)&
             &-JVS(2324)*X(157)-JVS(2325)*X(158)-JVS(2326)*X(159)-JVS(2327)*X(160)-JVS(2328)*X(161)-JVS(2329)*X(162)&
             &-JVS(2330)*X(163)-JVS(2331)*X(164)-JVS(2332)*X(165)-JVS(2333)*X(166)-JVS(2334)*X(167)-JVS(2335)*X(168)&
             &-JVS(2336)*X(169)-JVS(2337)*X(170)-JVS(2338)*X(171)
  X(173) = X(173)-JVS(2346)*X(41)-JVS(2347)*X(60)-JVS(2348)*X(63)-JVS(2349)*X(80)-JVS(2350)*X(81)-JVS(2351)*X(82)&
             &-JVS(2352)*X(84)-JVS(2353)*X(90)-JVS(2354)*X(93)-JVS(2355)*X(94)-JVS(2356)*X(99)-JVS(2357)*X(100)-JVS(2358)&
             &*X(107)-JVS(2359)*X(108)-JVS(2360)*X(109)-JVS(2361)*X(111)-JVS(2362)*X(112)-JVS(2363)*X(115)-JVS(2364)*X(118)&
             &-JVS(2365)*X(121)-JVS(2366)*X(122)-JVS(2367)*X(124)-JVS(2368)*X(125)-JVS(2369)*X(127)-JVS(2370)*X(130)&
             &-JVS(2371)*X(131)-JVS(2372)*X(132)-JVS(2373)*X(135)-JVS(2374)*X(139)-JVS(2375)*X(141)-JVS(2376)*X(143)&
             &-JVS(2377)*X(144)-JVS(2378)*X(145)-JVS(2379)*X(146)-JVS(2380)*X(147)-JVS(2381)*X(148)-JVS(2382)*X(149)&
             &-JVS(2383)*X(150)-JVS(2384)*X(151)-JVS(2385)*X(152)-JVS(2386)*X(153)-JVS(2387)*X(155)-JVS(2388)*X(156)&
             &-JVS(2389)*X(158)-JVS(2390)*X(159)-JVS(2391)*X(160)-JVS(2392)*X(161)-JVS(2393)*X(162)-JVS(2394)*X(163)&
             &-JVS(2395)*X(164)-JVS(2396)*X(165)-JVS(2397)*X(166)-JVS(2398)*X(167)-JVS(2399)*X(168)-JVS(2400)*X(169)&
             &-JVS(2401)*X(170)-JVS(2402)*X(171)-JVS(2403)*X(172)
  X(174) = X(174)-JVS(2410)*X(26)-JVS(2411)*X(27)-JVS(2412)*X(28)-JVS(2413)*X(29)-JVS(2414)*X(30)-JVS(2415)*X(31)&
             &-JVS(2416)*X(32)-JVS(2417)*X(33)-JVS(2418)*X(34)-JVS(2419)*X(37)-JVS(2420)*X(38)-JVS(2421)*X(45)-JVS(2422)&
             &*X(46)-JVS(2423)*X(56)-JVS(2424)*X(57)-JVS(2425)*X(58)-JVS(2426)*X(59)-JVS(2427)*X(62)-JVS(2428)*X(101)&
             &-JVS(2429)*X(110)-JVS(2430)*X(128)-JVS(2431)*X(138)-JVS(2432)*X(154)-JVS(2433)*X(157)-JVS(2434)*X(159)&
             &-JVS(2435)*X(160)-JVS(2436)*X(161)-JVS(2437)*X(162)-JVS(2438)*X(164)-JVS(2439)*X(165)-JVS(2440)*X(166)&
             &-JVS(2441)*X(167)-JVS(2442)*X(168)-JVS(2443)*X(169)-JVS(2444)*X(170)-JVS(2445)*X(171)-JVS(2446)*X(172)&
             &-JVS(2447)*X(173)
  X(175) = X(175)-JVS(2453)*X(19)-JVS(2454)*X(24)-JVS(2455)*X(41)-JVS(2456)*X(42)-JVS(2457)*X(43)-JVS(2458)*X(44)&
             &-JVS(2459)*X(45)-JVS(2460)*X(46)-JVS(2461)*X(48)-JVS(2462)*X(49)-JVS(2463)*X(50)-JVS(2464)*X(52)-JVS(2465)&
             &*X(53)-JVS(2466)*X(54)-JVS(2467)*X(55)-JVS(2468)*X(56)-JVS(2469)*X(57)-JVS(2470)*X(58)-JVS(2471)*X(59)&
             &-JVS(2472)*X(60)-JVS(2473)*X(61)-JVS(2474)*X(62)-JVS(2475)*X(63)-JVS(2476)*X(64)-JVS(2477)*X(65)-JVS(2478)&
             &*X(67)-JVS(2479)*X(68)-JVS(2480)*X(69)-JVS(2481)*X(71)-JVS(2482)*X(72)-JVS(2483)*X(73)-JVS(2484)*X(74)&
             &-JVS(2485)*X(75)-JVS(2486)*X(76)-JVS(2487)*X(77)-JVS(2488)*X(78)-JVS(2489)*X(79)-JVS(2490)*X(80)-JVS(2491)&
             &*X(81)-JVS(2492)*X(82)-JVS(2493)*X(83)-JVS(2494)*X(84)-JVS(2495)*X(85)-JVS(2496)*X(86)-JVS(2497)*X(87)&
             &-JVS(2498)*X(88)-JVS(2499)*X(89)-JVS(2500)*X(90)-JVS(2501)*X(91)-JVS(2502)*X(92)-JVS(2503)*X(93)-JVS(2504)&
             &*X(94)-JVS(2505)*X(95)-JVS(2506)*X(96)-JVS(2507)*X(97)-JVS(2508)*X(98)-JVS(2509)*X(99)-JVS(2510)*X(100)&
             &-JVS(2511)*X(101)-JVS(2512)*X(102)-JVS(2513)*X(103)-JVS(2514)*X(104)-JVS(2515)*X(105)-JVS(2516)*X(106)&
             &-JVS(2517)*X(107)-JVS(2518)*X(108)-JVS(2519)*X(109)-JVS(2520)*X(110)-JVS(2521)*X(111)-JVS(2522)*X(112)&
             &-JVS(2523)*X(113)-JVS(2524)*X(114)-JVS(2525)*X(115)-JVS(2526)*X(117)-JVS(2527)*X(118)-JVS(2528)*X(119)&
             &-JVS(2529)*X(120)-JVS(2530)*X(121)-JVS(2531)*X(122)-JVS(2532)*X(123)-JVS(2533)*X(124)-JVS(2534)*X(125)&
             &-JVS(2535)*X(126)-JVS(2536)*X(127)-JVS(2537)*X(128)-JVS(2538)*X(129)-JVS(2539)*X(130)-JVS(2540)*X(131)&
             &-JVS(2541)*X(132)-JVS(2542)*X(133)-JVS(2543)*X(134)-JVS(2544)*X(135)-JVS(2545)*X(136)-JVS(2546)*X(137)&
             &-JVS(2547)*X(138)-JVS(2548)*X(139)-JVS(2549)*X(140)-JVS(2550)*X(141)-JVS(2551)*X(142)-JVS(2552)*X(143)&
             &-JVS(2553)*X(144)-JVS(2554)*X(145)-JVS(2555)*X(146)-JVS(2556)*X(147)-JVS(2557)*X(148)-JVS(2558)*X(149)&
             &-JVS(2559)*X(150)-JVS(2560)*X(151)-JVS(2561)*X(152)-JVS(2562)*X(153)-JVS(2563)*X(154)-JVS(2564)*X(155)&
             &-JVS(2565)*X(156)-JVS(2566)*X(157)-JVS(2567)*X(158)-JVS(2568)*X(159)-JVS(2569)*X(160)-JVS(2570)*X(161)&
             &-JVS(2571)*X(162)-JVS(2572)*X(163)-JVS(2573)*X(164)-JVS(2574)*X(165)-JVS(2575)*X(166)-JVS(2576)*X(167)&
             &-JVS(2577)*X(168)-JVS(2578)*X(169)-JVS(2579)*X(170)-JVS(2580)*X(171)-JVS(2581)*X(172)-JVS(2582)*X(173)&
             &-JVS(2583)*X(174)
  X(176) = X(176)-JVS(2588)*X(63)-JVS(2589)*X(85)-JVS(2590)*X(96)-JVS(2591)*X(106)-JVS(2592)*X(110)-JVS(2593)*X(126)&
             &-JVS(2594)*X(128)-JVS(2595)*X(138)-JVS(2596)*X(146)-JVS(2597)*X(150)-JVS(2598)*X(154)-JVS(2599)*X(157)&
             &-JVS(2600)*X(158)-JVS(2601)*X(159)-JVS(2602)*X(160)-JVS(2603)*X(161)-JVS(2604)*X(162)-JVS(2605)*X(163)&
             &-JVS(2606)*X(164)-JVS(2607)*X(165)-JVS(2608)*X(166)-JVS(2609)*X(167)-JVS(2610)*X(168)-JVS(2611)*X(169)&
             &-JVS(2612)*X(170)-JVS(2613)*X(171)-JVS(2614)*X(172)-JVS(2615)*X(173)-JVS(2616)*X(174)-JVS(2617)*X(175)
  X(177) = X(177)-JVS(2621)*X(34)-JVS(2622)*X(35)-JVS(2623)*X(36)-JVS(2624)*X(38)-JVS(2625)*X(40)-JVS(2626)*X(51)&
             &-JVS(2627)*X(53)-JVS(2628)*X(91)-JVS(2629)*X(92)-JVS(2630)*X(93)-JVS(2631)*X(97)-JVS(2632)*X(102)-JVS(2633)&
             &*X(104)-JVS(2634)*X(109)-JVS(2635)*X(111)-JVS(2636)*X(112)-JVS(2637)*X(113)-JVS(2638)*X(114)-JVS(2639)*X(115)&
             &-JVS(2640)*X(116)-JVS(2641)*X(117)-JVS(2642)*X(119)-JVS(2643)*X(121)-JVS(2644)*X(122)-JVS(2645)*X(123)&
             &-JVS(2646)*X(124)-JVS(2647)*X(125)-JVS(2648)*X(127)-JVS(2649)*X(129)-JVS(2650)*X(130)-JVS(2651)*X(131)&
             &-JVS(2652)*X(132)-JVS(2653)*X(133)-JVS(2654)*X(134)-JVS(2655)*X(135)-JVS(2656)*X(136)-JVS(2657)*X(140)&
             &-JVS(2658)*X(141)-JVS(2659)*X(142)-JVS(2660)*X(143)-JVS(2661)*X(144)-JVS(2662)*X(145)-JVS(2663)*X(146)&
             &-JVS(2664)*X(148)-JVS(2665)*X(149)-JVS(2666)*X(150)-JVS(2667)*X(151)-JVS(2668)*X(153)-JVS(2669)*X(154)&
             &-JVS(2670)*X(155)-JVS(2671)*X(156)-JVS(2672)*X(157)-JVS(2673)*X(158)-JVS(2674)*X(160)-JVS(2675)*X(161)&
             &-JVS(2676)*X(162)-JVS(2677)*X(164)-JVS(2678)*X(165)-JVS(2679)*X(166)-JVS(2680)*X(167)-JVS(2681)*X(168)&
             &-JVS(2682)*X(169)-JVS(2683)*X(170)-JVS(2684)*X(171)-JVS(2685)*X(172)-JVS(2686)*X(173)-JVS(2687)*X(174)&
             &-JVS(2688)*X(175)-JVS(2689)*X(176)
  X(178) = X(178)-JVS(2692)*X(60)-JVS(2693)*X(81)-JVS(2694)*X(118)-JVS(2695)*X(128)-JVS(2696)*X(130)-JVS(2697)*X(131)&
             &-JVS(2698)*X(138)-JVS(2699)*X(151)-JVS(2700)*X(153)-JVS(2701)*X(154)-JVS(2702)*X(156)-JVS(2703)*X(157)&
             &-JVS(2704)*X(158)-JVS(2705)*X(159)-JVS(2706)*X(160)-JVS(2707)*X(161)-JVS(2708)*X(162)-JVS(2709)*X(163)&
             &-JVS(2710)*X(164)-JVS(2711)*X(165)-JVS(2712)*X(166)-JVS(2713)*X(167)-JVS(2714)*X(168)-JVS(2715)*X(169)&
             &-JVS(2716)*X(170)-JVS(2717)*X(171)-JVS(2718)*X(172)-JVS(2719)*X(173)-JVS(2720)*X(174)-JVS(2721)*X(175)&
             &-JVS(2722)*X(176)-JVS(2723)*X(177)
  X(178) = X(178)/JVS(2724)
  X(177) = (X(177)-JVS(2691)*X(178))/(JVS(2690))
  X(176) = (X(176)-JVS(2619)*X(177)-JVS(2620)*X(178))/(JVS(2618))
  X(175) = (X(175)-JVS(2585)*X(176)-JVS(2586)*X(177)-JVS(2587)*X(178))/(JVS(2584))
  X(174) = (X(174)-JVS(2449)*X(175)-JVS(2450)*X(176)-JVS(2451)*X(177)-JVS(2452)*X(178))/(JVS(2448))
  X(173) = (X(173)-JVS(2405)*X(174)-JVS(2406)*X(175)-JVS(2407)*X(176)-JVS(2408)*X(177)-JVS(2409)*X(178))/(JVS(2404))
  X(172) = (X(172)-JVS(2340)*X(173)-JVS(2341)*X(174)-JVS(2342)*X(175)-JVS(2343)*X(176)-JVS(2344)*X(177)-JVS(2345)&
             &*X(178))/(JVS(2339))
  X(171) = (X(171)-JVS(2268)*X(172)-JVS(2269)*X(173)-JVS(2270)*X(174)-JVS(2271)*X(175)-JVS(2272)*X(176)-JVS(2273)*X(177)&
             &-JVS(2274)*X(178))/(JVS(2267))
  X(170) = (X(170)-JVS(2217)*X(171)-JVS(2218)*X(172)-JVS(2219)*X(173)-JVS(2220)*X(174)-JVS(2221)*X(175)-JVS(2222)*X(176)&
             &-JVS(2223)*X(177)-JVS(2224)*X(178))/(JVS(2216))
  X(169) = (X(169)-JVS(2176)*X(170)-JVS(2177)*X(171)-JVS(2178)*X(172)-JVS(2179)*X(173)-JVS(2180)*X(174)-JVS(2181)*X(175)&
             &-JVS(2182)*X(176)-JVS(2183)*X(177)-JVS(2184)*X(178))/(JVS(2175))
  X(168) = (X(168)-JVS(2125)*X(169)-JVS(2126)*X(170)-JVS(2127)*X(171)-JVS(2128)*X(172)-JVS(2129)*X(173)-JVS(2130)*X(174)&
             &-JVS(2131)*X(175)-JVS(2132)*X(176)-JVS(2133)*X(177)-JVS(2134)*X(178))/(JVS(2124))
  X(167) = (X(167)-JVS(2033)*X(168)-JVS(2034)*X(169)-JVS(2035)*X(170)-JVS(2036)*X(171)-JVS(2037)*X(172)-JVS(2038)*X(173)&
             &-JVS(2039)*X(174)-JVS(2040)*X(175)-JVS(2041)*X(176)-JVS(2042)*X(177)-JVS(2043)*X(178))/(JVS(2032))
  X(166) = (X(166)-JVS(1930)*X(167)-JVS(1931)*X(168)-JVS(1932)*X(169)-JVS(1933)*X(170)-JVS(1934)*X(171)-JVS(1935)*X(172)&
             &-JVS(1936)*X(173)-JVS(1937)*X(174)-JVS(1938)*X(175)-JVS(1939)*X(176)-JVS(1940)*X(177)-JVS(1941)*X(178))&
             &/(JVS(1929))
  X(165) = (X(165)-JVS(1844)*X(166)-JVS(1845)*X(167)-JVS(1846)*X(168)-JVS(1847)*X(169)-JVS(1848)*X(170)-JVS(1849)*X(171)&
             &-JVS(1850)*X(172)-JVS(1851)*X(173)-JVS(1852)*X(174)-JVS(1853)*X(175)-JVS(1854)*X(176)-JVS(1855)*X(177)&
             &-JVS(1856)*X(178))/(JVS(1843))
  X(164) = (X(164)-JVS(1799)*X(165)-JVS(1800)*X(166)-JVS(1801)*X(167)-JVS(1802)*X(168)-JVS(1803)*X(169)-JVS(1804)*X(170)&
             &-JVS(1805)*X(171)-JVS(1806)*X(172)-JVS(1807)*X(173)-JVS(1808)*X(174)-JVS(1809)*X(175)-JVS(1810)*X(176)&
             &-JVS(1811)*X(177)-JVS(1812)*X(178))/(JVS(1798))
  X(163) = (X(163)-JVS(1729)*X(164)-JVS(1730)*X(165)-JVS(1731)*X(166)-JVS(1732)*X(167)-JVS(1733)*X(168)-JVS(1734)*X(169)&
             &-JVS(1735)*X(170)-JVS(1736)*X(171)-JVS(1737)*X(172)-JVS(1738)*X(173)-JVS(1739)*X(174)-JVS(1740)*X(175)&
             &-JVS(1741)*X(176)-JVS(1742)*X(177)-JVS(1743)*X(178))/(JVS(1728))
  X(162) = (X(162)-JVS(1650)*X(164)-JVS(1651)*X(165)-JVS(1652)*X(166)-JVS(1653)*X(167)-JVS(1654)*X(168)-JVS(1655)*X(169)&
             &-JVS(1656)*X(170)-JVS(1657)*X(172)-JVS(1658)*X(173)-JVS(1659)*X(175)-JVS(1660)*X(177))/(JVS(1649))
  X(161) = (X(161)-JVS(1592)*X(162)-JVS(1593)*X(164)-JVS(1594)*X(166)-JVS(1595)*X(167)-JVS(1596)*X(168)-JVS(1597)*X(169)&
             &-JVS(1598)*X(170)-JVS(1599)*X(172)-JVS(1600)*X(173)-JVS(1601)*X(175)-JVS(1602)*X(177))/(JVS(1591))
  X(160) = (X(160)-JVS(1567)*X(161)-JVS(1568)*X(162)-JVS(1569)*X(164)-JVS(1570)*X(166)-JVS(1571)*X(167)-JVS(1572)*X(168)&
             &-JVS(1573)*X(170)-JVS(1574)*X(172)-JVS(1575)*X(173)-JVS(1576)*X(175)-JVS(1577)*X(177))/(JVS(1566))
  X(159) = (X(159)-JVS(1548)*X(160)-JVS(1549)*X(161)-JVS(1550)*X(162)-JVS(1551)*X(164)-JVS(1552)*X(165)-JVS(1553)*X(166)&
             &-JVS(1554)*X(167)-JVS(1555)*X(168)-JVS(1556)*X(170)-JVS(1557)*X(172)-JVS(1558)*X(173)-JVS(1559)*X(175)&
             &-JVS(1560)*X(177))/(JVS(1547))
  X(158) = (X(158)-JVS(1514)*X(161)-JVS(1515)*X(162)-JVS(1516)*X(164)-JVS(1517)*X(166)-JVS(1518)*X(167)-JVS(1519)*X(168)&
             &-JVS(1520)*X(170)-JVS(1521)*X(172)-JVS(1522)*X(173)-JVS(1523)*X(175)-JVS(1524)*X(177))/(JVS(1513))
  X(157) = (X(157)-JVS(1494)*X(164)-JVS(1495)*X(165)-JVS(1496)*X(166)-JVS(1497)*X(167)-JVS(1498)*X(168)-JVS(1499)*X(169)&
             &-JVS(1500)*X(170)-JVS(1501)*X(171)-JVS(1502)*X(172)-JVS(1503)*X(174)-JVS(1504)*X(175)-JVS(1505)*X(176)&
             &-JVS(1506)*X(177)-JVS(1507)*X(178))/(JVS(1493))
  X(156) = (X(156)-JVS(1461)*X(158)-JVS(1462)*X(160)-JVS(1463)*X(161)-JVS(1464)*X(162)-JVS(1465)*X(164)-JVS(1466)*X(165)&
             &-JVS(1467)*X(166)-JVS(1468)*X(167)-JVS(1469)*X(168)-JVS(1470)*X(170)-JVS(1471)*X(172)-JVS(1472)*X(173)&
             &-JVS(1473)*X(175)-JVS(1474)*X(177))/(JVS(1460))
  X(155) = (X(155)-JVS(1419)*X(156)-JVS(1420)*X(158)-JVS(1421)*X(160)-JVS(1422)*X(161)-JVS(1423)*X(162)-JVS(1424)*X(164)&
             &-JVS(1425)*X(165)-JVS(1426)*X(166)-JVS(1427)*X(167)-JVS(1428)*X(168)-JVS(1429)*X(170)-JVS(1430)*X(172)&
             &-JVS(1431)*X(173)-JVS(1432)*X(175)-JVS(1433)*X(177))/(JVS(1418))
  X(154) = (X(154)-JVS(1369)*X(157)-JVS(1370)*X(165)-JVS(1371)*X(166)-JVS(1372)*X(167)-JVS(1373)*X(168)-JVS(1374)*X(169)&
             &-JVS(1375)*X(170)-JVS(1376)*X(172)-JVS(1377)*X(174)-JVS(1378)*X(175)-JVS(1379)*X(176)-JVS(1380)*X(177)&
             &-JVS(1381)*X(178))/(JVS(1368))
  X(153) = (X(153)-JVS(1349)*X(156)-JVS(1350)*X(158)-JVS(1351)*X(162)-JVS(1352)*X(164)-JVS(1353)*X(165)-JVS(1354)*X(167)&
             &-JVS(1355)*X(168)-JVS(1356)*X(170)-JVS(1357)*X(172)-JVS(1358)*X(175)-JVS(1359)*X(177))/(JVS(1348))
  X(152) = (X(152)-JVS(1319)*X(153)-JVS(1320)*X(156)-JVS(1321)*X(158)-JVS(1322)*X(160)-JVS(1323)*X(161)-JVS(1324)*X(162)&
             &-JVS(1325)*X(164)-JVS(1326)*X(165)-JVS(1327)*X(166)-JVS(1328)*X(167)-JVS(1329)*X(168)-JVS(1330)*X(170)&
             &-JVS(1331)*X(172)-JVS(1332)*X(173)-JVS(1333)*X(175)-JVS(1334)*X(177))/(JVS(1318))
  X(151) = (X(151)-JVS(1283)*X(153)-JVS(1284)*X(158)-JVS(1285)*X(162)-JVS(1286)*X(164)-JVS(1287)*X(167)-JVS(1288)*X(170)&
             &-JVS(1289)*X(172)-JVS(1290)*X(175)-JVS(1291)*X(177))/(JVS(1282))
  X(150) = (X(150)-JVS(1264)*X(161)-JVS(1265)*X(166)-JVS(1266)*X(168)-JVS(1267)*X(170)-JVS(1268)*X(172)-JVS(1269)*X(173)&
             &-JVS(1270)*X(175)-JVS(1271)*X(177))/(JVS(1263))
  X(149) = (X(149)-JVS(1254)*X(158)-JVS(1255)*X(162)-JVS(1256)*X(164)-JVS(1257)*X(167)-JVS(1258)*X(170)-JVS(1259)*X(172)&
             &-JVS(1260)*X(175)-JVS(1261)*X(177))/(JVS(1253))
  X(148) = (X(148)-JVS(1238)*X(149)-JVS(1239)*X(158)-JVS(1240)*X(162)-JVS(1241)*X(164)-JVS(1242)*X(167)-JVS(1243)*X(170)&
             &-JVS(1244)*X(172)-JVS(1245)*X(175)-JVS(1246)*X(177))/(JVS(1237))
  X(147) = (X(147)-JVS(1212)*X(148)-JVS(1213)*X(149)-JVS(1214)*X(150)-JVS(1215)*X(151)-JVS(1216)*X(152)-JVS(1217)*X(153)&
             &-JVS(1218)*X(156)-JVS(1219)*X(158)-JVS(1220)*X(160)-JVS(1221)*X(161)-JVS(1222)*X(162)-JVS(1223)*X(164)&
             &-JVS(1224)*X(165)-JVS(1225)*X(166)-JVS(1226)*X(167)-JVS(1227)*X(168)-JVS(1228)*X(170)-JVS(1229)*X(172)&
             &-JVS(1230)*X(173)-JVS(1231)*X(175)-JVS(1232)*X(177))/(JVS(1211))
  X(146) = (X(146)-JVS(1181)*X(162)-JVS(1182)*X(164)-JVS(1183)*X(167)-JVS(1184)*X(170)-JVS(1185)*X(172)-JVS(1186)*X(175)&
             &-JVS(1187)*X(177))/(JVS(1180))
  X(145) = (X(145)-JVS(1168)*X(162)-JVS(1169)*X(164)-JVS(1170)*X(167)-JVS(1171)*X(170)-JVS(1172)*X(172)-JVS(1173)*X(175)&
             &-JVS(1174)*X(177))/(JVS(1167))
  X(144) = (X(144)-JVS(1158)*X(162)-JVS(1159)*X(164)-JVS(1160)*X(167)-JVS(1161)*X(170)-JVS(1162)*X(172)-JVS(1163)*X(175)&
             &-JVS(1164)*X(177))/(JVS(1157))
  X(143) = (X(143)-JVS(1142)*X(144)-JVS(1143)*X(158)-JVS(1144)*X(162)-JVS(1145)*X(164)-JVS(1146)*X(167)-JVS(1147)*X(168)&
             &-JVS(1148)*X(170)-JVS(1149)*X(172)-JVS(1150)*X(175)-JVS(1151)*X(177))/(JVS(1141))
  X(142) = (X(142)-JVS(1126)*X(151)-JVS(1127)*X(153)-JVS(1128)*X(156)-JVS(1129)*X(162)-JVS(1130)*X(164)-JVS(1131)*X(165)&
             &-JVS(1132)*X(167)-JVS(1133)*X(170)-JVS(1134)*X(172)-JVS(1135)*X(175)-JVS(1136)*X(177))/(JVS(1125))
  X(141) = (X(141)-JVS(1113)*X(144)-JVS(1114)*X(162)-JVS(1115)*X(164)-JVS(1116)*X(170)-JVS(1117)*X(172)-JVS(1118)*X(175)&
             &-JVS(1119)*X(177))/(JVS(1112))
  X(140) = (X(140)-JVS(1102)*X(148)-JVS(1103)*X(149)-JVS(1104)*X(153)-JVS(1105)*X(158)-JVS(1106)*X(162)-JVS(1107)*X(164)&
             &-JVS(1108)*X(167)-JVS(1109)*X(172)-JVS(1110)*X(175)-JVS(1111)*X(177))/(JVS(1101))
  X(139) = (X(139)-JVS(1082)*X(144)-JVS(1083)*X(145)-JVS(1084)*X(146)-JVS(1085)*X(148)-JVS(1086)*X(149)-JVS(1087)*X(160)&
             &-JVS(1088)*X(161)-JVS(1089)*X(162)-JVS(1090)*X(164)-JVS(1091)*X(166)-JVS(1092)*X(167)-JVS(1093)*X(168)&
             &-JVS(1094)*X(170)-JVS(1095)*X(172)-JVS(1096)*X(173)-JVS(1097)*X(175)-JVS(1098)*X(177))/(JVS(1081))
  X(138) = (X(138)-JVS(1059)*X(154)-JVS(1060)*X(157)-JVS(1061)*X(164)-JVS(1062)*X(166)-JVS(1063)*X(167)-JVS(1064)*X(168)&
             &-JVS(1065)*X(169)-JVS(1066)*X(171)-JVS(1067)*X(172)-JVS(1068)*X(174)-JVS(1069)*X(175)-JVS(1070)*X(176)&
             &-JVS(1071)*X(178))/(JVS(1058))
  X(137) = (X(137)-JVS(1023)*X(139)-JVS(1024)*X(141)-JVS(1025)*X(143)-JVS(1026)*X(145)-JVS(1027)*X(146)-JVS(1028)*X(147)&
             &-JVS(1029)*X(148)-JVS(1030)*X(149)-JVS(1031)*X(154)-JVS(1032)*X(155)-JVS(1033)*X(156)-JVS(1034)*X(157)&
             &-JVS(1035)*X(158)-JVS(1036)*X(159)-JVS(1037)*X(162)-JVS(1038)*X(163)-JVS(1039)*X(164)-JVS(1040)*X(165)&
             &-JVS(1041)*X(166)-JVS(1042)*X(167)-JVS(1043)*X(168)-JVS(1044)*X(169)-JVS(1045)*X(170)-JVS(1046)*X(171)&
             &-JVS(1047)*X(172)-JVS(1048)*X(175)-JVS(1049)*X(176)-JVS(1050)*X(177)-JVS(1051)*X(178))/(JVS(1022))
  X(136) = (X(136)-JVS(1003)*X(156)-JVS(1004)*X(162)-JVS(1005)*X(164)-JVS(1006)*X(167)-JVS(1007)*X(170)-JVS(1008)*X(172)&
             &-JVS(1009)*X(175)-JVS(1010)*X(177))/(JVS(1002))
  X(135) = (X(135)-JVS(993)*X(150)-JVS(994)*X(158)-JVS(995)*X(162)-JVS(996)*X(164)-JVS(997)*X(166)-JVS(998)*X(167)&
             &-JVS(999)*X(175)-JVS(1000)*X(177))/(JVS(992))
  X(134) = (X(134)-JVS(980)*X(141)-JVS(981)*X(155)-JVS(982)*X(156)-JVS(983)*X(160)-JVS(984)*X(162)-JVS(985)*X(164)&
             &-JVS(986)*X(167)-JVS(987)*X(168)-JVS(988)*X(172)-JVS(989)*X(175)-JVS(990)*X(177))/(JVS(979))
  X(133) = (X(133)-JVS(964)*X(134)-JVS(965)*X(151)-JVS(966)*X(153)-JVS(967)*X(155)-JVS(968)*X(156)-JVS(969)*X(162)&
             &-JVS(970)*X(164)-JVS(971)*X(165)-JVS(972)*X(167)-JVS(973)*X(172)-JVS(974)*X(175)-JVS(975)*X(177))/(JVS(963))
  X(132) = (X(132)-JVS(955)*X(146)-JVS(956)*X(162)-JVS(957)*X(164)-JVS(958)*X(167)-JVS(959)*X(175)-JVS(960)*X(177))&
             &/(JVS(954))
  X(131) = (X(131)-JVS(946)*X(162)-JVS(947)*X(164)-JVS(948)*X(167)-JVS(949)*X(170)-JVS(950)*X(172)-JVS(951)*X(175)&
             &-JVS(952)*X(177))/(JVS(945))
  X(130) = (X(130)-JVS(935)*X(151)-JVS(936)*X(153)-JVS(937)*X(162)-JVS(938)*X(164)-JVS(939)*X(165)-JVS(940)*X(167)&
             &-JVS(941)*X(175)-JVS(942)*X(177))/(JVS(934))
  X(129) = (X(129)-JVS(924)*X(160)-JVS(925)*X(162)-JVS(926)*X(164)-JVS(927)*X(167)-JVS(928)*X(170)-JVS(929)*X(172)&
             &-JVS(930)*X(175)-JVS(931)*X(177))/(JVS(923))
  X(128) = (X(128)-JVS(913)*X(157)-JVS(914)*X(166)-JVS(915)*X(168)-JVS(916)*X(169)-JVS(917)*X(171)-JVS(918)*X(175)&
             &-JVS(919)*X(176)-JVS(920)*X(178))/(JVS(912))
  X(127) = (X(127)-JVS(904)*X(160)-JVS(905)*X(162)-JVS(906)*X(164)-JVS(907)*X(167)-JVS(908)*X(170)-JVS(909)*X(172)&
             &-JVS(910)*X(175)-JVS(911)*X(177))/(JVS(903))
  X(126) = (X(126)-JVS(886)*X(146)-JVS(887)*X(150)-JVS(888)*X(158)-JVS(889)*X(160)-JVS(890)*X(161)-JVS(891)*X(166)&
             &-JVS(892)*X(167)-JVS(893)*X(168)-JVS(894)*X(169)-JVS(895)*X(170)-JVS(896)*X(171)-JVS(897)*X(172)-JVS(898)&
             &*X(173)-JVS(899)*X(175)-JVS(900)*X(177))/(JVS(885))
  X(125) = (X(125)-JVS(872)*X(158)-JVS(873)*X(162)-JVS(874)*X(164)-JVS(875)*X(167)-JVS(876)*X(172)-JVS(877)*X(177))&
             &/(JVS(871))
  X(124) = (X(124)-JVS(862)*X(160)-JVS(863)*X(161)-JVS(864)*X(166)-JVS(865)*X(168)-JVS(866)*X(170)-JVS(867)*X(172)&
             &-JVS(868)*X(173)-JVS(869)*X(175)-JVS(870)*X(177))/(JVS(861))
  X(123) = (X(123)-JVS(852)*X(160)-JVS(853)*X(162)-JVS(854)*X(164)-JVS(855)*X(167)-JVS(856)*X(170)-JVS(857)*X(172)&
             &-JVS(858)*X(175)-JVS(859)*X(177))/(JVS(851))
  X(122) = (X(122)-JVS(841)*X(135)-JVS(842)*X(145)-JVS(843)*X(148)-JVS(844)*X(149)-JVS(845)*X(167)-JVS(846)*X(170)&
             &-JVS(847)*X(175)-JVS(848)*X(177))/(JVS(840))
  X(121) = (X(121)-JVS(833)*X(141)-JVS(834)*X(167)-JVS(835)*X(168)-JVS(836)*X(172)-JVS(837)*X(175)-JVS(838)*X(177))&
             &/(JVS(832))
  X(120) = (X(120)-JVS(805)*X(122)-JVS(806)*X(123)-JVS(807)*X(124)-JVS(808)*X(125)-JVS(809)*X(127)-JVS(810)*X(129)&
             &-JVS(811)*X(130)-JVS(812)*X(132)-JVS(813)*X(133)-JVS(814)*X(135)-JVS(815)*X(136)-JVS(816)*X(140)-JVS(817)&
             &*X(142)-JVS(818)*X(143)-JVS(819)*X(144)-JVS(820)*X(145)-JVS(821)*X(151)-JVS(822)*X(152)-JVS(823)*X(153)&
             &-JVS(824)*X(162)-JVS(825)*X(164)-JVS(826)*X(165)-JVS(827)*X(166)-JVS(828)*X(167)-JVS(829)*X(168)-JVS(830)&
             &*X(175)-JVS(831)*X(177))/(JVS(804))
  X(119) = (X(119)-JVS(792)*X(158)-JVS(793)*X(160)-JVS(794)*X(161)-JVS(795)*X(166)-JVS(796)*X(168)-JVS(797)*X(170)&
             &-JVS(798)*X(172)-JVS(799)*X(175)-JVS(800)*X(177))/(JVS(791))
  X(118) = (X(118)-JVS(779)*X(130)-JVS(780)*X(131)-JVS(781)*X(151)-JVS(782)*X(153)-JVS(783)*X(162)-JVS(784)*X(164)&
             &-JVS(785)*X(165)-JVS(786)*X(167)-JVS(787)*X(175)-JVS(788)*X(177))/(JVS(778))
  X(117) = (X(117)-JVS(770)*X(162)-JVS(771)*X(164)-JVS(772)*X(167)-JVS(773)*X(170)-JVS(774)*X(172)-JVS(775)*X(175)&
             &-JVS(776)*X(177))/(JVS(769))
  X(116) = (X(116)-JVS(759)*X(117)-JVS(760)*X(162)-JVS(761)*X(164)-JVS(762)*X(167)-JVS(763)*X(170)-JVS(764)*X(172)&
             &-JVS(765)*X(175)-JVS(766)*X(177))/(JVS(758))
  X(115) = (X(115)-JVS(750)*X(160)-JVS(751)*X(161)-JVS(752)*X(166)-JVS(753)*X(168)-JVS(754)*X(170)-JVS(755)*X(173)&
             &-JVS(756)*X(177))/(JVS(749))
  X(114) = (X(114)-JVS(741)*X(151)-JVS(742)*X(153)-JVS(743)*X(162)-JVS(744)*X(164)-JVS(745)*X(165)-JVS(746)*X(167)&
             &-JVS(747)*X(175)-JVS(748)*X(177))/(JVS(740))
  X(113) = (X(113)-JVS(732)*X(143)-JVS(733)*X(162)-JVS(734)*X(164)-JVS(735)*X(167)-JVS(736)*X(175)-JVS(737)*X(177))&
             &/(JVS(731))
  X(112) = (X(112)-JVS(722)*X(146)-JVS(723)*X(158)-JVS(724)*X(161)-JVS(725)*X(166)-JVS(726)*X(168)-JVS(727)*X(170)&
             &-JVS(728)*X(173)-JVS(729)*X(177))/(JVS(721))
  X(111) = (X(111)-JVS(713)*X(161)-JVS(714)*X(166)-JVS(715)*X(168)-JVS(716)*X(170)-JVS(717)*X(172)-JVS(718)*X(173)&
             &-JVS(719)*X(175)-JVS(720)*X(177))/(JVS(712))
  X(110) = (X(110)-JVS(704)*X(159)-JVS(705)*X(160)-JVS(706)*X(170)-JVS(707)*X(171)-JVS(708)*X(172)-JVS(709)*X(174)&
             &-JVS(710)*X(175))/(JVS(703))
  X(109) = (X(109)-JVS(695)*X(146)-JVS(696)*X(161)-JVS(697)*X(166)-JVS(698)*X(168)-JVS(699)*X(170)-JVS(700)*X(173)&
             &-JVS(701)*X(177))/(JVS(694))
  X(108) = (X(108)-JVS(683)*X(132)-JVS(684)*X(139)-JVS(685)*X(141)-JVS(686)*X(145)-JVS(687)*X(162)-JVS(688)*X(164)&
             &-JVS(689)*X(167)-JVS(690)*X(170)-JVS(691)*X(172)-JVS(692)*X(175)-JVS(693)*X(177))/(JVS(682))
  X(107) = (X(107)-JVS(664)*X(125)-JVS(665)*X(127)-JVS(666)*X(144)-JVS(667)*X(145)-JVS(668)*X(149)-JVS(669)*X(162)&
             &-JVS(670)*X(164)-JVS(671)*X(167)-JVS(672)*X(170)-JVS(673)*X(175)-JVS(674)*X(177))/(JVS(663))
  X(106) = (X(106)-JVS(652)*X(154)-JVS(653)*X(165)-JVS(654)*X(166)-JVS(655)*X(167)-JVS(656)*X(168)-JVS(657)*X(169)&
             &-JVS(658)*X(175)-JVS(659)*X(176)-JVS(660)*X(178))/(JVS(651))
  X(105) = (X(105)-JVS(642)*X(129)-JVS(643)*X(145)-JVS(644)*X(148)-JVS(645)*X(167)-JVS(646)*X(170)-JVS(647)*X(175)&
             &-JVS(648)*X(177))/(JVS(641))
  X(104) = (X(104)-JVS(635)*X(141)-JVS(636)*X(164)-JVS(637)*X(167)-JVS(638)*X(172)-JVS(639)*X(177))/(JVS(634))
  X(103) = (X(103)-JVS(628)*X(144)-JVS(629)*X(145)-JVS(630)*X(164)-JVS(631)*X(170)-JVS(632)*X(175)-JVS(633)*X(177))&
             &/(JVS(627))
  X(102) = (X(102)-JVS(622)*X(141)-JVS(623)*X(164)-JVS(624)*X(167)-JVS(625)*X(175)-JVS(626)*X(177))/(JVS(621))
  X(101) = (X(101)-JVS(612)*X(128)-JVS(613)*X(138)-JVS(614)*X(154)-JVS(615)*X(157)-JVS(616)*X(164)-JVS(617)*X(171)&
             &-JVS(618)*X(174)-JVS(619)*X(175)-JVS(620)*X(176))/(JVS(611))
  X(100) = (X(100)-JVS(606)*X(160)-JVS(607)*X(170)-JVS(608)*X(172)-JVS(609)*X(175))/(JVS(605))
  X(99) = (X(99)-JVS(601)*X(170)-JVS(602)*X(172)-JVS(603)*X(175))/(JVS(600))
  X(98) = (X(98)-JVS(590)*X(110)-JVS(591)*X(163)-JVS(592)*X(167)-JVS(593)*X(169)-JVS(594)*X(170)-JVS(595)*X(171)&
            &-JVS(596)*X(174)-JVS(597)*X(175)-JVS(598)*X(176)-JVS(599)*X(178))/(JVS(589))
  X(97) = (X(97)-JVS(584)*X(122)-JVS(585)*X(167)-JVS(586)*X(168)-JVS(587)*X(175)-JVS(588)*X(177))/(JVS(583))
  X(96) = (X(96)-JVS(577)*X(154)-JVS(578)*X(165)-JVS(579)*X(166)-JVS(580)*X(168)-JVS(581)*X(176))/(JVS(576))
  X(95) = (X(95)-JVS(560)*X(113)-JVS(561)*X(114)-JVS(562)*X(117)-JVS(563)*X(123)-JVS(564)*X(127)-JVS(565)*X(129)&
            &-JVS(566)*X(130)-JVS(567)*X(131)-JVS(568)*X(132)-JVS(569)*X(135)-JVS(570)*X(136)-JVS(571)*X(140)-JVS(572)&
            &*X(145)-JVS(573)*X(151)-JVS(574)*X(164)-JVS(575)*X(175))/(JVS(559))
  X(94) = (X(94)-JVS(554)*X(121)-JVS(555)*X(143)-JVS(556)*X(168)-JVS(557)*X(170)-JVS(558)*X(175))/(JVS(553))
  X(93) = (X(93)-JVS(549)*X(145)-JVS(550)*X(167)-JVS(551)*X(175)-JVS(552)*X(177))/(JVS(548))
  X(92) = (X(92)-JVS(542)*X(145)-JVS(543)*X(162)-JVS(544)*X(167)-JVS(545)*X(177))/(JVS(541))
  X(91) = (X(91)-JVS(535)*X(132)-JVS(536)*X(162)-JVS(537)*X(167)-JVS(538)*X(170)-JVS(539)*X(175)-JVS(540)*X(177))&
            &/(JVS(534))
  X(90) = (X(90)-JVS(530)*X(170)-JVS(531)*X(172)-JVS(532)*X(175))/(JVS(529))
  X(89) = (X(89)-JVS(517)*X(93)-JVS(518)*X(97)-JVS(519)*X(105)-JVS(520)*X(119)-JVS(521)*X(131)-JVS(522)*X(139)-JVS(523)&
            &*X(149)-JVS(524)*X(152)-JVS(525)*X(166)-JVS(526)*X(167)-JVS(527)*X(175)-JVS(528)*X(177))/(JVS(516))
  X(88) = (X(88)-JVS(512)*X(145)-JVS(513)*X(170)-JVS(514)*X(175)-JVS(515)*X(177))/(JVS(511))
  X(87) = (X(87)-JVS(506)*X(102)-JVS(507)*X(104)-JVS(508)*X(144)-JVS(509)*X(167)-JVS(510)*X(175))/(JVS(505))
  X(86) = (X(86)-JVS(500)*X(125)-JVS(501)*X(148)-JVS(502)*X(149)-JVS(503)*X(167)-JVS(504)*X(175))/(JVS(499))
  X(85) = (X(85)-JVS(495)*X(166)-JVS(496)*X(168)-JVS(497)*X(172)-JVS(498)*X(176))/(JVS(494))
  X(84) = (X(84)-JVS(489)*X(135)-JVS(490)*X(150)-JVS(491)*X(166)-JVS(492)*X(167)-JVS(493)*X(175))/(JVS(488))
  X(83) = (X(83)-JVS(483)*X(132)-JVS(484)*X(162)-JVS(485)*X(170)-JVS(486)*X(175)-JVS(487)*X(177))/(JVS(482))
  X(82) = (X(82)-JVS(477)*X(132)-JVS(478)*X(162)-JVS(479)*X(167)-JVS(480)*X(175)-JVS(481)*X(177))/(JVS(476))
  X(81) = (X(81)-JVS(472)*X(165)-JVS(473)*X(172)-JVS(474)*X(175))/(JVS(471))
  X(80) = (X(80)-JVS(468)*X(132)-JVS(469)*X(167)-JVS(470)*X(175))/(JVS(467))
  X(79) = (X(79)-JVS(463)*X(136)-JVS(464)*X(142)-JVS(465)*X(167)-JVS(466)*X(175))/(JVS(462))
  X(78) = (X(78)-JVS(459)*X(129)-JVS(460)*X(167)-JVS(461)*X(175))/(JVS(458))
  X(77) = (X(77)-JVS(455)*X(145)-JVS(456)*X(167)-JVS(457)*X(175))/(JVS(454))
  X(76) = (X(76)-JVS(449)*X(91)-JVS(450)*X(92)-JVS(451)*X(151)-JVS(452)*X(167)-JVS(453)*X(175))/(JVS(448))
  X(75) = (X(75)-JVS(445)*X(123)-JVS(446)*X(167)-JVS(447)*X(175))/(JVS(444))
  X(74) = (X(74)-JVS(438)*X(103)-JVS(439)*X(149)-JVS(440)*X(167)-JVS(441)*X(170)-JVS(442)*X(175)-JVS(443)*X(177))&
            &/(JVS(437))
  X(73) = (X(73)-JVS(431)*X(96)-JVS(432)*X(106)-JVS(433)*X(154)-JVS(434)*X(165)-JVS(435)*X(175)-JVS(436)*X(178))&
            &/(JVS(430))
  X(72) = (X(72)-JVS(421)*X(109)-JVS(422)*X(111)-JVS(423)*X(112)-JVS(424)*X(115)-JVS(425)*X(119)-JVS(426)*X(124)&
            &-JVS(427)*X(150)-JVS(428)*X(161)-JVS(429)*X(175))/(JVS(420))
  X(71) = (X(71)-JVS(417)*X(127)-JVS(418)*X(167)-JVS(419)*X(175))/(JVS(416))
  X(70) = (X(70)-JVS(408)*X(96)-JVS(409)*X(106)-JVS(410)*X(128)-JVS(411)*X(138)-JVS(412)*X(154)-JVS(413)*X(157)-JVS(414)&
            &*X(176)-JVS(415)*X(178))/(JVS(407))
  X(69) = (X(69)-JVS(403)*X(121)-JVS(404)*X(134)-JVS(405)*X(167)-JVS(406)*X(175))/(JVS(402))
  X(68) = (X(68)-JVS(399)*X(131)-JVS(400)*X(167)-JVS(401)*X(175))/(JVS(398))
  X(67) = (X(67)-JVS(395)*X(164)-JVS(396)*X(167)-JVS(397)*X(175))/(JVS(394))
  X(66) = (X(66)-JVS(389)*X(154)-JVS(390)*X(157)-JVS(391)*X(164)-JVS(392)*X(171)-JVS(393)*X(175))/(JVS(388))
  X(65) = (X(65)-JVS(384)*X(167)-JVS(385)*X(168)-JVS(386)*X(175))/(JVS(383))
  X(64) = (X(64)-JVS(380)*X(143)-JVS(381)*X(167)-JVS(382)*X(175))/(JVS(379))
  X(63) = (X(63)-JVS(377)*X(171)-JVS(378)*X(175))/(JVS(376))
  X(62) = (X(62)-JVS(374)*X(174)-JVS(375)*X(175))/(JVS(373))
  X(61) = (X(61)-JVS(370)*X(133)-JVS(371)*X(167)-JVS(372)*X(175))/(JVS(369))
  X(60) = (X(60)-JVS(367)*X(165)-JVS(368)*X(175))/(JVS(366))
  X(59) = (X(59)-JVS(364)*X(174)-JVS(365)*X(175))/(JVS(363))
  X(58) = (X(58)-JVS(361)*X(174)-JVS(362)*X(175))/(JVS(360))
  X(57) = (X(57)-JVS(358)*X(174)-JVS(359)*X(175))/(JVS(357))
  X(56) = (X(56)-JVS(355)*X(174)-JVS(356)*X(175))/(JVS(354))
  X(55) = (X(55)-JVS(351)*X(85)-JVS(352)*X(175)-JVS(353)*X(176))/(JVS(350))
  X(54) = (X(54)-JVS(347)*X(154)-JVS(348)*X(157)-JVS(349)*X(175))/(JVS(346))
  X(53) = (X(53)-JVS(343)*X(168)-JVS(344)*X(175)-JVS(345)*X(177))/(JVS(342))
  X(52) = (X(52)-JVS(340)*X(172)-JVS(341)*X(175))/(JVS(339))
  X(51) = (X(51)-JVS(337)*X(172)-JVS(338)*X(175))/(JVS(336))
  X(50) = (X(50)-JVS(333)*X(130)-JVS(334)*X(167)-JVS(335)*X(175))/(JVS(332))
  X(49) = (X(49)-JVS(329)*X(114)-JVS(330)*X(167)-JVS(331)*X(175))/(JVS(328))
  X(48) = (X(48)-JVS(326)*X(157)-JVS(327)*X(175))/(JVS(325))
  X(47) = (X(47)-JVS(323)*X(164)-JVS(324)*X(168))/(JVS(322))
  X(46) = (X(46)-JVS(320)*X(174)-JVS(321)*X(175))/(JVS(319))
  X(45) = (X(45)-JVS(317)*X(174)-JVS(318)*X(175))/(JVS(316))
  X(44) = (X(44)-JVS(313)*X(162)-JVS(314)*X(167)-JVS(315)*X(175))/(JVS(312))
  X(43) = (X(43)-JVS(309)*X(133)-JVS(310)*X(164)-JVS(311)*X(175))/(JVS(308))
  X(42) = (X(42)-JVS(306)*X(172)-JVS(307)*X(175))/(JVS(305))
  X(41) = (X(41)-JVS(303)*X(169)-JVS(304)*X(175))/(JVS(302))
  X(40) = (X(40)-JVS(298)*X(51)-JVS(299)*X(167)-JVS(300)*X(175)-JVS(301)*X(177))/(JVS(297))
  X(39) = (X(39)-JVS(295)*X(162)-JVS(296)*X(168))/(JVS(294))
  X(38) = (X(38)-JVS(292)*X(168)-JVS(293)*X(177))/(JVS(291))
  X(37) = (X(37)-JVS(290)*X(174))/(JVS(289))
  X(36) = (X(36)-JVS(286)*X(167)-JVS(287)*X(175)-JVS(288)*X(177))/(JVS(285))
  X(35) = (X(35)-JVS(281)*X(167)-JVS(282)*X(175)-JVS(283)*X(177))/(JVS(280))
  X(34) = (X(34)-JVS(276)*X(38)-JVS(277)*X(168)-JVS(278)*X(174))/(JVS(275))
  X(33) = (X(33)-JVS(274)*X(174))/(JVS(273))
  X(32) = (X(32)-JVS(272)*X(174))/(JVS(271))
  X(31) = (X(31)-JVS(270)*X(174))/(JVS(269))
  X(30) = (X(30)-JVS(268)*X(174))/(JVS(267))
  X(29) = (X(29)-JVS(266)*X(174))/(JVS(265))
  X(28) = (X(28)-JVS(264)*X(174))/(JVS(263))
  X(27) = (X(27)-JVS(262)*X(174))/(JVS(261))
  X(26) = (X(26)-JVS(260)*X(174))/(JVS(259))
  X(25) = (X(25)-JVS(257)*X(97)-JVS(258)*X(168))/(JVS(256))
  X(24) = (X(24)-JVS(254)*X(77)-JVS(255)*X(175))/(JVS(253))
  X(23) = (X(23)-JVS(251)*X(165)-JVS(252)*X(168))/(JVS(250))
  X(22) = (X(22)-JVS(249)*X(175))/(JVS(248))
  X(21) = (X(21)-JVS(246)*X(134)-JVS(247)*X(168))/(JVS(245))
  X(20) = (X(20)-JVS(244)*X(175))/(JVS(243))
  X(19) = (X(19)-JVS(242)*X(175))/(JVS(241))
  X(18) = (X(18)-JVS(232)*X(109)-JVS(233)*X(111)-JVS(234)*X(112)-JVS(235)*X(115)-JVS(236)*X(119)-JVS(237)*X(124)&
            &-JVS(238)*X(150)-JVS(239)*X(161)-JVS(240)*X(175))/(JVS(231))
  X(17) = (X(17)-JVS(223)*X(109)-JVS(224)*X(111)-JVS(225)*X(112)-JVS(226)*X(115)-JVS(227)*X(124)-JVS(228)*X(150)&
            &-JVS(229)*X(173)-JVS(230)*X(175))/(JVS(222))
  X(16) = (X(16)-JVS(182)*X(41)-JVS(183)*X(60)-JVS(184)*X(63)-JVS(185)*X(80)-JVS(186)*X(81)-JVS(187)*X(82)-JVS(188)&
            &*X(84)-JVS(189)*X(90)-JVS(190)*X(93)-JVS(191)*X(94)-JVS(192)*X(99)-JVS(193)*X(100)-JVS(194)*X(107)-JVS(195)&
            &*X(108)-JVS(196)*X(118)-JVS(197)*X(121)-JVS(198)*X(122)-JVS(199)*X(125)-JVS(200)*X(132)-JVS(201)*X(135)&
            &-JVS(202)*X(139)-JVS(203)*X(143)-JVS(204)*X(146)-JVS(205)*X(147)-JVS(206)*X(152)-JVS(207)*X(155)-JVS(208)&
            &*X(158)-JVS(209)*X(159)-JVS(210)*X(160)-JVS(211)*X(162)-JVS(212)*X(163)-JVS(213)*X(164)-JVS(214)*X(165)&
            &-JVS(215)*X(167)-JVS(216)*X(169)-JVS(217)*X(170)-JVS(218)*X(171)-JVS(219)*X(172)-JVS(220)*X(175)-JVS(221)&
            &*X(177))/(JVS(181))
  X(15) = (X(15)-JVS(126)*X(34)-JVS(127)*X(41)-JVS(128)*X(42)-JVS(129)*X(48)-JVS(130)*X(51)-JVS(131)*X(52)-JVS(132)&
            &*X(54)-JVS(133)*X(56)-JVS(134)*X(62)-JVS(135)*X(81)-JVS(136)*X(83)-JVS(137)*X(85)-JVS(138)*X(86)-JVS(139)*X(88)&
            &-JVS(140)*X(90)-JVS(141)*X(96)-JVS(142)*X(97)-JVS(143)*X(98)-JVS(144)*X(99)-JVS(145)*X(100)-JVS(146)*X(102)&
            &-JVS(147)*X(103)-JVS(148)*X(106)-JVS(149)*X(108)-JVS(150)*X(110)-JVS(151)*X(116)-JVS(152)*X(121)-JVS(153)&
            &*X(126)-JVS(154)*X(128)-JVS(155)*X(131)-JVS(156)*X(138)-JVS(157)*X(141)-JVS(158)*X(144)-JVS(159)*X(146)&
            &-JVS(160)*X(147)-JVS(161)*X(154)-JVS(162)*X(155)-JVS(163)*X(156)-JVS(164)*X(157)-JVS(165)*X(158)-JVS(166)&
            &*X(159)-JVS(167)*X(160)-JVS(168)*X(163)-JVS(169)*X(164)-JVS(170)*X(166)-JVS(171)*X(167)-JVS(172)*X(168)&
            &-JVS(173)*X(169)-JVS(174)*X(170)-JVS(175)*X(172)-JVS(176)*X(174)-JVS(177)*X(175)-JVS(178)*X(176)-JVS(179)&
            &*X(177)-JVS(180)*X(178))/(JVS(125))
  X(14) = (X(14)-JVS(67)*X(25)-JVS(68)*X(34)-JVS(69)*X(38)-JVS(70)*X(39)-JVS(71)*X(47)-JVS(72)*X(53)-JVS(73)*X(55)&
            &-JVS(74)*X(65)-JVS(75)*X(66)-JVS(76)*X(73)-JVS(77)*X(91)-JVS(78)*X(92)-JVS(79)*X(93)-JVS(80)*X(97)-JVS(81)&
            &*X(98)-JVS(82)*X(101)-JVS(83)*X(104)-JVS(84)*X(105)-JVS(85)*X(109)-JVS(86)*X(111)-JVS(87)*X(112)-JVS(88)*X(113)&
            &-JVS(89)*X(114)-JVS(90)*X(115)-JVS(91)*X(116)-JVS(92)*X(117)-JVS(93)*X(119)-JVS(94)*X(121)-JVS(95)*X(123)&
            &-JVS(96)*X(124)-JVS(97)*X(125)-JVS(98)*X(127)-JVS(99)*X(128)-JVS(100)*X(129)-JVS(101)*X(130)-JVS(102)*X(131)&
            &-JVS(103)*X(132)-JVS(104)*X(133)-JVS(105)*X(134)-JVS(106)*X(135)-JVS(107)*X(136)-JVS(108)*X(137)-JVS(109)&
            &*X(140)-JVS(110)*X(142)-JVS(111)*X(143)-JVS(112)*X(144)-JVS(113)*X(145)-JVS(114)*X(148)-JVS(115)*X(149)&
            &-JVS(116)*X(150)-JVS(117)*X(151)-JVS(118)*X(162)-JVS(119)*X(164)-JVS(120)*X(167)-JVS(121)*X(168)-JVS(122)&
            &*X(171)-JVS(123)*X(175)-JVS(124)*X(177))/(JVS(66))
  X(13) = (X(13)-JVS(58)*X(116)-JVS(59)*X(117)-JVS(60)*X(131)-JVS(61)*X(162)-JVS(62)*X(164)-JVS(63)*X(167)-JVS(64)&
            &*X(172)-JVS(65)*X(177))/(JVS(57))
  X(12) = (X(12)-JVS(33)*X(41)-JVS(34)*X(51)-JVS(35)*X(74)-JVS(36)*X(83)-JVS(37)*X(84)-JVS(38)*X(89)-JVS(39)*X(91)&
            &-JVS(40)*X(93)-JVS(41)*X(97)-JVS(42)*X(113)-JVS(43)*X(120)-JVS(44)*X(125)-JVS(45)*X(139)-JVS(46)*X(143)-JVS(47)&
            &*X(145)-JVS(48)*X(152)-JVS(49)*X(162)-JVS(50)*X(164)-JVS(51)*X(167)-JVS(52)*X(170)-JVS(53)*X(172)-JVS(54)&
            &*X(173)-JVS(55)*X(175)-JVS(56)*X(177))/(JVS(32))
  X(11) = (X(11)-JVS(30)*X(105)-JVS(31)*X(175))/(JVS(29))
  X(10) = (X(10)-JVS(27)*X(40)-JVS(28)*X(177))/(JVS(26))
  X(9) = (X(9)-JVS(24)*X(40)-JVS(25)*X(167))/(JVS(23))
  X(8) = (X(8)-JVS(21)*X(36)-JVS(22)*X(177))/(JVS(20))
  X(7) = (X(7)-JVS(18)*X(36)-JVS(19)*X(167))/(JVS(17))
  X(6) = (X(6)-JVS(15)*X(35)-JVS(16)*X(177))/(JVS(14))
  X(5) = (X(5)-JVS(12)*X(35)-JVS(13)*X(167))/(JVS(11))
  X(4) = (X(4)-JVS(9)*X(99)-JVS(10)*X(172))/(JVS(8))
  X(3) = (X(3)-JVS(6)*X(99)-JVS(7)*X(175))/(JVS(5))
  X(2) = (X(2)-JVS(3)*X(52)-JVS(4)*X(175))/(JVS(2))
  X(1) = X(1)/JVS(1)
      
END SUBROUTINE KppSolve

! End of KppSolve function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolveTR - sparse, transposed back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
!      XX        - Vector for output variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolveTR ( JVS, X, XX )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)
! XX - Vector for output variables
  REAL(kind=dp) :: XX(NVAR)

  XX(1) = X(1)/JVS(1)
  XX(2) = X(2)/JVS(2)
  XX(3) = X(3)/JVS(5)
  XX(4) = X(4)/JVS(8)
  XX(5) = X(5)/JVS(11)
  XX(6) = X(6)/JVS(14)
  XX(7) = X(7)/JVS(17)
  XX(8) = X(8)/JVS(20)
  XX(9) = X(9)/JVS(23)
  XX(10) = X(10)/JVS(26)
  XX(11) = X(11)/JVS(29)
  XX(12) = X(12)/JVS(32)
  XX(13) = X(13)/JVS(57)
  XX(14) = X(14)/JVS(66)
  XX(15) = X(15)/JVS(125)
  XX(16) = X(16)/JVS(181)
  XX(17) = X(17)/JVS(222)
  XX(18) = X(18)/JVS(231)
  XX(19) = X(19)/JVS(241)
  XX(20) = X(20)/JVS(243)
  XX(21) = X(21)/JVS(245)
  XX(22) = X(22)/JVS(248)
  XX(23) = X(23)/JVS(250)
  XX(24) = X(24)/JVS(253)
  XX(25) = (X(25)-JVS(67)*XX(14))/(JVS(256))
  XX(26) = X(26)/JVS(259)
  XX(27) = X(27)/JVS(261)
  XX(28) = X(28)/JVS(263)
  XX(29) = X(29)/JVS(265)
  XX(30) = X(30)/JVS(267)
  XX(31) = X(31)/JVS(269)
  XX(32) = X(32)/JVS(271)
  XX(33) = X(33)/JVS(273)
  XX(34) = (X(34)-JVS(68)*XX(14)-JVS(126)*XX(15))/(JVS(275))
  XX(35) = (X(35)-JVS(12)*XX(5)-JVS(15)*XX(6))/(JVS(280))
  XX(36) = (X(36)-JVS(18)*XX(7)-JVS(21)*XX(8))/(JVS(285))
  XX(37) = X(37)/JVS(289)
  XX(38) = (X(38)-JVS(69)*XX(14)-JVS(276)*XX(34))/(JVS(291))
  XX(39) = (X(39)-JVS(70)*XX(14))/(JVS(294))
  XX(40) = (X(40)-JVS(24)*XX(9)-JVS(27)*XX(10))/(JVS(297))
  XX(41) = (X(41)-JVS(33)*XX(12)-JVS(127)*XX(15)-JVS(182)*XX(16))/(JVS(302))
  XX(42) = (X(42)-JVS(128)*XX(15))/(JVS(305))
  XX(43) = X(43)/JVS(308)
  XX(44) = X(44)/JVS(312)
  XX(45) = X(45)/JVS(316)
  XX(46) = X(46)/JVS(319)
  XX(47) = (X(47)-JVS(71)*XX(14))/(JVS(322))
  XX(48) = (X(48)-JVS(129)*XX(15))/(JVS(325))
  XX(49) = X(49)/JVS(328)
  XX(50) = X(50)/JVS(332)
  XX(51) = (X(51)-JVS(34)*XX(12)-JVS(130)*XX(15)-JVS(298)*XX(40))/(JVS(336))
  XX(52) = (X(52)-JVS(3)*XX(2)-JVS(131)*XX(15))/(JVS(339))
  XX(53) = (X(53)-JVS(72)*XX(14))/(JVS(342))
  XX(54) = (X(54)-JVS(132)*XX(15))/(JVS(346))
  XX(55) = (X(55)-JVS(73)*XX(14))/(JVS(350))
  XX(56) = (X(56)-JVS(133)*XX(15))/(JVS(354))
  XX(57) = X(57)/JVS(357)
  XX(58) = X(58)/JVS(360)
  XX(59) = X(59)/JVS(363)
  XX(60) = (X(60)-JVS(183)*XX(16))/(JVS(366))
  XX(61) = X(61)/JVS(369)
  XX(62) = (X(62)-JVS(134)*XX(15))/(JVS(373))
  XX(63) = (X(63)-JVS(184)*XX(16))/(JVS(376))
  XX(64) = X(64)/JVS(379)
  XX(65) = (X(65)-JVS(74)*XX(14))/(JVS(383))
  XX(66) = (X(66)-JVS(75)*XX(14))/(JVS(388))
  XX(67) = X(67)/JVS(394)
  XX(68) = X(68)/JVS(398)
  XX(69) = X(69)/JVS(402)
  XX(70) = X(70)/JVS(407)
  XX(71) = X(71)/JVS(416)
  XX(72) = X(72)/JVS(420)
  XX(73) = (X(73)-JVS(76)*XX(14))/(JVS(430))
  XX(74) = (X(74)-JVS(35)*XX(12))/(JVS(437))
  XX(75) = X(75)/JVS(444)
  XX(76) = X(76)/JVS(448)
  XX(77) = (X(77)-JVS(254)*XX(24))/(JVS(454))
  XX(78) = X(78)/JVS(458)
  XX(79) = X(79)/JVS(462)
  XX(80) = (X(80)-JVS(185)*XX(16))/(JVS(467))
  XX(81) = (X(81)-JVS(135)*XX(15)-JVS(186)*XX(16))/(JVS(471))
  XX(82) = (X(82)-JVS(187)*XX(16))/(JVS(476))
  XX(83) = (X(83)-JVS(36)*XX(12)-JVS(136)*XX(15))/(JVS(482))
  XX(84) = (X(84)-JVS(37)*XX(12)-JVS(188)*XX(16))/(JVS(488))
  XX(85) = (X(85)-JVS(137)*XX(15)-JVS(351)*XX(55))/(JVS(494))
  XX(86) = (X(86)-JVS(138)*XX(15))/(JVS(499))
  XX(87) = X(87)/JVS(505)
  XX(88) = (X(88)-JVS(139)*XX(15))/(JVS(511))
  XX(89) = (X(89)-JVS(38)*XX(12))/(JVS(516))
  XX(90) = (X(90)-JVS(140)*XX(15)-JVS(189)*XX(16))/(JVS(529))
  XX(91) = (X(91)-JVS(39)*XX(12)-JVS(77)*XX(14)-JVS(449)*XX(76))/(JVS(534))
  XX(92) = (X(92)-JVS(78)*XX(14)-JVS(450)*XX(76))/(JVS(541))
  XX(93) = (X(93)-JVS(40)*XX(12)-JVS(79)*XX(14)-JVS(190)*XX(16)-JVS(517)*XX(89))/(JVS(548))
  XX(94) = (X(94)-JVS(191)*XX(16))/(JVS(553))
  XX(95) = X(95)/JVS(559)
  XX(96) = (X(96)-JVS(141)*XX(15)-JVS(408)*XX(70)-JVS(431)*XX(73))/(JVS(576))
  XX(97) = (X(97)-JVS(41)*XX(12)-JVS(80)*XX(14)-JVS(142)*XX(15)-JVS(257)*XX(25)-JVS(518)*XX(89))/(JVS(583))
  XX(98) = (X(98)-JVS(81)*XX(14)-JVS(143)*XX(15))/(JVS(589))
  XX(99) = (X(99)-JVS(6)*XX(3)-JVS(9)*XX(4)-JVS(144)*XX(15)-JVS(192)*XX(16))/(JVS(600))
  XX(100) = (X(100)-JVS(145)*XX(15)-JVS(193)*XX(16))/(JVS(605))
  XX(101) = (X(101)-JVS(82)*XX(14))/(JVS(611))
  XX(102) = (X(102)-JVS(146)*XX(15)-JVS(506)*XX(87))/(JVS(621))
  XX(103) = (X(103)-JVS(147)*XX(15)-JVS(438)*XX(74))/(JVS(627))
  XX(104) = (X(104)-JVS(83)*XX(14)-JVS(507)*XX(87))/(JVS(634))
  XX(105) = (X(105)-JVS(30)*XX(11)-JVS(84)*XX(14)-JVS(519)*XX(89))/(JVS(641))
  XX(106) = (X(106)-JVS(148)*XX(15)-JVS(409)*XX(70)-JVS(432)*XX(73))/(JVS(651))
  XX(107) = (X(107)-JVS(194)*XX(16))/(JVS(663))
  XX(108) = (X(108)-JVS(149)*XX(15)-JVS(195)*XX(16))/(JVS(682))
  XX(109) = (X(109)-JVS(85)*XX(14)-JVS(223)*XX(17)-JVS(232)*XX(18)-JVS(421)*XX(72))/(JVS(694))
  XX(110) = (X(110)-JVS(150)*XX(15)-JVS(590)*XX(98))/(JVS(703))
  XX(111) = (X(111)-JVS(86)*XX(14)-JVS(224)*XX(17)-JVS(233)*XX(18)-JVS(422)*XX(72))/(JVS(712))
  XX(112) = (X(112)-JVS(87)*XX(14)-JVS(225)*XX(17)-JVS(234)*XX(18)-JVS(423)*XX(72))/(JVS(721))
  XX(113) = (X(113)-JVS(42)*XX(12)-JVS(88)*XX(14)-JVS(560)*XX(95))/(JVS(731))
  XX(114) = (X(114)-JVS(89)*XX(14)-JVS(329)*XX(49)-JVS(561)*XX(95))/(JVS(740))
  XX(115) = (X(115)-JVS(90)*XX(14)-JVS(226)*XX(17)-JVS(235)*XX(18)-JVS(424)*XX(72))/(JVS(749))
  XX(116) = (X(116)-JVS(58)*XX(13)-JVS(91)*XX(14)-JVS(151)*XX(15))/(JVS(758))
  XX(117) = (X(117)-JVS(59)*XX(13)-JVS(92)*XX(14)-JVS(562)*XX(95)-JVS(759)*XX(116))/(JVS(769))
  XX(118) = (X(118)-JVS(196)*XX(16))/(JVS(778))
  XX(119) = (X(119)-JVS(93)*XX(14)-JVS(236)*XX(18)-JVS(425)*XX(72)-JVS(520)*XX(89))/(JVS(791))
  XX(120) = (X(120)-JVS(43)*XX(12))/(JVS(804))
  XX(121) = (X(121)-JVS(94)*XX(14)-JVS(152)*XX(15)-JVS(197)*XX(16)-JVS(403)*XX(69)-JVS(554)*XX(94))/(JVS(832))
  XX(122) = (X(122)-JVS(198)*XX(16)-JVS(584)*XX(97)-JVS(805)*XX(120))/(JVS(840))
  XX(123) = (X(123)-JVS(95)*XX(14)-JVS(445)*XX(75)-JVS(563)*XX(95)-JVS(806)*XX(120))/(JVS(851))
  XX(124) = (X(124)-JVS(96)*XX(14)-JVS(227)*XX(17)-JVS(237)*XX(18)-JVS(426)*XX(72)-JVS(807)*XX(120))/(JVS(861))
  XX(125) = (X(125)-JVS(44)*XX(12)-JVS(97)*XX(14)-JVS(199)*XX(16)-JVS(500)*XX(86)-JVS(664)*XX(107)-JVS(808)*XX(120))&
              &/(JVS(871))
  XX(126) = (X(126)-JVS(153)*XX(15))/(JVS(885))
  XX(127) = (X(127)-JVS(98)*XX(14)-JVS(417)*XX(71)-JVS(564)*XX(95)-JVS(665)*XX(107)-JVS(809)*XX(120))/(JVS(903))
  XX(128) = (X(128)-JVS(99)*XX(14)-JVS(154)*XX(15)-JVS(410)*XX(70)-JVS(612)*XX(101))/(JVS(912))
  XX(129) = (X(129)-JVS(100)*XX(14)-JVS(459)*XX(78)-JVS(565)*XX(95)-JVS(642)*XX(105)-JVS(810)*XX(120))/(JVS(923))
  XX(130) = (X(130)-JVS(101)*XX(14)-JVS(333)*XX(50)-JVS(566)*XX(95)-JVS(779)*XX(118)-JVS(811)*XX(120))/(JVS(934))
  XX(131) = (X(131)-JVS(60)*XX(13)-JVS(102)*XX(14)-JVS(155)*XX(15)-JVS(399)*XX(68)-JVS(521)*XX(89)-JVS(567)*XX(95)&
              &-JVS(780)*XX(118))/(JVS(945))
  XX(132) = (X(132)-JVS(103)*XX(14)-JVS(200)*XX(16)-JVS(468)*XX(80)-JVS(477)*XX(82)-JVS(483)*XX(83)-JVS(535)*XX(91)&
              &-JVS(568)*XX(95)-JVS(683)*XX(108)-JVS(812)*XX(120))/(JVS(954))
  XX(133) = (X(133)-JVS(104)*XX(14)-JVS(309)*XX(43)-JVS(370)*XX(61)-JVS(813)*XX(120))/(JVS(963))
  XX(134) = (X(134)-JVS(105)*XX(14)-JVS(246)*XX(21)-JVS(404)*XX(69)-JVS(964)*XX(133))/(JVS(979))
  XX(135) = (X(135)-JVS(106)*XX(14)-JVS(201)*XX(16)-JVS(489)*XX(84)-JVS(569)*XX(95)-JVS(814)*XX(120)-JVS(841)*XX(122))&
              &/(JVS(992))
  XX(136) = (X(136)-JVS(107)*XX(14)-JVS(463)*XX(79)-JVS(570)*XX(95)-JVS(815)*XX(120))/(JVS(1002))
  XX(137) = (X(137)-JVS(108)*XX(14))/(JVS(1022))
  XX(138) = (X(138)-JVS(156)*XX(15)-JVS(411)*XX(70)-JVS(613)*XX(101))/(JVS(1058))
  XX(139) = (X(139)-JVS(45)*XX(12)-JVS(202)*XX(16)-JVS(522)*XX(89)-JVS(684)*XX(108)-JVS(1023)*XX(137))/(JVS(1081))
  XX(140) = (X(140)-JVS(109)*XX(14)-JVS(571)*XX(95)-JVS(816)*XX(120))/(JVS(1101))
  XX(141) = (X(141)-JVS(157)*XX(15)-JVS(622)*XX(102)-JVS(635)*XX(104)-JVS(685)*XX(108)-JVS(833)*XX(121)-JVS(980)*XX(134)&
              &-JVS(1024)*XX(137))/(JVS(1112))
  XX(142) = (X(142)-JVS(110)*XX(14)-JVS(464)*XX(79)-JVS(817)*XX(120))/(JVS(1125))
  XX(143) = (X(143)-JVS(46)*XX(12)-JVS(111)*XX(14)-JVS(203)*XX(16)-JVS(380)*XX(64)-JVS(555)*XX(94)-JVS(732)*XX(113)&
              &-JVS(818)*XX(120)-JVS(1025)*XX(137))/(JVS(1141))
  XX(144) = (X(144)-JVS(112)*XX(14)-JVS(158)*XX(15)-JVS(508)*XX(87)-JVS(628)*XX(103)-JVS(666)*XX(107)-JVS(819)*XX(120)&
              &-JVS(1082)*XX(139)-JVS(1113)*XX(141)-JVS(1142)*XX(143))/(JVS(1157))
  XX(145) = (X(145)-JVS(47)*XX(12)-JVS(113)*XX(14)-JVS(455)*XX(77)-JVS(512)*XX(88)-JVS(542)*XX(92)-JVS(549)*XX(93)&
              &-JVS(572)*XX(95)-JVS(629)*XX(103)-JVS(643)*XX(105)-JVS(667)*XX(107)-JVS(686)*XX(108)-JVS(820)*XX(120)&
              &-JVS(842)*XX(122)-JVS(1026)*XX(137)-JVS(1083)*XX(139))/(JVS(1167))
  XX(146) = (X(146)-JVS(159)*XX(15)-JVS(204)*XX(16)-JVS(695)*XX(109)-JVS(722)*XX(112)-JVS(886)*XX(126)-JVS(955)*XX(132)&
              &-JVS(1027)*XX(137)-JVS(1084)*XX(139))/(JVS(1180))
  XX(147) = (X(147)-JVS(160)*XX(15)-JVS(205)*XX(16)-JVS(1028)*XX(137))/(JVS(1211))
  XX(148) = (X(148)-JVS(114)*XX(14)-JVS(501)*XX(86)-JVS(644)*XX(105)-JVS(843)*XX(122)-JVS(1029)*XX(137)-JVS(1085)&
              &*XX(139)-JVS(1102)*XX(140)-JVS(1212)*XX(147))/(JVS(1237))
  XX(149) = (X(149)-JVS(115)*XX(14)-JVS(439)*XX(74)-JVS(502)*XX(86)-JVS(523)*XX(89)-JVS(668)*XX(107)-JVS(844)*XX(122)&
              &-JVS(1030)*XX(137)-JVS(1086)*XX(139)-JVS(1103)*XX(140)-JVS(1213)*XX(147)-JVS(1238)*XX(148))/(JVS(1253))
  XX(150) = (X(150)-JVS(116)*XX(14)-JVS(228)*XX(17)-JVS(238)*XX(18)-JVS(427)*XX(72)-JVS(490)*XX(84)-JVS(887)*XX(126)&
              &-JVS(993)*XX(135)-JVS(1214)*XX(147))/(JVS(1263))
  XX(151) = (X(151)-JVS(117)*XX(14)-JVS(451)*XX(76)-JVS(573)*XX(95)-JVS(741)*XX(114)-JVS(781)*XX(118)-JVS(821)*XX(120)&
              &-JVS(935)*XX(130)-JVS(965)*XX(133)-JVS(1126)*XX(142)-JVS(1215)*XX(147))/(JVS(1282))
  XX(152) = (X(152)-JVS(48)*XX(12)-JVS(206)*XX(16)-JVS(524)*XX(89)-JVS(822)*XX(120)-JVS(1216)*XX(147))/(JVS(1318))
  XX(153) = (X(153)-JVS(742)*XX(114)-JVS(782)*XX(118)-JVS(823)*XX(120)-JVS(936)*XX(130)-JVS(966)*XX(133)-JVS(1104)&
              &*XX(140)-JVS(1127)*XX(142)-JVS(1217)*XX(147)-JVS(1283)*XX(151)-JVS(1319)*XX(152))/(JVS(1348))
  XX(154) = (X(154)-JVS(161)*XX(15)-JVS(347)*XX(54)-JVS(389)*XX(66)-JVS(412)*XX(70)-JVS(433)*XX(73)-JVS(577)*XX(96)&
              &-JVS(614)*XX(101)-JVS(652)*XX(106)-JVS(1031)*XX(137)-JVS(1059)*XX(138))/(JVS(1368))
  XX(155) = (X(155)-JVS(162)*XX(15)-JVS(207)*XX(16)-JVS(967)*XX(133)-JVS(981)*XX(134)-JVS(1032)*XX(137))/(JVS(1418))
  XX(156) = (X(156)-JVS(163)*XX(15)-JVS(968)*XX(133)-JVS(982)*XX(134)-JVS(1003)*XX(136)-JVS(1033)*XX(137)-JVS(1128)&
              &*XX(142)-JVS(1218)*XX(147)-JVS(1320)*XX(152)-JVS(1349)*XX(153)-JVS(1419)*XX(155))/(JVS(1460))
  XX(157) = (X(157)-JVS(164)*XX(15)-JVS(326)*XX(48)-JVS(348)*XX(54)-JVS(390)*XX(66)-JVS(413)*XX(70)-JVS(615)*XX(101)&
              &-JVS(913)*XX(128)-JVS(1034)*XX(137)-JVS(1060)*XX(138)-JVS(1369)*XX(154))/(JVS(1493))
  XX(158) = (X(158)-JVS(165)*XX(15)-JVS(208)*XX(16)-JVS(723)*XX(112)-JVS(792)*XX(119)-JVS(872)*XX(125)-JVS(888)*XX(126)&
              &-JVS(994)*XX(135)-JVS(1035)*XX(137)-JVS(1105)*XX(140)-JVS(1143)*XX(143)-JVS(1219)*XX(147)-JVS(1239)*XX(148)&
              &-JVS(1254)*XX(149)-JVS(1284)*XX(151)-JVS(1321)*XX(152)-JVS(1350)*XX(153)-JVS(1420)*XX(155)-JVS(1461)*XX(156))&
              &/(JVS(1513))
  XX(159) = (X(159)-JVS(166)*XX(15)-JVS(209)*XX(16)-JVS(704)*XX(110)-JVS(1036)*XX(137))/(JVS(1547))
  XX(160) = (X(160)-JVS(167)*XX(15)-JVS(210)*XX(16)-JVS(606)*XX(100)-JVS(705)*XX(110)-JVS(750)*XX(115)-JVS(793)*XX(119)&
              &-JVS(852)*XX(123)-JVS(862)*XX(124)-JVS(889)*XX(126)-JVS(904)*XX(127)-JVS(924)*XX(129)-JVS(983)*XX(134)&
              &-JVS(1087)*XX(139)-JVS(1220)*XX(147)-JVS(1322)*XX(152)-JVS(1421)*XX(155)-JVS(1462)*XX(156)-JVS(1548)*XX(159))&
              &/(JVS(1566))
  XX(161) = (X(161)-JVS(239)*XX(18)-JVS(428)*XX(72)-JVS(696)*XX(109)-JVS(713)*XX(111)-JVS(724)*XX(112)-JVS(751)*XX(115)&
              &-JVS(794)*XX(119)-JVS(863)*XX(124)-JVS(890)*XX(126)-JVS(1088)*XX(139)-JVS(1221)*XX(147)-JVS(1264)*XX(150)&
              &-JVS(1323)*XX(152)-JVS(1422)*XX(155)-JVS(1463)*XX(156)-JVS(1514)*XX(158)-JVS(1549)*XX(159)-JVS(1567)*XX(160))&
              &/(JVS(1591))
  XX(162) = (X(162)-JVS(49)*XX(12)-JVS(61)*XX(13)-JVS(118)*XX(14)-JVS(211)*XX(16)-JVS(295)*XX(39)-JVS(313)*XX(44)&
              &-JVS(478)*XX(82)-JVS(484)*XX(83)-JVS(536)*XX(91)-JVS(543)*XX(92)-JVS(669)*XX(107)-JVS(687)*XX(108)-JVS(733)&
              &*XX(113)-JVS(743)*XX(114)-JVS(760)*XX(116)-JVS(770)*XX(117)-JVS(783)*XX(118)-JVS(824)*XX(120)-JVS(853)&
              &*XX(123)-JVS(873)*XX(125)-JVS(905)*XX(127)-JVS(925)*XX(129)-JVS(937)*XX(130)-JVS(946)*XX(131)-JVS(956)&
              &*XX(132)-JVS(969)*XX(133)-JVS(984)*XX(134)-JVS(995)*XX(135)-JVS(1004)*XX(136)-JVS(1037)*XX(137)-JVS(1089)&
              &*XX(139)-JVS(1106)*XX(140)-JVS(1114)*XX(141)-JVS(1129)*XX(142)-JVS(1144)*XX(143)-JVS(1158)*XX(144)-JVS(1168)&
              &*XX(145)-JVS(1181)*XX(146)-JVS(1222)*XX(147)-JVS(1240)*XX(148)-JVS(1255)*XX(149)-JVS(1285)*XX(151)-JVS(1324)&
              &*XX(152)-JVS(1351)*XX(153)-JVS(1423)*XX(155)-JVS(1464)*XX(156)-JVS(1515)*XX(158)-JVS(1550)*XX(159)-JVS(1568)&
              &*XX(160)-JVS(1592)*XX(161))/(JVS(1649))
  XX(163) = (X(163)-JVS(168)*XX(15)-JVS(212)*XX(16)-JVS(591)*XX(98)-JVS(1038)*XX(137))/(JVS(1728))
  XX(164) = (X(164)-JVS(50)*XX(12)-JVS(62)*XX(13)-JVS(119)*XX(14)-JVS(169)*XX(15)-JVS(213)*XX(16)-JVS(310)*XX(43)&
              &-JVS(323)*XX(47)-JVS(391)*XX(66)-JVS(395)*XX(67)-JVS(574)*XX(95)-JVS(616)*XX(101)-JVS(623)*XX(102)-JVS(630)&
              &*XX(103)-JVS(636)*XX(104)-JVS(670)*XX(107)-JVS(688)*XX(108)-JVS(734)*XX(113)-JVS(744)*XX(114)-JVS(761)&
              &*XX(116)-JVS(771)*XX(117)-JVS(784)*XX(118)-JVS(825)*XX(120)-JVS(854)*XX(123)-JVS(874)*XX(125)-JVS(906)&
              &*XX(127)-JVS(926)*XX(129)-JVS(938)*XX(130)-JVS(947)*XX(131)-JVS(957)*XX(132)-JVS(970)*XX(133)-JVS(985)&
              &*XX(134)-JVS(996)*XX(135)-JVS(1005)*XX(136)-JVS(1039)*XX(137)-JVS(1061)*XX(138)-JVS(1090)*XX(139)-JVS(1107)&
              &*XX(140)-JVS(1115)*XX(141)-JVS(1130)*XX(142)-JVS(1145)*XX(143)-JVS(1159)*XX(144)-JVS(1169)*XX(145)-JVS(1182)&
              &*XX(146)-JVS(1223)*XX(147)-JVS(1241)*XX(148)-JVS(1256)*XX(149)-JVS(1286)*XX(151)-JVS(1325)*XX(152)-JVS(1352)&
              &*XX(153)-JVS(1424)*XX(155)-JVS(1465)*XX(156)-JVS(1494)*XX(157)-JVS(1516)*XX(158)-JVS(1551)*XX(159)-JVS(1569)&
              &*XX(160)-JVS(1593)*XX(161)-JVS(1650)*XX(162)-JVS(1729)*XX(163))/(JVS(1798))
  XX(165) = (X(165)-JVS(214)*XX(16)-JVS(251)*XX(23)-JVS(367)*XX(60)-JVS(434)*XX(73)-JVS(472)*XX(81)-JVS(578)*XX(96)&
              &-JVS(653)*XX(106)-JVS(745)*XX(114)-JVS(785)*XX(118)-JVS(826)*XX(120)-JVS(939)*XX(130)-JVS(971)*XX(133)&
              &-JVS(1040)*XX(137)-JVS(1131)*XX(142)-JVS(1224)*XX(147)-JVS(1326)*XX(152)-JVS(1353)*XX(153)-JVS(1370)*XX(154)&
              &-JVS(1425)*XX(155)-JVS(1466)*XX(156)-JVS(1495)*XX(157)-JVS(1552)*XX(159)-JVS(1651)*XX(162)-JVS(1730)*XX(163)&
              &-JVS(1799)*XX(164))/(JVS(1843))
  XX(166) = (X(166)-JVS(170)*XX(15)-JVS(491)*XX(84)-JVS(495)*XX(85)-JVS(525)*XX(89)-JVS(579)*XX(96)-JVS(654)*XX(106)&
              &-JVS(697)*XX(109)-JVS(714)*XX(111)-JVS(725)*XX(112)-JVS(752)*XX(115)-JVS(795)*XX(119)-JVS(827)*XX(120)&
              &-JVS(864)*XX(124)-JVS(891)*XX(126)-JVS(914)*XX(128)-JVS(997)*XX(135)-JVS(1041)*XX(137)-JVS(1062)*XX(138)&
              &-JVS(1091)*XX(139)-JVS(1225)*XX(147)-JVS(1265)*XX(150)-JVS(1327)*XX(152)-JVS(1371)*XX(154)-JVS(1426)*XX(155)&
              &-JVS(1467)*XX(156)-JVS(1496)*XX(157)-JVS(1517)*XX(158)-JVS(1553)*XX(159)-JVS(1570)*XX(160)-JVS(1594)*XX(161)&
              &-JVS(1652)*XX(162)-JVS(1731)*XX(163)-JVS(1800)*XX(164)-JVS(1844)*XX(165))/(JVS(1929))
  XX(167) = (X(167)-JVS(13)*XX(5)-JVS(19)*XX(7)-JVS(25)*XX(9)-JVS(51)*XX(12)-JVS(63)*XX(13)-JVS(120)*XX(14)-JVS(171)&
              &*XX(15)-JVS(215)*XX(16)-JVS(281)*XX(35)-JVS(286)*XX(36)-JVS(299)*XX(40)-JVS(314)*XX(44)-JVS(330)*XX(49)&
              &-JVS(334)*XX(50)-JVS(371)*XX(61)-JVS(381)*XX(64)-JVS(384)*XX(65)-JVS(396)*XX(67)-JVS(400)*XX(68)-JVS(405)&
              &*XX(69)-JVS(418)*XX(71)-JVS(440)*XX(74)-JVS(446)*XX(75)-JVS(452)*XX(76)-JVS(456)*XX(77)-JVS(460)*XX(78)&
              &-JVS(465)*XX(79)-JVS(469)*XX(80)-JVS(479)*XX(82)-JVS(492)*XX(84)-JVS(503)*XX(86)-JVS(509)*XX(87)-JVS(526)&
              &*XX(89)-JVS(537)*XX(91)-JVS(544)*XX(92)-JVS(550)*XX(93)-JVS(585)*XX(97)-JVS(592)*XX(98)-JVS(624)*XX(102)&
              &-JVS(637)*XX(104)-JVS(645)*XX(105)-JVS(655)*XX(106)-JVS(671)*XX(107)-JVS(689)*XX(108)-JVS(735)*XX(113)&
              &-JVS(746)*XX(114)-JVS(762)*XX(116)-JVS(772)*XX(117)-JVS(786)*XX(118)-JVS(828)*XX(120)-JVS(834)*XX(121)&
              &-JVS(845)*XX(122)-JVS(855)*XX(123)-JVS(875)*XX(125)-JVS(892)*XX(126)-JVS(907)*XX(127)-JVS(927)*XX(129)&
              &-JVS(940)*XX(130)-JVS(948)*XX(131)-JVS(958)*XX(132)-JVS(972)*XX(133)-JVS(986)*XX(134)-JVS(998)*XX(135)&
              &-JVS(1006)*XX(136)-JVS(1042)*XX(137)-JVS(1063)*XX(138)-JVS(1092)*XX(139)-JVS(1108)*XX(140)-JVS(1132)*XX(142)&
              &-JVS(1146)*XX(143)-JVS(1160)*XX(144)-JVS(1170)*XX(145)-JVS(1183)*XX(146)-JVS(1226)*XX(147)-JVS(1242)*XX(148)&
              &-JVS(1257)*XX(149)-JVS(1287)*XX(151)-JVS(1328)*XX(152)-JVS(1354)*XX(153)-JVS(1372)*XX(154)-JVS(1427)*XX(155)&
              &-JVS(1468)*XX(156)-JVS(1497)*XX(157)-JVS(1518)*XX(158)-JVS(1554)*XX(159)-JVS(1571)*XX(160)-JVS(1595)*XX(161)&
              &-JVS(1653)*XX(162)-JVS(1732)*XX(163)-JVS(1801)*XX(164)-JVS(1845)*XX(165)-JVS(1930)*XX(166))/(JVS(2032))
  XX(168) = (X(168)-JVS(121)*XX(14)-JVS(172)*XX(15)-JVS(247)*XX(21)-JVS(252)*XX(23)-JVS(258)*XX(25)-JVS(277)*XX(34)&
              &-JVS(292)*XX(38)-JVS(296)*XX(39)-JVS(324)*XX(47)-JVS(343)*XX(53)-JVS(385)*XX(65)-JVS(496)*XX(85)-JVS(556)&
              &*XX(94)-JVS(580)*XX(96)-JVS(586)*XX(97)-JVS(656)*XX(106)-JVS(698)*XX(109)-JVS(715)*XX(111)-JVS(726)*XX(112)&
              &-JVS(753)*XX(115)-JVS(796)*XX(119)-JVS(829)*XX(120)-JVS(835)*XX(121)-JVS(865)*XX(124)-JVS(893)*XX(126)&
              &-JVS(915)*XX(128)-JVS(987)*XX(134)-JVS(1043)*XX(137)-JVS(1064)*XX(138)-JVS(1093)*XX(139)-JVS(1147)*XX(143)&
              &-JVS(1227)*XX(147)-JVS(1266)*XX(150)-JVS(1329)*XX(152)-JVS(1355)*XX(153)-JVS(1373)*XX(154)-JVS(1428)*XX(155)&
              &-JVS(1469)*XX(156)-JVS(1498)*XX(157)-JVS(1519)*XX(158)-JVS(1555)*XX(159)-JVS(1572)*XX(160)-JVS(1596)*XX(161)&
              &-JVS(1654)*XX(162)-JVS(1733)*XX(163)-JVS(1802)*XX(164)-JVS(1846)*XX(165)-JVS(1931)*XX(166)-JVS(2033)*XX(167))&
              &/(JVS(2124))
  XX(169) = (X(169)-JVS(173)*XX(15)-JVS(216)*XX(16)-JVS(303)*XX(41)-JVS(593)*XX(98)-JVS(657)*XX(106)-JVS(894)*XX(126)&
              &-JVS(916)*XX(128)-JVS(1044)*XX(137)-JVS(1065)*XX(138)-JVS(1374)*XX(154)-JVS(1499)*XX(157)-JVS(1597)*XX(161)&
              &-JVS(1655)*XX(162)-JVS(1734)*XX(163)-JVS(1803)*XX(164)-JVS(1847)*XX(165)-JVS(1932)*XX(166)-JVS(2034)*XX(167)&
              &-JVS(2125)*XX(168))/(JVS(2175))
  XX(170) = (X(170)-JVS(52)*XX(12)-JVS(174)*XX(15)-JVS(217)*XX(16)-JVS(441)*XX(74)-JVS(485)*XX(83)-JVS(513)*XX(88)&
              &-JVS(530)*XX(90)-JVS(538)*XX(91)-JVS(557)*XX(94)-JVS(594)*XX(98)-JVS(601)*XX(99)-JVS(607)*XX(100)-JVS(631)&
              &*XX(103)-JVS(646)*XX(105)-JVS(672)*XX(107)-JVS(690)*XX(108)-JVS(699)*XX(109)-JVS(706)*XX(110)-JVS(716)&
              &*XX(111)-JVS(727)*XX(112)-JVS(754)*XX(115)-JVS(763)*XX(116)-JVS(773)*XX(117)-JVS(797)*XX(119)-JVS(846)&
              &*XX(122)-JVS(856)*XX(123)-JVS(866)*XX(124)-JVS(895)*XX(126)-JVS(908)*XX(127)-JVS(928)*XX(129)-JVS(949)&
              &*XX(131)-JVS(1007)*XX(136)-JVS(1045)*XX(137)-JVS(1094)*XX(139)-JVS(1116)*XX(141)-JVS(1133)*XX(142)-JVS(1148)&
              &*XX(143)-JVS(1161)*XX(144)-JVS(1171)*XX(145)-JVS(1184)*XX(146)-JVS(1228)*XX(147)-JVS(1243)*XX(148)-JVS(1258)&
              &*XX(149)-JVS(1267)*XX(150)-JVS(1288)*XX(151)-JVS(1330)*XX(152)-JVS(1356)*XX(153)-JVS(1375)*XX(154)-JVS(1429)&
              &*XX(155)-JVS(1470)*XX(156)-JVS(1500)*XX(157)-JVS(1520)*XX(158)-JVS(1556)*XX(159)-JVS(1573)*XX(160)-JVS(1598)&
              &*XX(161)-JVS(1656)*XX(162)-JVS(1735)*XX(163)-JVS(1804)*XX(164)-JVS(1848)*XX(165)-JVS(1933)*XX(166)-JVS(2035)&
              &*XX(167)-JVS(2126)*XX(168)-JVS(2176)*XX(169))/(JVS(2216))
  XX(171) = (X(171)-JVS(122)*XX(14)-JVS(218)*XX(16)-JVS(377)*XX(63)-JVS(392)*XX(66)-JVS(595)*XX(98)-JVS(617)*XX(101)&
              &-JVS(707)*XX(110)-JVS(896)*XX(126)-JVS(917)*XX(128)-JVS(1046)*XX(137)-JVS(1066)*XX(138)-JVS(1501)*XX(157)&
              &-JVS(1736)*XX(163)-JVS(1805)*XX(164)-JVS(1849)*XX(165)-JVS(1934)*XX(166)-JVS(2036)*XX(167)-JVS(2127)*XX(168)&
              &-JVS(2177)*XX(169)-JVS(2217)*XX(170))/(JVS(2267))
  XX(172) = (X(172)-JVS(10)*XX(4)-JVS(53)*XX(12)-JVS(64)*XX(13)-JVS(175)*XX(15)-JVS(219)*XX(16)-JVS(306)*XX(42)-JVS(337)&
              &*XX(51)-JVS(340)*XX(52)-JVS(473)*XX(81)-JVS(497)*XX(85)-JVS(531)*XX(90)-JVS(602)*XX(99)-JVS(608)*XX(100)&
              &-JVS(638)*XX(104)-JVS(691)*XX(108)-JVS(708)*XX(110)-JVS(717)*XX(111)-JVS(764)*XX(116)-JVS(774)*XX(117)&
              &-JVS(798)*XX(119)-JVS(836)*XX(121)-JVS(857)*XX(123)-JVS(867)*XX(124)-JVS(876)*XX(125)-JVS(897)*XX(126)&
              &-JVS(909)*XX(127)-JVS(929)*XX(129)-JVS(950)*XX(131)-JVS(973)*XX(133)-JVS(988)*XX(134)-JVS(1008)*XX(136)&
              &-JVS(1047)*XX(137)-JVS(1067)*XX(138)-JVS(1095)*XX(139)-JVS(1109)*XX(140)-JVS(1117)*XX(141)-JVS(1134)*XX(142)&
              &-JVS(1149)*XX(143)-JVS(1162)*XX(144)-JVS(1172)*XX(145)-JVS(1185)*XX(146)-JVS(1229)*XX(147)-JVS(1244)*XX(148)&
              &-JVS(1259)*XX(149)-JVS(1268)*XX(150)-JVS(1289)*XX(151)-JVS(1331)*XX(152)-JVS(1357)*XX(153)-JVS(1376)*XX(154)&
              &-JVS(1430)*XX(155)-JVS(1471)*XX(156)-JVS(1502)*XX(157)-JVS(1521)*XX(158)-JVS(1557)*XX(159)-JVS(1574)*XX(160)&
              &-JVS(1599)*XX(161)-JVS(1657)*XX(162)-JVS(1737)*XX(163)-JVS(1806)*XX(164)-JVS(1850)*XX(165)-JVS(1935)*XX(166)&
              &-JVS(2037)*XX(167)-JVS(2128)*XX(168)-JVS(2178)*XX(169)-JVS(2218)*XX(170)-JVS(2268)*XX(171))/(JVS(2339))
  XX(173) = (X(173)-JVS(54)*XX(12)-JVS(229)*XX(17)-JVS(700)*XX(109)-JVS(718)*XX(111)-JVS(728)*XX(112)-JVS(755)*XX(115)&
              &-JVS(868)*XX(124)-JVS(898)*XX(126)-JVS(1096)*XX(139)-JVS(1230)*XX(147)-JVS(1269)*XX(150)-JVS(1332)*XX(152)&
              &-JVS(1431)*XX(155)-JVS(1472)*XX(156)-JVS(1522)*XX(158)-JVS(1558)*XX(159)-JVS(1575)*XX(160)-JVS(1600)*XX(161)&
              &-JVS(1658)*XX(162)-JVS(1738)*XX(163)-JVS(1807)*XX(164)-JVS(1851)*XX(165)-JVS(1936)*XX(166)-JVS(2038)*XX(167)&
              &-JVS(2129)*XX(168)-JVS(2179)*XX(169)-JVS(2219)*XX(170)-JVS(2269)*XX(171)-JVS(2340)*XX(172))/(JVS(2404))
  XX(174) = (X(174)-JVS(176)*XX(15)-JVS(260)*XX(26)-JVS(262)*XX(27)-JVS(264)*XX(28)-JVS(266)*XX(29)-JVS(268)*XX(30)&
              &-JVS(270)*XX(31)-JVS(272)*XX(32)-JVS(274)*XX(33)-JVS(278)*XX(34)-JVS(290)*XX(37)-JVS(317)*XX(45)-JVS(320)&
              &*XX(46)-JVS(355)*XX(56)-JVS(358)*XX(57)-JVS(361)*XX(58)-JVS(364)*XX(59)-JVS(374)*XX(62)-JVS(596)*XX(98)&
              &-JVS(618)*XX(101)-JVS(709)*XX(110)-JVS(1068)*XX(138)-JVS(1377)*XX(154)-JVS(1503)*XX(157)-JVS(1739)*XX(163)&
              &-JVS(1808)*XX(164)-JVS(1852)*XX(165)-JVS(1937)*XX(166)-JVS(2039)*XX(167)-JVS(2130)*XX(168)-JVS(2180)*XX(169)&
              &-JVS(2220)*XX(170)-JVS(2270)*XX(171)-JVS(2341)*XX(172)-JVS(2405)*XX(173))/(JVS(2448))
  XX(175) = (X(175)-JVS(4)*XX(2)-JVS(7)*XX(3)-JVS(31)*XX(11)-JVS(55)*XX(12)-JVS(123)*XX(14)-JVS(177)*XX(15)-JVS(220)&
              &*XX(16)-JVS(230)*XX(17)-JVS(240)*XX(18)-JVS(242)*XX(19)-JVS(244)*XX(20)-JVS(249)*XX(22)-JVS(255)*XX(24)&
              &-JVS(282)*XX(35)-JVS(287)*XX(36)-JVS(300)*XX(40)-JVS(304)*XX(41)-JVS(307)*XX(42)-JVS(311)*XX(43)-JVS(315)&
              &*XX(44)-JVS(318)*XX(45)-JVS(321)*XX(46)-JVS(327)*XX(48)-JVS(331)*XX(49)-JVS(335)*XX(50)-JVS(338)*XX(51)&
              &-JVS(341)*XX(52)-JVS(344)*XX(53)-JVS(349)*XX(54)-JVS(352)*XX(55)-JVS(356)*XX(56)-JVS(359)*XX(57)-JVS(362)&
              &*XX(58)-JVS(365)*XX(59)-JVS(368)*XX(60)-JVS(372)*XX(61)-JVS(375)*XX(62)-JVS(378)*XX(63)-JVS(382)*XX(64)&
              &-JVS(386)*XX(65)-JVS(393)*XX(66)-JVS(397)*XX(67)-JVS(401)*XX(68)-JVS(406)*XX(69)-JVS(419)*XX(71)-JVS(429)&
              &*XX(72)-JVS(435)*XX(73)-JVS(442)*XX(74)-JVS(447)*XX(75)-JVS(453)*XX(76)-JVS(457)*XX(77)-JVS(461)*XX(78)&
              &-JVS(466)*XX(79)-JVS(470)*XX(80)-JVS(474)*XX(81)-JVS(480)*XX(82)-JVS(486)*XX(83)-JVS(493)*XX(84)-JVS(504)&
              &*XX(86)-JVS(510)*XX(87)-JVS(514)*XX(88)-JVS(527)*XX(89)-JVS(532)*XX(90)-JVS(539)*XX(91)-JVS(551)*XX(93)&
              &-JVS(558)*XX(94)-JVS(575)*XX(95)-JVS(587)*XX(97)-JVS(597)*XX(98)-JVS(603)*XX(99)-JVS(609)*XX(100)-JVS(619)&
              &*XX(101)-JVS(625)*XX(102)-JVS(632)*XX(103)-JVS(647)*XX(105)-JVS(658)*XX(106)-JVS(673)*XX(107)-JVS(692)&
              &*XX(108)-JVS(710)*XX(110)-JVS(719)*XX(111)-JVS(736)*XX(113)-JVS(747)*XX(114)-JVS(765)*XX(116)-JVS(775)&
              &*XX(117)-JVS(787)*XX(118)-JVS(799)*XX(119)-JVS(830)*XX(120)-JVS(837)*XX(121)-JVS(847)*XX(122)-JVS(858)&
              &*XX(123)-JVS(869)*XX(124)-JVS(899)*XX(126)-JVS(910)*XX(127)-JVS(918)*XX(128)-JVS(930)*XX(129)-JVS(941)&
              &*XX(130)-JVS(951)*XX(131)-JVS(959)*XX(132)-JVS(974)*XX(133)-JVS(989)*XX(134)-JVS(999)*XX(135)-JVS(1009)&
              &*XX(136)-JVS(1048)*XX(137)-JVS(1069)*XX(138)-JVS(1097)*XX(139)-JVS(1110)*XX(140)-JVS(1118)*XX(141)-JVS(1135)&
              &*XX(142)-JVS(1150)*XX(143)-JVS(1163)*XX(144)-JVS(1173)*XX(145)-JVS(1186)*XX(146)-JVS(1231)*XX(147)-JVS(1245)&
              &*XX(148)-JVS(1260)*XX(149)-JVS(1270)*XX(150)-JVS(1290)*XX(151)-JVS(1333)*XX(152)-JVS(1358)*XX(153)-JVS(1378)&
              &*XX(154)-JVS(1432)*XX(155)-JVS(1473)*XX(156)-JVS(1504)*XX(157)-JVS(1523)*XX(158)-JVS(1559)*XX(159)-JVS(1576)&
              &*XX(160)-JVS(1601)*XX(161)-JVS(1659)*XX(162)-JVS(1740)*XX(163)-JVS(1809)*XX(164)-JVS(1853)*XX(165)-JVS(1938)&
              &*XX(166)-JVS(2040)*XX(167)-JVS(2131)*XX(168)-JVS(2181)*XX(169)-JVS(2221)*XX(170)-JVS(2271)*XX(171)-JVS(2342)&
              &*XX(172)-JVS(2406)*XX(173)-JVS(2449)*XX(174))/(JVS(2584))
  XX(176) = (X(176)-JVS(178)*XX(15)-JVS(353)*XX(55)-JVS(414)*XX(70)-JVS(498)*XX(85)-JVS(581)*XX(96)-JVS(598)*XX(98)&
              &-JVS(620)*XX(101)-JVS(659)*XX(106)-JVS(919)*XX(128)-JVS(1049)*XX(137)-JVS(1070)*XX(138)-JVS(1379)*XX(154)&
              &-JVS(1505)*XX(157)-JVS(1741)*XX(163)-JVS(1810)*XX(164)-JVS(1854)*XX(165)-JVS(1939)*XX(166)-JVS(2041)*XX(167)&
              &-JVS(2132)*XX(168)-JVS(2182)*XX(169)-JVS(2222)*XX(170)-JVS(2272)*XX(171)-JVS(2343)*XX(172)-JVS(2407)*XX(173)&
              &-JVS(2450)*XX(174)-JVS(2585)*XX(175))/(JVS(2618))
  XX(177) = (X(177)-JVS(16)*XX(6)-JVS(22)*XX(8)-JVS(28)*XX(10)-JVS(56)*XX(12)-JVS(65)*XX(13)-JVS(124)*XX(14)-JVS(179)&
              &*XX(15)-JVS(221)*XX(16)-JVS(283)*XX(35)-JVS(288)*XX(36)-JVS(293)*XX(38)-JVS(301)*XX(40)-JVS(345)*XX(53)&
              &-JVS(443)*XX(74)-JVS(481)*XX(82)-JVS(487)*XX(83)-JVS(515)*XX(88)-JVS(528)*XX(89)-JVS(540)*XX(91)-JVS(545)&
              &*XX(92)-JVS(552)*XX(93)-JVS(588)*XX(97)-JVS(626)*XX(102)-JVS(633)*XX(103)-JVS(639)*XX(104)-JVS(648)*XX(105)&
              &-JVS(674)*XX(107)-JVS(693)*XX(108)-JVS(701)*XX(109)-JVS(720)*XX(111)-JVS(729)*XX(112)-JVS(737)*XX(113)&
              &-JVS(748)*XX(114)-JVS(756)*XX(115)-JVS(766)*XX(116)-JVS(776)*XX(117)-JVS(788)*XX(118)-JVS(800)*XX(119)&
              &-JVS(831)*XX(120)-JVS(838)*XX(121)-JVS(848)*XX(122)-JVS(859)*XX(123)-JVS(870)*XX(124)-JVS(877)*XX(125)&
              &-JVS(900)*XX(126)-JVS(911)*XX(127)-JVS(931)*XX(129)-JVS(942)*XX(130)-JVS(952)*XX(131)-JVS(960)*XX(132)&
              &-JVS(975)*XX(133)-JVS(990)*XX(134)-JVS(1000)*XX(135)-JVS(1010)*XX(136)-JVS(1050)*XX(137)-JVS(1098)*XX(139)&
              &-JVS(1111)*XX(140)-JVS(1119)*XX(141)-JVS(1136)*XX(142)-JVS(1151)*XX(143)-JVS(1164)*XX(144)-JVS(1174)*XX(145)&
              &-JVS(1187)*XX(146)-JVS(1232)*XX(147)-JVS(1246)*XX(148)-JVS(1261)*XX(149)-JVS(1271)*XX(150)-JVS(1291)*XX(151)&
              &-JVS(1334)*XX(152)-JVS(1359)*XX(153)-JVS(1380)*XX(154)-JVS(1433)*XX(155)-JVS(1474)*XX(156)-JVS(1506)*XX(157)&
              &-JVS(1524)*XX(158)-JVS(1560)*XX(159)-JVS(1577)*XX(160)-JVS(1602)*XX(161)-JVS(1660)*XX(162)-JVS(1742)*XX(163)&
              &-JVS(1811)*XX(164)-JVS(1855)*XX(165)-JVS(1940)*XX(166)-JVS(2042)*XX(167)-JVS(2133)*XX(168)-JVS(2183)*XX(169)&
              &-JVS(2223)*XX(170)-JVS(2273)*XX(171)-JVS(2344)*XX(172)-JVS(2408)*XX(173)-JVS(2451)*XX(174)-JVS(2586)*XX(175)&
              &-JVS(2619)*XX(176))/(JVS(2690))
  XX(178) = (X(178)-JVS(180)*XX(15)-JVS(415)*XX(70)-JVS(436)*XX(73)-JVS(599)*XX(98)-JVS(660)*XX(106)-JVS(920)*XX(128)&
              &-JVS(1051)*XX(137)-JVS(1071)*XX(138)-JVS(1381)*XX(154)-JVS(1507)*XX(157)-JVS(1743)*XX(163)-JVS(1812)*XX(164)&
              &-JVS(1856)*XX(165)-JVS(1941)*XX(166)-JVS(2043)*XX(167)-JVS(2134)*XX(168)-JVS(2184)*XX(169)-JVS(2224)*XX(170)&
              &-JVS(2274)*XX(171)-JVS(2345)*XX(172)-JVS(2409)*XX(173)-JVS(2452)*XX(174)-JVS(2587)*XX(175)-JVS(2620)*XX(176)&
              &-JVS(2691)*XX(177))/(JVS(2724))
  XX(178) = XX(178)
  XX(177) = XX(177)-JVS(2723)*XX(178)
  XX(176) = XX(176)-JVS(2689)*XX(177)-JVS(2722)*XX(178)
  XX(175) = XX(175)-JVS(2617)*XX(176)-JVS(2688)*XX(177)-JVS(2721)*XX(178)
  XX(174) = XX(174)-JVS(2583)*XX(175)-JVS(2616)*XX(176)-JVS(2687)*XX(177)-JVS(2720)*XX(178)
  XX(173) = XX(173)-JVS(2447)*XX(174)-JVS(2582)*XX(175)-JVS(2615)*XX(176)-JVS(2686)*XX(177)-JVS(2719)*XX(178)
  XX(172) = XX(172)-JVS(2403)*XX(173)-JVS(2446)*XX(174)-JVS(2581)*XX(175)-JVS(2614)*XX(176)-JVS(2685)*XX(177)-JVS(2718)&
              &*XX(178)
  XX(171) = XX(171)-JVS(2338)*XX(172)-JVS(2402)*XX(173)-JVS(2445)*XX(174)-JVS(2580)*XX(175)-JVS(2613)*XX(176)-JVS(2684)&
              &*XX(177)-JVS(2717)*XX(178)
  XX(170) = XX(170)-JVS(2266)*XX(171)-JVS(2337)*XX(172)-JVS(2401)*XX(173)-JVS(2444)*XX(174)-JVS(2579)*XX(175)-JVS(2612)&
              &*XX(176)-JVS(2683)*XX(177)-JVS(2716)*XX(178)
  XX(169) = XX(169)-JVS(2215)*XX(170)-JVS(2265)*XX(171)-JVS(2336)*XX(172)-JVS(2400)*XX(173)-JVS(2443)*XX(174)-JVS(2578)&
              &*XX(175)-JVS(2611)*XX(176)-JVS(2682)*XX(177)-JVS(2715)*XX(178)
  XX(168) = XX(168)-JVS(2174)*XX(169)-JVS(2214)*XX(170)-JVS(2264)*XX(171)-JVS(2335)*XX(172)-JVS(2399)*XX(173)-JVS(2442)&
              &*XX(174)-JVS(2577)*XX(175)-JVS(2610)*XX(176)-JVS(2681)*XX(177)-JVS(2714)*XX(178)
  XX(167) = XX(167)-JVS(2123)*XX(168)-JVS(2173)*XX(169)-JVS(2213)*XX(170)-JVS(2263)*XX(171)-JVS(2334)*XX(172)-JVS(2398)&
              &*XX(173)-JVS(2441)*XX(174)-JVS(2576)*XX(175)-JVS(2609)*XX(176)-JVS(2680)*XX(177)-JVS(2713)*XX(178)
  XX(166) = XX(166)-JVS(2031)*XX(167)-JVS(2122)*XX(168)-JVS(2172)*XX(169)-JVS(2212)*XX(170)-JVS(2262)*XX(171)-JVS(2333)&
              &*XX(172)-JVS(2397)*XX(173)-JVS(2440)*XX(174)-JVS(2575)*XX(175)-JVS(2608)*XX(176)-JVS(2679)*XX(177)-JVS(2712)&
              &*XX(178)
  XX(165) = XX(165)-JVS(1928)*XX(166)-JVS(2030)*XX(167)-JVS(2121)*XX(168)-JVS(2171)*XX(169)-JVS(2211)*XX(170)-JVS(2261)&
              &*XX(171)-JVS(2332)*XX(172)-JVS(2396)*XX(173)-JVS(2439)*XX(174)-JVS(2574)*XX(175)-JVS(2607)*XX(176)-JVS(2678)&
              &*XX(177)-JVS(2711)*XX(178)
  XX(164) = XX(164)-JVS(1842)*XX(165)-JVS(1927)*XX(166)-JVS(2029)*XX(167)-JVS(2120)*XX(168)-JVS(2170)*XX(169)-JVS(2210)&
              &*XX(170)-JVS(2260)*XX(171)-JVS(2331)*XX(172)-JVS(2395)*XX(173)-JVS(2438)*XX(174)-JVS(2573)*XX(175)-JVS(2606)&
              &*XX(176)-JVS(2677)*XX(177)-JVS(2710)*XX(178)
  XX(163) = XX(163)-JVS(1841)*XX(165)-JVS(1926)*XX(166)-JVS(2028)*XX(167)-JVS(2119)*XX(168)-JVS(2169)*XX(169)-JVS(2209)&
              &*XX(170)-JVS(2259)*XX(171)-JVS(2330)*XX(172)-JVS(2394)*XX(173)-JVS(2572)*XX(175)-JVS(2605)*XX(176)-JVS(2709)&
              &*XX(178)
  XX(162) = XX(162)-JVS(1727)*XX(163)-JVS(1797)*XX(164)-JVS(1840)*XX(165)-JVS(1925)*XX(166)-JVS(2027)*XX(167)-JVS(2118)&
              &*XX(168)-JVS(2168)*XX(169)-JVS(2208)*XX(170)-JVS(2258)*XX(171)-JVS(2329)*XX(172)-JVS(2393)*XX(173)-JVS(2437)&
              &*XX(174)-JVS(2571)*XX(175)-JVS(2604)*XX(176)-JVS(2676)*XX(177)-JVS(2708)*XX(178)
  XX(161) = XX(161)-JVS(1648)*XX(162)-JVS(1726)*XX(163)-JVS(1796)*XX(164)-JVS(1839)*XX(165)-JVS(1924)*XX(166)-JVS(2026)&
              &*XX(167)-JVS(2117)*XX(168)-JVS(2167)*XX(169)-JVS(2207)*XX(170)-JVS(2257)*XX(171)-JVS(2328)*XX(172)-JVS(2392)&
              &*XX(173)-JVS(2436)*XX(174)-JVS(2570)*XX(175)-JVS(2603)*XX(176)-JVS(2675)*XX(177)-JVS(2707)*XX(178)
  XX(160) = XX(160)-JVS(1590)*XX(161)-JVS(1647)*XX(162)-JVS(1725)*XX(163)-JVS(1795)*XX(164)-JVS(1838)*XX(165)-JVS(1923)&
              &*XX(166)-JVS(2025)*XX(167)-JVS(2116)*XX(168)-JVS(2166)*XX(169)-JVS(2206)*XX(170)-JVS(2256)*XX(171)-JVS(2327)&
              &*XX(172)-JVS(2391)*XX(173)-JVS(2435)*XX(174)-JVS(2569)*XX(175)-JVS(2602)*XX(176)-JVS(2674)*XX(177)-JVS(2706)&
              &*XX(178)
  XX(159) = XX(159)-JVS(1646)*XX(162)-JVS(1724)*XX(163)-JVS(1794)*XX(164)-JVS(1837)*XX(165)-JVS(1922)*XX(166)-JVS(2024)&
              &*XX(167)-JVS(2115)*XX(168)-JVS(2165)*XX(169)-JVS(2205)*XX(170)-JVS(2255)*XX(171)-JVS(2326)*XX(172)-JVS(2390)&
              &*XX(173)-JVS(2434)*XX(174)-JVS(2568)*XX(175)-JVS(2601)*XX(176)-JVS(2705)*XX(178)
  XX(158) = XX(158)-JVS(1546)*XX(159)-JVS(1589)*XX(161)-JVS(1645)*XX(162)-JVS(1723)*XX(163)-JVS(1793)*XX(164)-JVS(1836)&
              &*XX(165)-JVS(1921)*XX(166)-JVS(2023)*XX(167)-JVS(2114)*XX(168)-JVS(2164)*XX(169)-JVS(2204)*XX(170)-JVS(2254)&
              &*XX(171)-JVS(2325)*XX(172)-JVS(2389)*XX(173)-JVS(2567)*XX(175)-JVS(2600)*XX(176)-JVS(2673)*XX(177)-JVS(2704)&
              &*XX(178)
  XX(157) = XX(157)-JVS(1722)*XX(163)-JVS(1792)*XX(164)-JVS(1835)*XX(165)-JVS(1920)*XX(166)-JVS(2022)*XX(167)-JVS(2113)&
              &*XX(168)-JVS(2163)*XX(169)-JVS(2253)*XX(171)-JVS(2324)*XX(172)-JVS(2433)*XX(174)-JVS(2566)*XX(175)-JVS(2599)&
              &*XX(176)-JVS(2672)*XX(177)-JVS(2703)*XX(178)
  XX(156) = XX(156)-JVS(1545)*XX(159)-JVS(1644)*XX(162)-JVS(1721)*XX(163)-JVS(1791)*XX(164)-JVS(1834)*XX(165)-JVS(1919)&
              &*XX(166)-JVS(2021)*XX(167)-JVS(2112)*XX(168)-JVS(2203)*XX(170)-JVS(2323)*XX(172)-JVS(2388)*XX(173)-JVS(2565)&
              &*XX(175)-JVS(2671)*XX(177)-JVS(2702)*XX(178)
  XX(155) = XX(155)-JVS(1544)*XX(159)-JVS(1643)*XX(162)-JVS(1720)*XX(163)-JVS(1790)*XX(164)-JVS(1918)*XX(166)-JVS(2020)&
              &*XX(167)-JVS(2111)*XX(168)-JVS(2202)*XX(170)-JVS(2322)*XX(172)-JVS(2387)*XX(173)-JVS(2564)*XX(175)-JVS(2670)&
              &*XX(177)
  XX(154) = XX(154)-JVS(1492)*XX(157)-JVS(1833)*XX(165)-JVS(1917)*XX(166)-JVS(2019)*XX(167)-JVS(2110)*XX(168)-JVS(2162)&
              &*XX(169)-JVS(2252)*XX(171)-JVS(2321)*XX(172)-JVS(2432)*XX(174)-JVS(2563)*XX(175)-JVS(2598)*XX(176)-JVS(2669)&
              &*XX(177)-JVS(2701)*XX(178)
  XX(153) = XX(153)-JVS(1417)*XX(155)-JVS(1459)*XX(156)-JVS(1543)*XX(159)-JVS(1642)*XX(162)-JVS(1719)*XX(163)-JVS(1789)&
              &*XX(164)-JVS(1832)*XX(165)-JVS(1916)*XX(166)-JVS(2018)*XX(167)-JVS(2109)*XX(168)-JVS(2320)*XX(172)-JVS(2386)&
              &*XX(173)-JVS(2562)*XX(175)-JVS(2668)*XX(177)-JVS(2700)*XX(178)
  XX(152) = XX(152)-JVS(1641)*XX(162)-JVS(1718)*XX(163)-JVS(1788)*XX(164)-JVS(1915)*XX(166)-JVS(2017)*XX(167)-JVS(2108)&
              &*XX(168)-JVS(2319)*XX(172)-JVS(2385)*XX(173)-JVS(2561)*XX(175)
  XX(151) = XX(151)-JVS(1317)*XX(152)-JVS(1347)*XX(153)-JVS(1416)*XX(155)-JVS(1458)*XX(156)-JVS(1542)*XX(159)-JVS(1640)&
              &*XX(162)-JVS(1717)*XX(163)-JVS(1787)*XX(164)-JVS(1831)*XX(165)-JVS(1914)*XX(166)-JVS(2016)*XX(167)-JVS(2107)&
              &*XX(168)-JVS(2318)*XX(172)-JVS(2384)*XX(173)-JVS(2560)*XX(175)-JVS(2667)*XX(177)-JVS(2699)*XX(178)
  XX(150) = XX(150)-JVS(1316)*XX(152)-JVS(1415)*XX(155)-JVS(1457)*XX(156)-JVS(1512)*XX(158)-JVS(1588)*XX(161)-JVS(1639)&
              &*XX(162)-JVS(1716)*XX(163)-JVS(1786)*XX(164)-JVS(1913)*XX(166)-JVS(2015)*XX(167)-JVS(2106)*XX(168)-JVS(2161)&
              &*XX(169)-JVS(2251)*XX(171)-JVS(2317)*XX(172)-JVS(2383)*XX(173)-JVS(2559)*XX(175)-JVS(2597)*XX(176)-JVS(2666)&
              &*XX(177)
  XX(149) = XX(149)-JVS(1281)*XX(151)-JVS(1315)*XX(152)-JVS(1346)*XX(153)-JVS(1414)*XX(155)-JVS(1456)*XX(156)-JVS(1541)&
              &*XX(159)-JVS(1638)*XX(162)-JVS(1715)*XX(163)-JVS(1785)*XX(164)-JVS(1912)*XX(166)-JVS(2014)*XX(167)-JVS(2105)&
              &*XX(168)-JVS(2316)*XX(172)-JVS(2382)*XX(173)-JVS(2558)*XX(175)-JVS(2665)*XX(177)
  XX(148) = XX(148)-JVS(1252)*XX(149)-JVS(1280)*XX(151)-JVS(1314)*XX(152)-JVS(1345)*XX(153)-JVS(1413)*XX(155)-JVS(1540)&
              &*XX(159)-JVS(1637)*XX(162)-JVS(1714)*XX(163)-JVS(1784)*XX(164)-JVS(1911)*XX(166)-JVS(2013)*XX(167)-JVS(2104)&
              &*XX(168)-JVS(2315)*XX(172)-JVS(2381)*XX(173)-JVS(2557)*XX(175)-JVS(2664)*XX(177)
  XX(147) = XX(147)-JVS(1636)*XX(162)-JVS(1910)*XX(166)-JVS(2012)*XX(167)-JVS(2103)*XX(168)-JVS(2314)*XX(172)-JVS(2380)&
              &*XX(173)-JVS(2556)*XX(175)
  XX(146) = XX(146)-JVS(1210)*XX(147)-JVS(1279)*XX(151)-JVS(1313)*XX(152)-JVS(1412)*XX(155)-JVS(1455)*XX(156)-JVS(1587)&
              &*XX(161)-JVS(1635)*XX(162)-JVS(1713)*XX(163)-JVS(1783)*XX(164)-JVS(1909)*XX(166)-JVS(2011)*XX(167)-JVS(2102)&
              &*XX(168)-JVS(2160)*XX(169)-JVS(2201)*XX(170)-JVS(2250)*XX(171)-JVS(2313)*XX(172)-JVS(2379)*XX(173)-JVS(2555)&
              &*XX(175)-JVS(2596)*XX(176)-JVS(2663)*XX(177)
  XX(145) = XX(145)-JVS(1179)*XX(146)-JVS(1209)*XX(147)-JVS(1236)*XX(148)-JVS(1251)*XX(149)-JVS(1278)*XX(151)-JVS(1312)&
              &*XX(152)-JVS(1411)*XX(155)-JVS(1454)*XX(156)-JVS(1511)*XX(158)-JVS(1565)*XX(160)-JVS(1634)*XX(162)-JVS(1712)&
              &*XX(163)-JVS(1782)*XX(164)-JVS(1908)*XX(166)-JVS(2010)*XX(167)-JVS(2101)*XX(168)-JVS(2200)*XX(170)-JVS(2312)&
              &*XX(172)-JVS(2378)*XX(173)-JVS(2554)*XX(175)-JVS(2662)*XX(177)
  XX(144) = XX(144)-JVS(1178)*XX(146)-JVS(1208)*XX(147)-JVS(1250)*XX(149)-JVS(1311)*XX(152)-JVS(1344)*XX(153)-JVS(1410)&
              &*XX(155)-JVS(1453)*XX(156)-JVS(1510)*XX(158)-JVS(1539)*XX(159)-JVS(1564)*XX(160)-JVS(1633)*XX(162)-JVS(1711)&
              &*XX(163)-JVS(1781)*XX(164)-JVS(1907)*XX(166)-JVS(2009)*XX(167)-JVS(2100)*XX(168)-JVS(2199)*XX(170)-JVS(2311)&
              &*XX(172)-JVS(2377)*XX(173)-JVS(2553)*XX(175)-JVS(2661)*XX(177)
  XX(143) = XX(143)-JVS(1310)*XX(152)-JVS(1409)*XX(155)-JVS(1452)*XX(156)-JVS(1632)*XX(162)-JVS(1710)*XX(163)-JVS(1780)&
              &*XX(164)-JVS(1906)*XX(166)-JVS(2008)*XX(167)-JVS(2099)*XX(168)-JVS(2198)*XX(170)-JVS(2310)*XX(172)-JVS(2376)&
              &*XX(173)-JVS(2552)*XX(175)-JVS(2660)*XX(177)
  XX(142) = XX(142)-JVS(1207)*XX(147)-JVS(1309)*XX(152)-JVS(1343)*XX(153)-JVS(1451)*XX(156)-JVS(1631)*XX(162)-JVS(1709)&
              &*XX(163)-JVS(1779)*XX(164)-JVS(1905)*XX(166)-JVS(2007)*XX(167)-JVS(2098)*XX(168)-JVS(2551)*XX(175)-JVS(2659)&
              &*XX(177)
  XX(141) = XX(141)-JVS(1140)*XX(143)-JVS(1156)*XX(144)-JVS(1308)*XX(152)-JVS(1342)*XX(153)-JVS(1408)*XX(155)-JVS(1450)&
              &*XX(156)-JVS(1538)*XX(159)-JVS(1630)*XX(162)-JVS(1708)*XX(163)-JVS(1778)*XX(164)-JVS(1904)*XX(166)-JVS(2006)&
              &*XX(167)-JVS(2097)*XX(168)-JVS(2197)*XX(170)-JVS(2309)*XX(172)-JVS(2375)*XX(173)-JVS(2550)*XX(175)-JVS(2658)&
              &*XX(177)
  XX(140) = XX(140)-JVS(1277)*XX(151)-JVS(1341)*XX(153)-JVS(1407)*XX(155)-JVS(1537)*XX(159)-JVS(1629)*XX(162)-JVS(1707)&
              &*XX(163)-JVS(1777)*XX(164)-JVS(1903)*XX(166)-JVS(2005)*XX(167)-JVS(2096)*XX(168)-JVS(2549)*XX(175)-JVS(2657)&
              &*XX(177)
  XX(139) = XX(139)-JVS(1706)*XX(163)-JVS(1902)*XX(166)-JVS(2004)*XX(167)-JVS(2095)*XX(168)-JVS(2308)*XX(172)-JVS(2374)&
              &*XX(173)-JVS(2548)*XX(175)
  XX(138) = XX(138)-JVS(1491)*XX(157)-JVS(1830)*XX(165)-JVS(1901)*XX(166)-JVS(2159)*XX(169)-JVS(2249)*XX(171)-JVS(2431)&
              &*XX(174)-JVS(2547)*XX(175)-JVS(2595)*XX(176)-JVS(2698)*XX(178)
  XX(137) = XX(137)-JVS(1900)*XX(166)-JVS(2094)*XX(168)-JVS(2307)*XX(172)-JVS(2546)*XX(175)
  XX(136) = XX(136)-JVS(1124)*XX(142)-JVS(1206)*XX(147)-JVS(1340)*XX(153)-JVS(1406)*XX(155)-JVS(1449)*XX(156)-JVS(1536)&
              &*XX(159)-JVS(1628)*XX(162)-JVS(1705)*XX(163)-JVS(1776)*XX(164)-JVS(1899)*XX(166)-JVS(2003)*XX(167)-JVS(2093)&
              &*XX(168)-JVS(2545)*XX(175)-JVS(2656)*XX(177)
  XX(135) = XX(135)-JVS(1205)*XX(147)-JVS(1307)*XX(152)-JVS(1405)*XX(155)-JVS(1448)*XX(156)-JVS(1627)*XX(162)-JVS(1704)&
              &*XX(163)-JVS(1775)*XX(164)-JVS(1898)*XX(166)-JVS(2002)*XX(167)-JVS(2092)*XX(168)-JVS(2306)*XX(172)-JVS(2373)&
              &*XX(173)-JVS(2544)*XX(175)-JVS(2655)*XX(177)
  XX(134) = XX(134)-JVS(1535)*XX(159)-JVS(1626)*XX(162)-JVS(1703)*XX(163)-JVS(1774)*XX(164)-JVS(1897)*XX(166)-JVS(2001)&
              &*XX(167)-JVS(2091)*XX(168)-JVS(2196)*XX(170)-JVS(2543)*XX(175)-JVS(2654)*XX(177)
  XX(133) = XX(133)-JVS(1534)*XX(159)-JVS(1625)*XX(162)-JVS(1702)*XX(163)-JVS(1773)*XX(164)-JVS(1896)*XX(166)-JVS(2000)&
              &*XX(167)-JVS(2090)*XX(168)-JVS(2542)*XX(175)-JVS(2653)*XX(177)
  XX(132) = XX(132)-JVS(1021)*XX(137)-JVS(1080)*XX(139)-JVS(1204)*XX(147)-JVS(1276)*XX(151)-JVS(1306)*XX(152)-JVS(1404)&
              &*XX(155)-JVS(1447)*XX(156)-JVS(1624)*XX(162)-JVS(1701)*XX(163)-JVS(1772)*XX(164)-JVS(1895)*XX(166)-JVS(1999)&
              &*XX(167)-JVS(2089)*XX(168)-JVS(2195)*XX(170)-JVS(2305)*XX(172)-JVS(2372)*XX(173)-JVS(2541)*XX(175)-JVS(2652)&
              &*XX(177)
  XX(131) = XX(131)-JVS(1123)*XX(142)-JVS(1403)*XX(155)-JVS(1446)*XX(156)-JVS(1623)*XX(162)-JVS(1700)*XX(163)-JVS(1771)&
              &*XX(164)-JVS(1829)*XX(165)-JVS(1894)*XX(166)-JVS(1998)*XX(167)-JVS(2088)*XX(168)-JVS(2304)*XX(172)-JVS(2371)&
              &*XX(173)-JVS(2540)*XX(175)-JVS(2651)*XX(177)-JVS(2697)*XX(178)
  XX(130) = XX(130)-JVS(1122)*XX(142)-JVS(1402)*XX(155)-JVS(1622)*XX(162)-JVS(1699)*XX(163)-JVS(1770)*XX(164)-JVS(1828)&
              &*XX(165)-JVS(1893)*XX(166)-JVS(1997)*XX(167)-JVS(2087)*XX(168)-JVS(2370)*XX(173)-JVS(2539)*XX(175)-JVS(2650)&
              &*XX(177)-JVS(2696)*XX(178)
  XX(129) = XX(129)-JVS(1079)*XX(139)-JVS(1203)*XX(147)-JVS(1401)*XX(155)-JVS(1445)*XX(156)-JVS(1621)*XX(162)-JVS(1698)&
              &*XX(163)-JVS(1769)*XX(164)-JVS(1892)*XX(166)-JVS(1996)*XX(167)-JVS(2086)*XX(168)-JVS(2303)*XX(172)-JVS(2538)&
              &*XX(175)-JVS(2649)*XX(177)
  XX(128) = XX(128)-JVS(1020)*XX(137)-JVS(1057)*XX(138)-JVS(1490)*XX(157)-JVS(1827)*XX(165)-JVS(1891)*XX(166)-JVS(2085)&
              &*XX(168)-JVS(2158)*XX(169)-JVS(2248)*XX(171)-JVS(2302)*XX(172)-JVS(2430)*XX(174)-JVS(2537)*XX(175)-JVS(2594)&
              &*XX(176)-JVS(2695)*XX(178)
  XX(127) = XX(127)-JVS(1202)*XX(147)-JVS(1400)*XX(155)-JVS(1533)*XX(159)-JVS(1620)*XX(162)-JVS(1697)*XX(163)-JVS(1768)&
              &*XX(164)-JVS(1890)*XX(166)-JVS(1995)*XX(167)-JVS(2084)*XX(168)-JVS(2369)*XX(173)-JVS(2536)*XX(175)-JVS(2648)&
              &*XX(177)
  XX(126) = XX(126)-JVS(1889)*XX(166)-JVS(1994)*XX(167)-JVS(2157)*XX(169)-JVS(2247)*XX(171)-JVS(2535)*XX(175)-JVS(2593)&
              &*XX(176)
  XX(125) = XX(125)-JVS(1100)*XX(140)-JVS(1201)*XX(147)-JVS(1235)*XX(148)-JVS(1249)*XX(149)-JVS(1339)*XX(153)-JVS(1399)&
              &*XX(155)-JVS(1619)*XX(162)-JVS(1696)*XX(163)-JVS(1767)*XX(164)-JVS(1888)*XX(166)-JVS(1993)*XX(167)-JVS(2083)&
              &*XX(168)-JVS(2368)*XX(173)-JVS(2534)*XX(175)-JVS(2647)*XX(177)
  XX(124) = XX(124)-JVS(884)*XX(126)-JVS(1532)*XX(159)-JVS(1586)*XX(161)-JVS(1766)*XX(164)-JVS(1887)*XX(166)-JVS(2082)&
              &*XX(168)-JVS(2301)*XX(172)-JVS(2367)*XX(173)-JVS(2533)*XX(175)-JVS(2646)*XX(177)
  XX(123) = XX(123)-JVS(1305)*XX(152)-JVS(1398)*XX(155)-JVS(1531)*XX(159)-JVS(1618)*XX(162)-JVS(1695)*XX(163)-JVS(1765)&
              &*XX(164)-JVS(1886)*XX(166)-JVS(1992)*XX(167)-JVS(2081)*XX(168)-JVS(2532)*XX(175)-JVS(2645)*XX(177)
  XX(122) = XX(122)-JVS(1200)*XX(147)-JVS(1304)*XX(152)-JVS(1694)*XX(163)-JVS(1764)*XX(164)-JVS(1885)*XX(166)-JVS(1991)&
              &*XX(167)-JVS(2080)*XX(168)-JVS(2300)*XX(172)-JVS(2366)*XX(173)-JVS(2531)*XX(175)-JVS(2644)*XX(177)
  XX(121) = XX(121)-JVS(978)*XX(134)-JVS(1139)*XX(143)-JVS(1303)*XX(152)-JVS(1338)*XX(153)-JVS(1530)*XX(159)-JVS(1617)&
              &*XX(162)-JVS(1693)*XX(163)-JVS(1990)*XX(167)-JVS(2079)*XX(168)-JVS(2194)*XX(170)-JVS(2299)*XX(172)-JVS(2365)&
              &*XX(173)-JVS(2530)*XX(175)-JVS(2643)*XX(177)
  XX(120) = XX(120)-JVS(1763)*XX(164)-JVS(1884)*XX(166)-JVS(2529)*XX(175)
  XX(119) = XX(119)-JVS(883)*XX(126)-JVS(1585)*XX(161)-JVS(1692)*XX(163)-JVS(1883)*XX(166)-JVS(1989)*XX(167)-JVS(2078)&
              &*XX(168)-JVS(2298)*XX(172)-JVS(2528)*XX(175)-JVS(2642)*XX(177)
  XX(118) = XX(118)-JVS(1121)*XX(142)-JVS(1616)*XX(162)-JVS(1762)*XX(164)-JVS(1826)*XX(165)-JVS(1882)*XX(166)-JVS(2364)&
              &*XX(173)-JVS(2527)*XX(175)-JVS(2694)*XX(178)
  XX(117) = XX(117)-JVS(1397)*XX(155)-JVS(1444)*XX(156)-JVS(1615)*XX(162)-JVS(1691)*XX(163)-JVS(1761)*XX(164)-JVS(1988)&
              &*XX(167)-JVS(2077)*XX(168)-JVS(2297)*XX(172)-JVS(2526)*XX(175)-JVS(2641)*XX(177)
  XX(116) = XX(116)-JVS(768)*XX(117)-JVS(1396)*XX(155)-JVS(1443)*XX(156)-JVS(1614)*XX(162)-JVS(1690)*XX(163)-JVS(1760)&
              &*XX(164)-JVS(1987)*XX(167)-JVS(2076)*XX(168)-JVS(2296)*XX(172)-JVS(2640)*XX(177)
  XX(115) = XX(115)-JVS(882)*XX(126)-JVS(1199)*XX(147)-JVS(1584)*XX(161)-JVS(1613)*XX(162)-JVS(1759)*XX(164)-JVS(1881)&
              &*XX(166)-JVS(2075)*XX(168)-JVS(2295)*XX(172)-JVS(2363)*XX(173)-JVS(2525)*XX(175)-JVS(2639)*XX(177)
  XX(114) = XX(114)-JVS(803)*XX(120)-JVS(1395)*XX(155)-JVS(1612)*XX(162)-JVS(1689)*XX(163)-JVS(1758)*XX(164)-JVS(1986)&
              &*XX(167)-JVS(2074)*XX(168)-JVS(2524)*XX(175)-JVS(2638)*XX(177)
  XX(113) = XX(113)-JVS(802)*XX(120)-JVS(1019)*XX(137)-JVS(1302)*XX(152)-JVS(1394)*XX(155)-JVS(1442)*XX(156)-JVS(1611)&
              &*XX(162)-JVS(1688)*XX(163)-JVS(1757)*XX(164)-JVS(1985)*XX(167)-JVS(2073)*XX(168)-JVS(2523)*XX(175)-JVS(2637)&
              &*XX(177)
  XX(112) = XX(112)-JVS(881)*XX(126)-JVS(1198)*XX(147)-JVS(1583)*XX(161)-JVS(1880)*XX(166)-JVS(2072)*XX(168)-JVS(2294)&
              &*XX(172)-JVS(2362)*XX(173)-JVS(2522)*XX(175)-JVS(2636)*XX(177)
  XX(111) = XX(111)-JVS(880)*XX(126)-JVS(1563)*XX(160)-JVS(1582)*XX(161)-JVS(1879)*XX(166)-JVS(2071)*XX(168)-JVS(2293)&
              &*XX(172)-JVS(2361)*XX(173)-JVS(2521)*XX(175)-JVS(2635)*XX(177)
  XX(110) = XX(110)-JVS(1687)*XX(163)-JVS(1756)*XX(164)-JVS(1878)*XX(166)-JVS(1984)*XX(167)-JVS(2156)*XX(169)-JVS(2193)&
              &*XX(170)-JVS(2246)*XX(171)-JVS(2429)*XX(174)-JVS(2520)*XX(175)-JVS(2592)*XX(176)
  XX(109) = XX(109)-JVS(879)*XX(126)-JVS(1078)*XX(139)-JVS(1301)*XX(152)-JVS(1581)*XX(161)-JVS(1877)*XX(166)-JVS(2070)&
              &*XX(168)-JVS(2292)*XX(172)-JVS(2360)*XX(173)-JVS(2519)*XX(175)-JVS(2634)*XX(177)
  XX(108) = XX(108)-JVS(1018)*XX(137)-JVS(1686)*XX(163)-JVS(1983)*XX(167)-JVS(2291)*XX(172)-JVS(2359)*XX(173)-JVS(2518)&
              &*XX(175)
  XX(107) = XX(107)-JVS(1197)*XX(147)-JVS(1685)*XX(163)-JVS(1755)*XX(164)-JVS(2069)*XX(168)-JVS(2358)*XX(173)-JVS(2517)&
              &*XX(175)
  XX(106) = XX(106)-JVS(1367)*XX(154)-JVS(1825)*XX(165)-JVS(1876)*XX(166)-JVS(2155)*XX(169)-JVS(2245)*XX(171)-JVS(2516)&
              &*XX(175)-JVS(2591)*XX(176)
  XX(105) = XX(105)-JVS(1077)*XX(139)-JVS(1196)*XX(147)-JVS(1610)*XX(162)-JVS(1684)*XX(163)-JVS(1875)*XX(166)-JVS(1982)&
              &*XX(167)-JVS(2068)*XX(168)-JVS(2290)*XX(172)-JVS(2515)*XX(175)
  XX(104) = XX(104)-JVS(681)*XX(108)-JVS(1155)*XX(144)-JVS(1337)*XX(153)-JVS(1393)*XX(155)-JVS(1441)*XX(156)-JVS(1683)&
              &*XX(163)-JVS(1754)*XX(164)-JVS(1981)*XX(167)-JVS(2067)*XX(168)-JVS(2289)*XX(172)-JVS(2514)*XX(175)-JVS(2633)&
              &*XX(177)
  XX(103) = XX(103)-JVS(662)*XX(107)-JVS(1076)*XX(139)-JVS(1177)*XX(146)-JVS(1248)*XX(149)-JVS(1300)*XX(152)-JVS(1682)&
              &*XX(163)-JVS(1980)*XX(167)-JVS(2066)*XX(168)-JVS(2192)*XX(170)-JVS(2513)*XX(175)
  XX(102) = XX(102)-JVS(680)*XX(108)-JVS(1154)*XX(144)-JVS(1336)*XX(153)-JVS(1392)*XX(155)-JVS(1440)*XX(156)-JVS(1681)&
              &*XX(163)-JVS(1753)*XX(164)-JVS(1979)*XX(167)-JVS(2065)*XX(168)-JVS(2512)*XX(175)-JVS(2632)*XX(177)
  XX(101) = XX(101)-JVS(1056)*XX(138)-JVS(1489)*XX(157)-JVS(2154)*XX(169)-JVS(2244)*XX(171)-JVS(2428)*XX(174)-JVS(2511)&
              &*XX(175)
  XX(100) = XX(100)-JVS(702)*XX(110)-JVS(790)*XX(119)-JVS(850)*XX(123)-JVS(860)*XX(124)-JVS(902)*XX(127)-JVS(1529)&
              &*XX(159)-JVS(1680)*XX(163)-JVS(1752)*XX(164)-JVS(1978)*XX(167)-JVS(2191)*XX(170)-JVS(2288)*XX(172)-JVS(2357)&
              &*XX(173)-JVS(2510)*XX(175)
  XX(99) = XX(99)-JVS(604)*XX(100)-JVS(711)*XX(111)-JVS(789)*XX(119)-JVS(922)*XX(129)-JVS(1153)*XX(144)-JVS(1166)&
             &*XX(145)-JVS(1262)*XX(150)-JVS(1509)*XX(158)-JVS(1562)*XX(160)-JVS(1609)*XX(162)-JVS(1679)*XX(163)-JVS(1751)&
             &*XX(164)-JVS(1977)*XX(167)-JVS(2190)*XX(170)-JVS(2287)*XX(172)-JVS(2356)*XX(173)-JVS(2509)*XX(175)
  XX(98) = XX(98)-JVS(1874)*XX(166)-JVS(1976)*XX(167)-JVS(2153)*XX(169)-JVS(2189)*XX(170)-JVS(2508)*XX(175)
  XX(97) = XX(97)-JVS(801)*XX(120)-JVS(1195)*XX(147)-JVS(1299)*XX(152)-JVS(1678)*XX(163)-JVS(1873)*XX(166)-JVS(1975)&
             &*XX(167)-JVS(2064)*XX(168)-JVS(2286)*XX(172)-JVS(2507)*XX(175)-JVS(2631)*XX(177)
  XX(96) = XX(96)-JVS(650)*XX(106)-JVS(1017)*XX(137)-JVS(1366)*XX(154)-JVS(1824)*XX(165)-JVS(1872)*XX(166)-JVS(2063)&
             &*XX(168)-JVS(2243)*XX(171)-JVS(2285)*XX(172)-JVS(2506)*XX(175)-JVS(2590)*XX(176)
  XX(95) = XX(95)-JVS(1391)*XX(155)-JVS(1974)*XX(167)-JVS(2505)*XX(175)
  XX(94) = XX(94)-JVS(1138)*XX(143)-JVS(1298)*XX(152)-JVS(1608)*XX(162)-JVS(1677)*XX(163)-JVS(2062)*XX(168)-JVS(2188)&
             &*XX(170)-JVS(2284)*XX(172)-JVS(2355)*XX(173)-JVS(2504)*XX(175)
  XX(93) = XX(93)-JVS(679)*XX(108)-JVS(1075)*XX(139)-JVS(1194)*XX(147)-JVS(1297)*XX(152)-JVS(1676)*XX(163)-JVS(1871)&
             &*XX(166)-JVS(1973)*XX(167)-JVS(2061)*XX(168)-JVS(2354)*XX(173)-JVS(2503)*XX(175)-JVS(2630)*XX(177)
  XX(92) = XX(92)-JVS(678)*XX(108)-JVS(1016)*XX(137)-JVS(1074)*XX(139)-JVS(1193)*XX(147)-JVS(1275)*XX(151)-JVS(1296)&
             &*XX(152)-JVS(1390)*XX(155)-JVS(1972)*XX(167)-JVS(2060)*XX(168)-JVS(2502)*XX(175)-JVS(2629)*XX(177)
  XX(91) = XX(91)-JVS(1015)*XX(137)-JVS(1274)*XX(151)-JVS(1389)*XX(155)-JVS(1971)*XX(167)-JVS(2059)*XX(168)-JVS(2501)&
             &*XX(175)-JVS(2628)*XX(177)
  XX(90) = XX(90)-JVS(757)*XX(116)-JVS(767)*XX(117)-JVS(878)*XX(126)-JVS(944)*XX(131)-JVS(1001)*XX(136)-JVS(1388)&
             &*XX(155)-JVS(1439)*XX(156)-JVS(1970)*XX(167)-JVS(2187)*XX(170)-JVS(2283)*XX(172)-JVS(2353)*XX(173)-JVS(2500)&
             &*XX(175)
  XX(89) = XX(89)-JVS(1870)*XX(166)-JVS(1969)*XX(167)-JVS(2499)*XX(175)
  XX(88) = XX(88)-JVS(640)*XX(105)-JVS(839)*XX(122)-JVS(1176)*XX(146)-JVS(1234)*XX(148)-JVS(1675)*XX(163)-JVS(1968)&
             &*XX(167)-JVS(2058)*XX(168)-JVS(2186)*XX(170)-JVS(2498)*XX(175)
  XX(87) = XX(87)-JVS(1152)*XX(144)-JVS(1335)*XX(153)-JVS(1387)*XX(155)-JVS(1438)*XX(156)-JVS(1967)*XX(167)-JVS(2057)&
             &*XX(168)-JVS(2497)*XX(175)
  XX(86) = XX(86)-JVS(1099)*XX(140)-JVS(1233)*XX(148)-JVS(1247)*XX(149)-JVS(1386)*XX(155)-JVS(1966)*XX(167)-JVS(2056)&
             &*XX(168)-JVS(2496)*XX(175)
  XX(85) = XX(85)-JVS(1014)*XX(137)-JVS(1055)*XX(138)-JVS(1869)*XX(166)-JVS(2055)*XX(168)-JVS(2242)*XX(171)-JVS(2282)&
             &*XX(172)-JVS(2495)*XX(175)-JVS(2589)*XX(176)
  XX(84) = XX(84)-JVS(991)*XX(135)-JVS(1295)*XX(152)-JVS(1674)*XX(163)-JVS(1965)*XX(167)-JVS(2352)*XX(173)-JVS(2494)&
             &*XX(175)
  XX(83) = XX(83)-JVS(533)*XX(91)-JVS(1437)*XX(156)-JVS(1964)*XX(167)-JVS(2185)*XX(170)-JVS(2493)*XX(175)
  XX(82) = XX(82)-JVS(1294)*XX(152)-JVS(1436)*XX(156)-JVS(1963)*XX(167)-JVS(2351)*XX(173)-JVS(2492)*XX(175)
  XX(81) = XX(81)-JVS(962)*XX(133)-JVS(1013)*XX(137)-JVS(1823)*XX(165)-JVS(1868)*XX(166)-JVS(2281)*XX(172)-JVS(2350)&
             &*XX(173)-JVS(2491)*XX(175)-JVS(2693)*XX(178)
  XX(80) = XX(80)-JVS(475)*XX(82)-JVS(953)*XX(132)-JVS(1073)*XX(139)-JVS(1192)*XX(147)-JVS(1293)*XX(152)-JVS(1962)&
             &*XX(167)-JVS(2349)*XX(173)-JVS(2490)*XX(175)
  XX(79) = XX(79)-JVS(1120)*XX(142)-JVS(1191)*XX(147)-JVS(1607)*XX(162)-JVS(1673)*XX(163)-JVS(1867)*XX(166)-JVS(2489)&
             &*XX(175)
  XX(78) = XX(78)-JVS(921)*XX(129)-JVS(1072)*XX(139)-JVS(1190)*XX(147)-JVS(1435)*XX(156)-JVS(1606)*XX(162)-JVS(1672)&
             &*XX(163)-JVS(1961)*XX(167)-JVS(2488)*XX(175)
  XX(77) = XX(77)-JVS(547)*XX(93)-JVS(1165)*XX(145)-JVS(1175)*XX(146)-JVS(1508)*XX(158)-JVS(1561)*XX(160)-JVS(1671)&
             &*XX(163)-JVS(1960)*XX(167)-JVS(2487)*XX(175)
  XX(76) = XX(76)-JVS(1273)*XX(151)-JVS(1385)*XX(155)-JVS(1959)*XX(167)-JVS(2486)*XX(175)
  XX(75) = XX(75)-JVS(849)*XX(123)-JVS(1292)*XX(152)-JVS(1528)*XX(159)-JVS(1670)*XX(163)-JVS(1958)*XX(167)-JVS(2485)&
             &*XX(175)
  XX(74) = XX(74)-JVS(1669)*XX(163)-JVS(2054)*XX(168)-JVS(2484)*XX(175)
  XX(73) = XX(73)-JVS(649)*XX(106)-JVS(1822)*XX(165)-JVS(2483)*XX(175)
  XX(72) = XX(72)-JVS(1580)*XX(161)-JVS(2482)*XX(175)
  XX(71) = XX(71)-JVS(661)*XX(107)-JVS(901)*XX(127)-JVS(1384)*XX(155)-JVS(1957)*XX(167)-JVS(2053)*XX(168)-JVS(2481)&
             &*XX(175)
  XX(70) = XX(70)-JVS(1821)*XX(165)-JVS(2241)*XX(171)
  XX(69) = XX(69)-JVS(977)*XX(134)-JVS(1527)*XX(159)-JVS(1956)*XX(167)-JVS(2480)*XX(175)
  XX(68) = XX(68)-JVS(943)*XX(131)-JVS(1383)*XX(155)-JVS(1434)*XX(156)-JVS(1955)*XX(167)-JVS(2479)*XX(175)
  XX(67) = XX(67)-JVS(1668)*XX(163)-JVS(1750)*XX(164)-JVS(1866)*XX(166)-JVS(1954)*XX(167)-JVS(2478)*XX(175)
  XX(66) = XX(66)-JVS(610)*XX(101)-JVS(1488)*XX(157)-JVS(2240)*XX(171)
  XX(65) = XX(65)-JVS(1865)*XX(166)-JVS(1953)*XX(167)-JVS(2052)*XX(168)-JVS(2280)*XX(172)-JVS(2477)*XX(175)
  XX(64) = XX(64)-JVS(730)*XX(113)-JVS(1137)*XX(143)-JVS(1605)*XX(162)-JVS(1667)*XX(163)-JVS(2476)*XX(175)
  XX(63) = XX(63)-JVS(1749)*XX(164)-JVS(1864)*XX(166)-JVS(1952)*XX(167)-JVS(2239)*XX(171)-JVS(2348)*XX(173)-JVS(2475)&
             &*XX(175)-JVS(2588)*XX(176)
  XX(62) = XX(62)-JVS(1365)*XX(154)-JVS(1748)*XX(164)-JVS(1820)*XX(165)-JVS(1863)*XX(166)-JVS(1951)*XX(167)-JVS(2427)&
             &*XX(174)-JVS(2474)*XX(175)
  XX(61) = XX(61)-JVS(961)*XX(133)-JVS(1526)*XX(159)-JVS(1950)*XX(167)-JVS(2473)*XX(175)
  XX(60) = XX(60)-JVS(739)*XX(114)-JVS(933)*XX(130)-JVS(1819)*XX(165)-JVS(2347)*XX(173)-JVS(2472)*XX(175)-JVS(2692)&
             &*XX(178)
  XX(59) = XX(59)-JVS(1487)*XX(157)-JVS(1862)*XX(166)-JVS(2152)*XX(169)-JVS(2238)*XX(171)-JVS(2426)*XX(174)-JVS(2471)&
             &*XX(175)
  XX(58) = XX(58)-JVS(1486)*XX(157)-JVS(1861)*XX(166)-JVS(2151)*XX(169)-JVS(2237)*XX(171)-JVS(2425)*XX(174)-JVS(2470)&
             &*XX(175)
  XX(57) = XX(57)-JVS(1485)*XX(157)-JVS(1860)*XX(166)-JVS(2150)*XX(169)-JVS(2236)*XX(171)-JVS(2424)*XX(174)-JVS(2469)&
             &*XX(175)
  XX(56) = XX(56)-JVS(1484)*XX(157)-JVS(1859)*XX(166)-JVS(2149)*XX(169)-JVS(2235)*XX(171)-JVS(2423)*XX(174)-JVS(2468)&
             &*XX(175)
  XX(55) = XX(55)-JVS(1054)*XX(138)-JVS(2051)*XX(168)-JVS(2234)*XX(171)-JVS(2467)*XX(175)
  XX(54) = XX(54)-JVS(1053)*XX(138)-JVS(1483)*XX(157)-JVS(2148)*XX(169)-JVS(2466)*XX(175)
  XX(53) = XX(53)-JVS(1858)*XX(166)-JVS(2050)*XX(168)-JVS(2465)*XX(175)-JVS(2627)*XX(177)
  XX(52) = XX(52)-JVS(1012)*XX(137)-JVS(1579)*XX(161)-JVS(1666)*XX(163)-JVS(1747)*XX(164)-JVS(2279)*XX(172)-JVS(2464)&
             &*XX(175)
  XX(51) = XX(51)-JVS(677)*XX(108)-JVS(1189)*XX(147)-JVS(1665)*XX(163)-JVS(1949)*XX(167)-JVS(2278)*XX(172)-JVS(2626)&
             &*XX(177)
  XX(50) = XX(50)-JVS(777)*XX(118)-JVS(932)*XX(130)-JVS(1948)*XX(167)-JVS(2463)*XX(175)
  XX(49) = XX(49)-JVS(738)*XX(114)-JVS(1382)*XX(155)-JVS(1947)*XX(167)-JVS(2462)*XX(175)
  XX(48) = XX(48)-JVS(387)*XX(66)-JVS(1052)*XX(138)-JVS(1482)*XX(157)-JVS(2233)*XX(171)-JVS(2461)*XX(175)
  XX(47) = XX(47)-JVS(1664)*XX(163)-JVS(1746)*XX(164)-JVS(1946)*XX(167)-JVS(2049)*XX(168)-JVS(2277)*XX(172)
  XX(46) = XX(46)-JVS(1364)*XX(154)-JVS(1818)*XX(165)-JVS(2147)*XX(169)-JVS(2422)*XX(174)-JVS(2460)*XX(175)
  XX(45) = XX(45)-JVS(1363)*XX(154)-JVS(1817)*XX(165)-JVS(2146)*XX(169)-JVS(2421)*XX(174)-JVS(2459)*XX(175)
  XX(44) = XX(44)-JVS(1604)*XX(162)-JVS(1745)*XX(164)-JVS(2458)*XX(175)
  XX(43) = XX(43)-JVS(1525)*XX(159)-JVS(1945)*XX(167)-JVS(2457)*XX(175)
  XX(42) = XX(42)-JVS(1011)*XX(137)-JVS(1272)*XX(151)-JVS(2276)*XX(172)-JVS(2456)*XX(175)
  XX(41) = XX(41)-JVS(1578)*XX(161)-JVS(2145)*XX(169)-JVS(2346)*XX(173)-JVS(2455)*XX(175)
  XX(40) = XX(40)-JVS(1944)*XX(167)-JVS(2625)*XX(177)
  XX(39) = XX(39)-JVS(1603)*XX(162)-JVS(1744)*XX(164)-JVS(2048)*XX(168)-JVS(2275)*XX(172)
  XX(38) = XX(38)-JVS(2047)*XX(168)-JVS(2144)*XX(169)-JVS(2420)*XX(174)-JVS(2624)*XX(177)
  XX(37) = XX(37)-JVS(1362)*XX(154)-JVS(1481)*XX(157)-JVS(1816)*XX(165)-JVS(2143)*XX(169)-JVS(2232)*XX(171)-JVS(2419)&
             &*XX(174)
  XX(36) = XX(36)-JVS(1943)*XX(167)-JVS(2623)*XX(177)
  XX(35) = XX(35)-JVS(1942)*XX(167)-JVS(2622)*XX(177)
  XX(34) = XX(34)-JVS(2418)*XX(174)-JVS(2621)*XX(177)
  XX(33) = XX(33)-JVS(1361)*XX(154)-JVS(1815)*XX(165)-JVS(2142)*XX(169)-JVS(2417)*XX(174)
  XX(32) = XX(32)-JVS(1360)*XX(154)-JVS(1814)*XX(165)-JVS(2141)*XX(169)-JVS(2416)*XX(174)
  XX(31) = XX(31)-JVS(1480)*XX(157)-JVS(2140)*XX(169)-JVS(2231)*XX(171)-JVS(2415)*XX(174)
  XX(30) = XX(30)-JVS(1479)*XX(157)-JVS(2139)*XX(169)-JVS(2230)*XX(171)-JVS(2414)*XX(174)
  XX(29) = XX(29)-JVS(1478)*XX(157)-JVS(2138)*XX(169)-JVS(2229)*XX(171)-JVS(2413)*XX(174)
  XX(28) = XX(28)-JVS(1477)*XX(157)-JVS(2137)*XX(169)-JVS(2228)*XX(171)-JVS(2412)*XX(174)
  XX(27) = XX(27)-JVS(1476)*XX(157)-JVS(2136)*XX(169)-JVS(2227)*XX(171)-JVS(2411)*XX(174)
  XX(26) = XX(26)-JVS(1475)*XX(157)-JVS(2135)*XX(169)-JVS(2226)*XX(171)-JVS(2410)*XX(174)
  XX(25) = XX(25)-JVS(582)*XX(97)-JVS(2046)*XX(168)
  XX(24) = XX(24)-JVS(546)*XX(93)-JVS(2454)*XX(175)
  XX(23) = XX(23)-JVS(1813)*XX(165)-JVS(2045)*XX(168)
  XX(22) = XX(22)-JVS(284)*XX(36)-JVS(676)*XX(108)-JVS(1188)*XX(147)-JVS(1663)*XX(163)
  XX(21) = XX(21)-JVS(976)*XX(134)-JVS(2044)*XX(168)
  XX(20) = XX(20)-JVS(279)*XX(35)-JVS(675)*XX(108)-JVS(1662)*XX(163)
  XX(19) = XX(19)-JVS(1857)*XX(166)-JVS(2225)*XX(171)-JVS(2453)*XX(175)
  XX(18) = XX(18)
  XX(17) = XX(17)
  XX(16) = XX(16)
  XX(15) = XX(15)
  XX(14) = XX(14)
  XX(13) = XX(13)
  XX(12) = XX(12)
  XX(11) = XX(11)
  XX(10) = XX(10)
  XX(9) = XX(9)
  XX(8) = XX(8)
  XX(7) = XX(7)
  XX(6) = XX(6)
  XX(5) = XX(5)
  XX(4) = XX(4)
  XX(3) = XX(3)
  XX(2) = XX(2)
  XX(1) = XX(1)-JVS(1661)*XX(163)
      
END SUBROUTINE KppSolveTR

! End of KppSolveTR function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! BLAS_UTIL - BLAS-LIKE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

!--------------------------------------------------------------
!
! BLAS/LAPACK-like subroutines used by the integration algorithms
! It is recommended to replace them by calls to the optimized
!      BLAS/LAPACK library for your machine
!
!  (C) Adrian Sandu, Aug. 2004
!      Virginia Polytechnic Institute and State University
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE WCOPY(N,X,incX,Y,incY)
!--------------------------------------------------------------
!     copies a vector, x, to a vector, y:  y <- x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL  SCOPY(N,X,1,Y,1)   or   CALL  DCOPY(N,X,1,Y,1)
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N)

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = X(i)
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i) = X(i)
        Y(i + 1) = X(i + 1)
        Y(i + 2) = X(i + 2)
        Y(i + 3) = X(i + 3)
        Y(i + 4) = X(i + 4)
        Y(i + 5) = X(i + 5)
        Y(i + 6) = X(i + 6)
        Y(i + 7) = X(i + 7)
      END DO

      END SUBROUTINE WCOPY


!--------------------------------------------------------------
      SUBROUTINE WAXPY(N,Alpha,X,incX,Y,incY)
!--------------------------------------------------------------
!     constant times a vector plus a vector: y <- y + Alpha*x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SAXPY(N,Alpha,X,1,Y,1) or  CALL DAXPY(N,Alpha,X,1,Y,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N),Alpha
      REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp

      IF (Alpha .EQ. ZERO) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,4)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = Y(i) + Alpha*X(i)
        END DO
        IF( N .LT. 4 ) RETURN
      END IF
      MP1 = M + 1
      DO i = MP1,N,4
        Y(i) = Y(i) + Alpha*X(i)
        Y(i + 1) = Y(i + 1) + Alpha*X(i + 1)
        Y(i + 2) = Y(i + 2) + Alpha*X(i + 2)
        Y(i + 3) = Y(i + 3) + Alpha*X(i + 3)
      END DO
      
      END SUBROUTINE WAXPY



!--------------------------------------------------------------
      SUBROUTINE WSCAL(N,Alpha,X,incX)
!--------------------------------------------------------------
!     constant times a vector: x(1:N) <- Alpha*x(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SSCAL(N,Alpha,X,1) or  CALL DSCAL(N,Alpha,X,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,M,MP1,N
      REAL(kind=dp)  :: X(N),Alpha
      REAL(kind=dp), PARAMETER  :: ZERO=0.0_dp, ONE=1.0_dp

      IF (Alpha .EQ. ONE) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,5)
      IF( M .NE. 0 ) THEN
        IF (Alpha .EQ. (-ONE)) THEN
          DO i = 1,M
            X(i) = -X(i)
          END DO
        ELSEIF (Alpha .EQ. ZERO) THEN
          DO i = 1,M
            X(i) = ZERO
          END DO
        ELSE
          DO i = 1,M
            X(i) = Alpha*X(i)
          END DO
        END IF
        IF( N .LT. 5 ) RETURN
      END IF
      MP1 = M + 1
      IF (Alpha .EQ. (-ONE)) THEN
        DO i = MP1,N,5
          X(i)     = -X(i)
          X(i + 1) = -X(i + 1)
          X(i + 2) = -X(i + 2)
          X(i + 3) = -X(i + 3)
          X(i + 4) = -X(i + 4)
        END DO
      ELSEIF (Alpha .EQ. ZERO) THEN
        DO i = MP1,N,5
          X(i)     = ZERO
          X(i + 1) = ZERO
          X(i + 2) = ZERO
          X(i + 3) = ZERO
          X(i + 4) = ZERO
        END DO
      ELSE
        DO i = MP1,N,5
          X(i)     = Alpha*X(i)
          X(i + 1) = Alpha*X(i + 1)
          X(i + 2) = Alpha*X(i + 2)
          X(i + 3) = Alpha*X(i + 3)
          X(i + 4) = Alpha*X(i + 4)
        END DO
      END IF

      END SUBROUTINE WSCAL

!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WLAMCH( C )
!--------------------------------------------------------------
!     returns epsilon machine
!     after LAPACK
!     replace this by the function from the optimized LAPACK implementation:
!          CALL SLAMCH('E') or CALL DLAMCH('E')
!--------------------------------------------------------------
!      USE gckpp_Precision

      CHARACTER ::  C
      INTEGER    :: i
      REAL(kind=dp), SAVE  ::  Eps
      REAL(kind=dp)  ::  Suma
      REAL(kind=dp), PARAMETER  ::  ONE=1.0_dp, HALF=0.5_dp
      LOGICAL, SAVE   ::  First=.TRUE.

!$OMP THREADPRIVATE( Eps, First )      

      IF (First) THEN
        First = .FALSE.
        Eps = HALF**(16)
        DO i = 17, 80
          Eps = Eps*HALF
          CALL WLAMCH_ADD(ONE,Eps,Suma)
          IF (Suma.LE.ONE) GOTO 10
        END DO
        PRINT*,'ERROR IN WLAMCH. EPS < ',Eps
        RETURN
10      Eps = Eps*2
        i = i-1      
      END IF

      WLAMCH = Eps

      END FUNCTION WLAMCH
     
      SUBROUTINE WLAMCH_ADD( A, B, Suma )
!      USE gckpp_Precision
      
      REAL(kind=dp) A, B, Suma
      Suma = A + B

      END SUBROUTINE WLAMCH_ADD
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE SET2ZERO(N,Y)
!--------------------------------------------------------------
!     copies zeros into the vector y:  y <- 0
!     after BLAS
!--------------------------------------------------------------
      
      INTEGER ::  i,M,MP1,N
      REAL(kind=dp) ::  Y(N)
      REAL(kind=dp), PARAMETER :: ZERO = 0.0d0

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = ZERO
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i)     = ZERO
        Y(i + 1) = ZERO
        Y(i + 2) = ZERO
        Y(i + 3) = ZERO
        Y(i + 4) = ZERO
        Y(i + 5) = ZERO
        Y(i + 6) = ZERO
        Y(i + 7) = ZERO
      END DO

      END SUBROUTINE SET2ZERO


!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WDOT (N, DX, incX, DY, incY) 
!--------------------------------------------------------------
!     dot produce: wdot = x(1:N)*y(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SDOT(N,X,1,Y,1) or  CALL DDOT(N,X,1,Y,1)
!--------------------------------------------------------------
!      USE messy_mecca_kpp_Precision
!--------------------------------------------------------------
      IMPLICIT NONE
      INTEGER :: N, incX, incY
      REAL(kind=dp) :: DX(N), DY(N) 

      INTEGER :: i, IX, IY, M, MP1, NS
                                 
      WDOT = 0.0D0 
      IF (N .LE. 0) RETURN 
      IF (incX .EQ. incY) IF (incX-1) 5,20,60 
!                                                                       
!     Code for unequal or nonpositive increments.                       
!                                                                       
    5 IX = 1 
      IY = 1 
      IF (incX .LT. 0) IX = (-N+1)*incX + 1 
      IF (incY .LT. 0) IY = (-N+1)*incY + 1 
      DO i = 1,N 
        WDOT = WDOT + DX(IX)*DY(IY) 
        IX = IX + incX 
        IY = IY + incY 
      END DO 
      RETURN 
!                                                                       
!     Code for both increments equal to 1.                              
!                                                                       
!     Clean-up loop so remaining vector length is a multiple of 5.      
!                                                                       
   20 M = MOD(N,5) 
      IF (M .EQ. 0) GO TO 40 
      DO i = 1,M 
         WDOT = WDOT + DX(i)*DY(i) 
      END DO 
      IF (N .LT. 5) RETURN 
   40 MP1 = M + 1 
      DO i = MP1,N,5 
          WDOT = WDOT + DX(i)*DY(i) + DX(i+1)*DY(i+1) + DX(i+2)*DY(i+2) +  &
                   DX(i+3)*DY(i+3) + DX(i+4)*DY(i+4)                   
      END DO 
      RETURN 
!                                                                       
!     Code for equal, positive, non-unit increments.                    
!                                                                       
   60 NS = N*incX 
      DO i = 1,NS,incX 
        WDOT = WDOT + DX(i)*DY(i) 
      END DO 

      END FUNCTION WDOT                                          


!--------------------------------------------------------------
      SUBROUTINE WADD(N,X,Y,Z)
!--------------------------------------------------------------
!     adds two vectors: z <- x + y
!     BLAS - like
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER :: i, M, MP1, N
      REAL(kind=dp) :: X(N),Y(N),Z(N)

      IF (N.LE.0) RETURN

      M = MOD(N,5)
      IF( M /= 0 ) THEN
         DO i = 1,M
            Z(i) = X(i) + Y(i)
         END DO
         IF( N < 5 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,5
         Z(i)     = X(i)     + Y(i)
         Z(i + 1) = X(i + 1) + Y(i + 1)
         Z(i + 2) = X(i + 2) + Y(i + 2)
         Z(i + 3) = X(i + 3) + Y(i + 3)
         Z(i + 4) = X(i + 4) + Y(i + 4)
      END DO

      END SUBROUTINE WADD
      
      
      
!--------------------------------------------------------------
      SUBROUTINE WGEFA(N,A,Ipvt,info)
!--------------------------------------------------------------
!     WGEFA FACTORS THE MATRIX A (N,N) BY
!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!     LINPACK - LIKE 
!--------------------------------------------------------------
!
      INTEGER       :: N,Ipvt(N),info
      REAL(kind=dp) :: A(N,N)
      REAL(kind=dp) :: t, dmax, da
      INTEGER       :: j,k,l
      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0

      info = 0

size: IF (n > 1) THEN
      
col:  DO k = 1, n-1

!        find l = pivot index
!        l = idamax(n-k+1,A(k,k),1) + k - 1
         l = k; dmax = abs(A(k,k))
         DO j = k+1,n
            da = ABS(A(j,k))
            IF (da > dmax) THEN
              l = j; dmax = da
            END IF
         END DO
         Ipvt(k) = l

!        zero pivot implies this column already triangularized
         IF (ABS(A(l,k)) < TINY(ZERO)) THEN
            info = k
            return
         ELSE   
            IF (l /= k) THEN
               t = A(l,k); A(l,k) = A(k,k); A(k,k) = t
            END IF
            t = -ONE/A(k,k)
            CALL WSCAL(n-k,t,A(k+1,k),1)
            DO j = k+1, n
               t = A(l,j)
               IF (l /= k) THEN
                  A(l,j) = A(k,j); A(k,j) = t
               END IF
               CALL WAXPY(n-k,t,A(k+1,k),1,A(k+1,j),1)
            END DO         
         END IF
         
       END DO col
       
      END IF size
      
      Ipvt(N) = N
      IF (ABS(A(N,N)) == ZERO) info = N
      
      END SUBROUTINE WGEFA


!--------------------------------------------------------------
      SUBROUTINE WGESL(Trans,N,A,Ipvt,b)
!--------------------------------------------------------------
!     WGESL solves the system
!     a * x = b  or  trans(a) * x = b
!     using the factors computed by WGEFA.
!
!     Trans      = 'N'   to solve  A*x = b ,
!                = 'T'   to solve  transpose(A)*x = b
!     LINPACK - LIKE 
!--------------------------------------------------------------

      INTEGER       :: N,Ipvt(N)
      CHARACTER     :: trans
      REAL(kind=dp) :: A(N,N),b(N)
      REAL(kind=dp) :: t
      INTEGER       :: k,kb,l

      
      SELECT CASE (Trans)

      CASE ('n','N')  !  Solve  A * x = b

!        first solve  L*y = b
         IF (n >= 2) THEN
          DO k = 1, n-1
            l = Ipvt(k)
            t = b(l)
            IF (l /= k) THEN
               b(l) = b(k)
               b(k) = t
            END IF
            CALL WAXPY(n-k,t,a(k+1,k),1,b(k+1),1)
          END DO
         END IF
!        now solve  U*x = y
         DO kb = 1, n
            k = n + 1 - kb
            b(k) = b(k)/a(k,k)
            t = -b(k)
            CALL WAXPY(k-1,t,a(1,k),1,b(1),1)
         END DO
      
      CASE ('t','T')  !  Solve transpose(A) * x = b

!        first solve  trans(U)*y = b
         DO k = 1, n
            t = WDOT(k-1,a(1,k),1,b(1),1)
            b(k) = (b(k) - t)/a(k,k)
         END DO
!        now solve trans(L)*x = y
         IF (n >= 2) THEN
         DO kb = 1, n-1
            k = n - kb
            b(k) = b(k) + WDOT(n-k,a(k+1,k),1,b(k+1),1)
            l = Ipvt(k)
            IF (l /= k) THEN
               t = b(l); b(l) = b(k); b(k) = t
            END IF
         END DO
         END IF
   
      END SELECT

      END SUBROUTINE WGESL
! End of BLAS_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



END MODULE gckpp_LinearAlgebra

